###-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureDetailCtrl               #
#   -> picture-detail-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-###
angular.module("DocCheckPictures.controllers").controller('PictureDetailCtrl', 
(
  $scope,               
  $state,                 # state control
  $ionicSlideBoxDelegate  # slide box control
  $ionicGesture           # zoom on double tap
  $translate              # translate service
  $ionicPopup             # for confirm popup
  $ionicViewService       # for getBackView() (back button)
  $ionicScrollDelegate    # for zoom scroll control
  $cacheFactory
  Popup                  # for various info popups
  Loading                 # loading control
  Pictures                # pictures handover serv
  UserPictures
  Search               
) ->

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Service-link functions & state transitions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  # go to edit view, save relevant information in the service
  $scope.toEdit = ->
    if($scope.currentItem.title.length > 0)
      Pictures.setCurrentIndex($scope.currentIndex, "my")
      Pictures.setCurrentPicture($scope.currentItem)
      $state.go('app.picturemy.editmy')

  # go to info view, save relevant information in the service
  $scope.toInfo = ->
    if($scope.currentItem.title.length > 0)
      if($state.current.name.indexOf('home') > 0)
        location = 'home'
      else if($state.current.name.indexOf('picturemy') > 0)
        location = 'my'
      else if($state.current.name.indexOf('picture') > 0)
        location = 'search'
      Pictures.setCurrentIndex($scope.currentIndex, location)
      Pictures.setItems($scope.details.items, $scope.currentItem.id)
      state = $state.current.name.substring(0, $state.current.name.lastIndexOf('.'))
      $state.go(state+'.info', {'pictureId':$scope.currentItem.id})

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Scope functions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  # load item information for the currently shown picture
  $scope.loadItemInfoFor = (index) ->
    $scope.currentItem.title = ''    
    $scope.currentIndex = index % $scope.details.items.length    
    Loading.start()
    Search.getPictureDetailByQuery($scope.details.items[index].id, $cacheFactory.get('PictureDetailCache'))
    .success((response) ->
      $scope.currentItem = response
      $scope.overlay.show = true
      Loading.stop()
    )
    .error((error) ->
      Loading.stop()
      $scope.currentItem.title = ''
    )

  $scope.dc = {
    deletePopup : () ->
      $scope.hideTabs()
      $scope.dc.confirmPopup = true

    deletePositive : (result) ->
      $scope.dc.confirmPopup = false
      $scope.showTabs()
      $scope.deletePicture()

    deleteNegative : (result) ->
      $scope.dc.confirmPopup = false
      $scope.showTabs()
      console.log("negative")

    confirmPopup : false
  }

  #
  # Editing
  #
  # delete one of your pictures (only possible if browsing own pictures)
  $scope.deletePicture = (id=$scope.currentItem.id) ->
    Loading.start()
    UserPictures.delete(id)
    .success((response) -> $scope.deleteSuccess(response))
    .error((error) -> $scope.deleteError(error))     
    ###
    confirmPopup = $ionicPopup.confirm({
      title: $scope.translations.DETAIL_DELETE_CHECK_HEADING
      template: $scope.translations.DETAIL_DELETE_CHECK_CONTENT
      buttons: [
        { 
          text: '' #$scope.translations.YES
          type: 'dc-confirm-button'
          onTap: ->
            if !Loading.inProgress()
              Loading.start()
              UserPictures.delete(id)
              .success((response) -> $scope.deleteSuccess(response))
              .error((error) -> $scope.deleteError(error))            
        },
        { 
          text: '' 
          type: 'dc-cancel-button'
        } #$scope.translations.NO }
      ]
    })
    ###

  # delete success function
  $scope.deleteSuccess = (response) ->
    $scope.details.items.splice($scope.currentIndex, 1)
    Loading.stop()
    $ionicViewService.getBackView().go()
    #$state.go('app.picturemy.searchmy')

  # delete error function
  $scope.deleteError = (error) ->
    if($scope.currentItem.title.length > 0)
      Loading.stop()
      Popup.show($scope.translations.DETAIL_DELETE_FAILURE_HEADING, $scope.translations.DETAIL_DELETE_FAILURE_CONTENT)

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # UI
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.calculateButtonWidth = ->
    $scope.buttons.width = (window.innerWidth - 91) / 4

  # Hide pictures which aren't near the currently shown slide
  $scope.isSlideHidden = ($index) ->
    len = $scope.details.items.length
    if (($index + len - $scope.currentIndex) % len > 1 && ($scope.currentIndex + len - $index) % len > 1) 
      return true
    return false

  # Show info overlay
  $scope.showOverlay = (show) -> $scope.overlay.show = (show && !Loading.inProgress())
  # Toggle info overlay
  $scope.toggleOverlay = -> $scope.overlay.show = (!$scope.overlay.show && !Loading.inProgress())
  
  #
  # Zoom Control
  #
  # Check if picture is zoomed
  # -> if yes, enable sliding to the next image
  # -> if not, disable sliding in the slide box
  $scope.checkZoomLevel = ->   
    if($ionicScrollDelegate.getScrollView().__zoomLevel <= 1)
        $ionicSlideBoxDelegate.enableSlide(true)
    else
        $ionicSlideBoxDelegate.enableSlide(false)

  # perform a zoom step on double-tap (or zoom out if currently zoomed in)
  $scope.triggerZoom = (e) ->    
    pos = e.gesture.srcEvent.changedTouches[0]

    if($ionicScrollDelegate.getScrollView().__zoomLevel > 3.0)
        $ionicScrollDelegate.zoomTo(1.0, true, pos.clientX, pos.clientY)
    else
        $ionicScrollDelegate.zoomBy(3.0, true, pos.clientX, pos.clientY)

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Init
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 
  $scope.init = ->
    # UI utility variables
    $scope.loaded = false
    $scope.overlay = {'show' : true}

    # check if a linked item should be loaded
    linkedItem = Pictures.getLinkedPicture()

    # if we have a linked item, load it into the view    
    if linkedItem.id
      $scope.details = {items : [linkedItem], 'editable' : false}
      $scope.currentIndex = 0
    # else load the item collection for the current location (home view, own pictures or regular search)
    else
      # determine the current location dependent on the current state to adjust the view accordingly
      if($state.current.name.indexOf('home') > 0)
        location = 'home'
      else if($state.current.name.indexOf('picturemy') > 0)
        location = 'my'
      else if($state.current.name.indexOf('picture') > 0)
        location = 'search'
      $scope.details = {items : Pictures.getItems(location), 'editable' : location == 'my'}    
      $scope.currentIndex = Pictures.getCurrentIndex(location) || 0
    $scope.currentItem = {'title' : ''}     

    element = angular.element(document.querySelector('#pictureScroll'))
    $ionicGesture.on('doubletap', $scope.triggerZoom, element)

    ###
    # Due to the fact that the Ionic slide box is currently not capable of building up dynamically and 
    # slide to a given index afterwards, timeouts need to be used at the moment.
    # TODO: Keep an eye on updates.
    ###
    setTimeout(->
      $scope.loadItemInfoFor($scope.currentIndex)
      setTimeout(->
        $scope.loaded = true
        $ionicSlideBoxDelegate.update()
      , 150)
    , 100)

    $scope.buttons = {'width' : 0}

    $scope.calculateButtonWidth()

    angular.element(window).bind('resize', ->
      $scope.calculateButtonWidth()
    ) 

    # Get the translations needed in this controller
    $translate([
               'DETAIL_DELETE_CHECK_HEADING', 
               'DETAIL_DELETE_CHECK_CONTENT',
               'DETAIL_DELETE_SUCCESS_HEADING',
               'DETAIL_DELETE_SUCCESS_CONTENT',
               'DETAIL_DELETE_FAILURE_HEADING',
               'DETAIL_DELETE_FAILURE_CONTENT',
               'DETAIL_PICINFO_FAILURE_CONTENT',
               'CONNECTION_ERROR',
               'YES',
               'NO'
               ])
    .then((translations) -> 
      $scope.translations = translations
    )
    
  $scope.init()  
)