###-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureDetailCtrl               #
#   -> picture-detail-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-###
angular.module("DocCheckPictures.controllers").controller('PictureDetailInfoCtrl', 
(
  $scope,
  $state,
  $stateParams, 
  $ionicViewService, 
  $cacheFactory,
  $translate,       
  Loading, 
  Pictures,  
  Search,
  UserPictures
) ->
  
  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Service-link functions & state transitions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.toEdit = ->
    if($scope.currentItem.title.length > 0)
      Pictures.setCurrentIndex($scope.currentIndex, "my")
      Pictures.setCurrentPicture($scope.currentItem)
      $state.go('app.picturemy.editmy')

  # Initiate a search for a clicked tag
  $scope.searchFor = (tag) ->
    Search.setLastSearchPattern(tag)
    $state.go('app.picture.search')

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Scope functions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.dc = {
    deletePopup : () ->
      $scope.hideTabs()
      $scope.dc.confirmPopup = true

    deletePositive : (result) ->
      $scope.dc.confirmPopup = false
      $scope.showTabs()
      $scope.deletePicture()

    deleteNegative : (result) ->
      $scope.dc.confirmPopup = false
      $scope.showTabs()
      console.log("negative")

    confirmPopup : false
  }

  $scope.setRating = ($index) ->
    if $scope.rating == $index
      $scope.rating = $scope.rating - 1
    else
      $scope.rating = $index

  $scope.getNumber = (num) ->
    return new Array(num)

  # Load information for the currently shown picture
  $scope.loadItemInfo = (pId) ->
    Loading.start()
    Search.getPictureDetailByQuery(pId, $cacheFactory.get('PictureDetailCache'))
    .success((response) ->
      console.log response

      $scope.currentItem = response

      tags = $scope.currentItem.tags
      
      # Make sure there are no duplicates in the tags
      $scope.currentItem.tags = []
      i = 0
      while i < tags.length
        j = 0
        isIn = false
        while j < $scope.currentItem.tags.length
          if tags[i] == $scope.currentItem.tags[j]
            isIn = true
          j++
        if !isIn
          $scope.currentItem.tags.push(tags[i])
        i++
      Loading.stop()
      if !$scope.$$phase
        $scope.$apply()
    )
    .error((error) ->
      $scope.currentItem.title = $scope.translations.CONNECTION_ERROR
      Loading.stop()
    )

  ###
  # Editing
  ###
  # delete one of your pictures (only possible if browsing own pictures)
  $scope.deletePicture = (id=$scope.currentItem.id) ->
    Loading.start()
    UserPictures.delete(id)
    .success((response) -> $scope.deleteSuccess(response))
    .error((error) -> $scope.deleteError(error))     

  # delete success function
  $scope.deleteSuccess = (response) ->
    Loading.stop()
    $ionicViewService.nextViewOptions({
      disableBack: true
    });
    $state.go('app.picturemy.searchmy')

  # delete error function
  $scope.deleteError = (error) ->
    if($scope.currentItem.title.length > 0)
      Loading.stop()
      Popup.show($scope.translations.DETAIL_DELETE_FAILURE_HEADING, $scope.translations.DETAIL_DELETE_FAILURE_CONTENT)

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # UI
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.isFilled = ($index) ->
    if ($index <= $scope.currentItem.rating_value)
      return "filled ion-ios7-star"
    return "notfilled ion-ios7-star-outline"

  $scope.calculateButtonWidth = ->
    $scope.buttons.width = (window.innerWidth - 91) / 4

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Init
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 
    
  ###
  # Basic Utility
  ###
  $scope.init = ->
    $scope.buttons = {
      'width' : 0
    }
    $scope.calculateButtonWidth()

    $scope.loadItemInfo($stateParams.pictureId)
    $scope.formatted = {'tags':''}
    $scope.info = {'editable' : $state.current.name.indexOf('my') >= 0} 

    document.onclick = (e) ->
      if(e.target.href != undefined || e.srcElement.href != undefined)
        e = e || window.event;
        element = e.target || e.srcElement;

        # If a pictures link has been clicked...
        if (
            element.href.indexOf('pictures.doccheck.com') >= 0 || 
            element.href.indexOf('../') == 0 || 
            element.href.indexOf('file://') >= 0 && element.href.indexOf('/photos/') > 0
          )
          e.preventDefault()
          e.stopPropagation()
          
          href = element.href

          if href.lastIndexOf('/')+1 == href.length
            href = href.substring(0, href.length-1)

          id = href.substring(href.lastIndexOf('/')+1)
          
          # ...determine the picture ID length...
          i = 0
          while i < id.length
            if id.charAt(i) < '0' || id.charAt(i) > '9'
              break
            i++
          # ...cut it out of the url...
          id = id.substring(0, i)

          # ...hand it to the service...
          Search.getPictureDetailByQuery(id, $cacheFactory.get('PictureDetailCache'))
          .success((response) ->
            Pictures.setLinkedPicture(response)
            state = $state.current.name.substring(0, $state.current.name.lastIndexOf('.'))
            # ...and go to detail state...
            $state.go(state+'.detail')
          )

        else if (element.tagName == 'A' && element.href != undefined && element.href != "" && (element.href.indexOf("http") > -1 || element.href.indexOf("www") > -1) && element.href.indexOf("#/app") == -1) 
            window.open(element.href, "_blank", "location=yes")
            return false

    $translate([
                'CONNECTION_ERROR',
                'LOADING'
              ])
    .then((translations) ->
      $scope.translations = translations
      if !$scope.currentItem || !$scope.currentItem.title
        $scope.currentItem = {'title' : $scope.translations.LOADING}
    )    
    
  $scope.init()  
)