###-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureHomeCtrl                 #
#   -> picture-search-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-###
angular.module("DocCheckPictures.controllers").controller('PictureHomeCtrl', 
(
  $scope, 
  $controller,
  $ionicScrollDelegate,  
  $ionicSlideBoxDelegate, 
  $interval,
  $timeout,
  $state,
  Loading,  
  Pictures, 
  Search,
  Network,
  SlideTimer
) ->

  $controller('PictureSearchCtrl', {$scope: $scope})

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Service-link functions & state transitions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.toInfo = (itemId) ->
    index = $ionicSlideBoxDelegate.$getByHandle("homeSlide").currentIndex()
    
    if !itemId
      itemId = $scope.items[index].id
    
    Pictures.setCurrentIndex(index, "home")    
    Pictures.setItems($scope.items, itemId)

    state = $state.current.name.substring(0, $state.current.name.lastIndexOf('.'))
    $state.go(state+'.info', {'pictureId':itemId})

  $scope.goToSearch = ->
    Search.setLastSearchPattern($scope.searchvar.keyword)
    $state.go("app.picture.search")

  # Transfer the current items to the Pictures service to make them accessible for other views.
  $scope.setItemsInService = (id) ->
    Pictures.setItems($scope.items, id, 'home')
    Pictures.ownItems(false)

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Scope functions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  ###
  # Search - adjusted for home view
  ###
  $scope.search = (searchQuery="", page=0) ->
    $scope.searchvar.connectionError = false
    append = true
    if searchQuery.length > 2 || searchQuery.length == 0 
      Loading.start()
      
      # Load additional items for the current keyword
      if searchQuery == "search.more" 
        $scope.searchvar.hasMoreData = true
        $scope.searchvar.noDataAtAll = false
        $scope.page++
      # Initiate a new search     
      else 
        $scope.clearItems()
        $scope.page = 1    
        $ionicScrollDelegate.scrollTop()

        append = false        
      try 
        # Start the actual search request
        Search.getPicturesByQuery(searchQuery, $scope.page, 20, 1).
          success((response) ->     
            $scope.searchSuccess(response, append)
          ).error((data, status, headers, config) ->
            $scope.searchFailure(data, status, headers, config)
          )         
      catch e
        return

  # search success function
  $scope.searchSuccess = (response, append) ->
    if response._meta.item_count == 0 
      # No data found for keyword
      $scope.searchvar.hasMoreData = false
      $scope.searchvar.noDataAtAll = true
    else 
      # Data found
      $scope.setSearchResults(response)
      $scope.setItems(append)              
      Search.setCache("homeCache", $scope.page, $scope.items, response._meta.item_count)     
      $scope.searchvar.noDataAtAll = false
      if response._links.next == undefined then $scope.searchvar.hasMoreData = false else $scope.searchvar.hasMoreData = true
    # Finish the search
    $scope.$broadcast('scroll.resize')
    $scope.$broadcast('scroll.infiniteScrollComplete')                      
    $scope.clearResults()
    $scope.load = true
    Loading.stop()
    return

  # search failure function
  $scope.searchFailure = (data, status, headers, config) ->
    # No connection           
    $scope.searchvar.hasMoreData = false
    $scope.searchvar.connectionError = true
    $scope.clearResults()            
    Loading.stop()

    document.addEventListener("online", ->
      $scope.search("search.more")
      document.removeEventListener("online")
    , false);

    # Stop loading & inform the user
    $scope.$broadcast('scroll.infiniteScrollComplete')
    return

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # UI
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  # set dimensions adjusted for home view
  $scope.setDimensions = (update) ->
    $scope.pictures.width = window.innerWidth
    $scope.pictures.height = Math.round(window.innerWidth / 2)

    if !$scope.$$phase
      $scope.$apply()

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Init
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ###     
  $scope.init = ->    
    $scope.cache = Search.getCache("homeCache")

    $scope.currentSlide = Pictures.getCurrentIndex("home") || 0

    $scope.pictures = {
      'width' : 0
      'height' : 0
    }
    $scope.searchvar = {
      'hasMoreData' : true,
      'noDataAtAll' : false,
      'connectionError' : false,
      'keyword':''
    }
    $scope.items = $scope.cache.items || []
    $scope.page = $scope.cache.page || 0
    $scope.totalResults = $scope.cache.totalResults || 0
    
    if $scope.items.length == 0
      $timeout(-> 
        Search.clearCaches()
        $scope.search("")
      , 500)

    $scope.lastResults = []   
    $scope.setDimensions()    

    $scope.load = false
    Loading.start()

    $timeout(->
      $scope.load = true
      Loading.stop()

      if(!$scope.searchvar.connectionError)
        SlideTimer.start(->
          $ionicSlideBoxDelegate.$getByHandle("homeSlide").slide(($ionicSlideBoxDelegate.$getByHandle("homeSlide").currentIndex() + 1) % $ionicSlideBoxDelegate.$getByHandle("homeSlide").slidesCount(), 1000)
          $ionicSlideBoxDelegate.$getByHandle("homeSlide").enableSlide(false)
        , 4000)
      $timeout(->
        $ionicSlideBoxDelegate.$getByHandle("homeSlide").enableSlide(false)
      )
    , 1500)

    $scope.$on('$destroy', -> 
      Loading.stop()
    )

    angular.element(window).bind('resize', ->
      $scope.setDimensions(true)
    ) 
  $scope.init() 
)