###-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureSearchCtrl               #
#   -> picture-search-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-###
angular.module("DocCheckPictures.controllers").controller('PictureSearchCtrl', 
(
  $scope, 
  $state, 
  $translate,
  $ionicScrollDelegate, 
  $http, 
  $timeout,
  Loading,   
  Pictures, 
  Camera, 
  LocalStorage, 
  Login,
  Search
) ->

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Service-link functions & state transitions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  # Transfer the current items to the Pictures service to make them accessible for other views.
  $scope.setItemsInService = (id) ->
    Pictures.setItems($scope.items, id, 'search')

  $scope.goHome = ->
    $state.go('app.home.search')



  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Scope functions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  # Adjust the shown items to the newest search results.
  # + (bool) append: if false the item array is cleared first,
  #                  otherwise the results will be appended.
  $scope.setItems = (append=false) ->
    if !append 
      $scope.clearItems()
    $scope.items.push.apply($scope.items, $scope.lastResults)

  # Empties the array containing the currently shown items.
  $scope.clearItems = ->
    while $scope.items.length > 0
      $scope.items.pop()
  
  $scope.setSearchResults = (response) ->
    if response && response._items && response._items.pictures_photo.length != 0
      for i in [0..response._items.pictures_photo.length-1]        
        photo = response._items.pictures_photo[i]
        photo.i = i
        photo.thumbnails.mq = photo.thumbnails.mq.replace("/photos/", "/images/")
        photo.thumbnails.l = photo.thumbnails.l.replace("/photos/", "/images/")

        $scope.lastResults.push(photo)
    $scope.totalResults = parseInt(response._meta.item_count, 10)  

  # Clears the search results array.
  $scope.clearResults = ->
    $scope.lastResults = []



  #
  # Search
  #

  $scope.search = (searchQuery="", page=0) ->
    console.log("search")
    $scope.searchvar.connectionError = false
    $scope.searchPattern = searchQuery
    append = true
    if searchQuery.length > 2 || searchQuery.length == 0 
      if Loading.inProgress()
        return
      else 
        Loading.start()
      
      # Load additional items for the current keyword
      if searchQuery == "search.more" 
        $scope.searchvar.hasMoreData = true
        $scope.searchvar.noDataAtAll = false

        searchQuery = Search.getLastSearchPattern()
        $scope.page++
      # Initiate a new search     
      else 
        $scope.clearItems()
        #$scope.clearInfo()
        $scope.page = 1    
        $ionicScrollDelegate.scrollTop()

        append = false
        
        Search.setLastSearchPattern(searchQuery)      
        
      try 
        # Start the actual search request
        Search.getPicturesByQuery(searchQuery, $scope.page, $scope.intPhotosPerPage).
          success((response) ->     
            $scope.searchSuccess(response, append)
          ).error((data, status, headers, config) ->
            $scope.searchFailure(data, status, headers, config)
          )         
      catch e 
        return

  $scope.searchSuccess = (response, append) ->
    $timeout.cancel($scope.refreshTimeout)
    document.removeEventListener("online")
    if response._meta.item_count == 0 
      # No data found for keyword
      $scope.searchvar.hasMoreData = false
      $scope.searchvar.noDataAtAll = true
    else 
      # Data found
      $scope.setSearchResults(response)
      $scope.setItems(append)       
      Search.setCache("searchCache", $scope.page, $scope.items, response._meta.item_count)       
      $scope.searchvar.noDataAtAll = false
      if response._links.next == undefined then $scope.searchvar.hasMoreData = false else $scope.searchvar.hasMoreData = true
    # Finish the search
    $scope.$broadcast('scroll.resize')
    $scope.$broadcast('scroll.infiniteScrollComplete')            
    $scope.setInfo(Search.getLastSearchPattern(), response._meta.item_count)            
    $scope.clearResults()
    Loading.stop()
    return

  $scope.searchFailure = (data, status, headers, config) ->
    # No connection         
    $scope.searchvar.hasMoreData = false
    $scope.searchvar.connectionError = true
    $scope.clearResults()            
    Loading.stop()

    $scope.page--
    document.addEventListener("online", ->
      document.removeEventListener("online")
      $timeout(->
        Loading.stop()
        $scope.search("search.more")
        if !$scope.$$phase
          $scope.$apply()
      , 500)
      
    , false);

    $scope.refreshTimeout = $timeout(->
      $scope.search("search.more")
    , 5000)

    # Stop loading & inform the user
    $scope.$broadcast('scroll.infiniteScrollComplete')
    $scope.setInfo(Search.getLastSearchPattern(), 0)
    return    

  $scope.setDimensions = (update) ->
    # -> columns
    columns = Math.floor(window.innerWidth / $scope.pictures.minPictureDim)    
    if (columns > $scope.pictures.maxColumns)
      columns = $scope.pictures.maxColumns
    # -> container dimensions
    $scope.pictures.containerDim = window.innerWidth / columns;
    # -> rows for settings photos per page (preloading)
    rows = Math.round(window.innerHeight / $scope.pictures.containerDim)
    $scope.intPhotosPerPage = rows * columns
    # -> picture dimensions
    if($scope.pictures.containerDim > $scope.pictures.maxPictureDim)
      $scope.pictures.picturesDim = $scope.pictures.maxPictureDim
    else
      $scope.pictures.picturesDim = Math.round($scope.pictures.containerDim - 2)
    # -> picture margins (centering in container)
    $scope.pictures.picturesMargin = ($scope.pictures.containerDim - $scope.pictures.picturesDim) / 2   



  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # UI
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.loseFocus = ($event) ->
    formElement = $event.currentTarget
    formElement.children[0].children[0].blur()

  $scope.setInfo = (keyword, results) ->
    if($scope.searchvar.connectionError && $scope.items.length > 0)
      $scope.info = $scope.translations.CONNECTION_ERROR
    else if keyword == ''
      $scope.info = $scope.translations.SEARCH_NEWEST_PICTURES
    else if($scope.searchvar.noDataAtAll)
      $scope.info = $scope.translations.SEARCH_NO_RESULTS
    else if($scope.items.length > 0)
      $scope.info = results + ' ' + $scope.translations.SEARCH_RESULTS_FOR + ' "' + keyword + '"'
    else 
      $scope.clearInfo()

  $scope.clearInfo = ->
    $scope.info = ''

  $scope.clearSearch = ->
    $scope.searchvar.keyword = ''

  $scope.scroll = ->
    if ($scope.lastScrollPos > $ionicScrollDelegate.getScrollPosition().top)
      if !$scope.bar.shown
        $scope.bar.shown = true
        if !$scope.$$digest
          $scope.$apply()
    else if ($scope.lastScrollPos < $ionicScrollDelegate.getScrollPosition().top)
      if $scope.bar.shown
        $scope.bar.shown = false
        if !$scope.$$digest
          $scope.$apply()
    else if ($ionicScrollDelegate.getScrollPosition().top == 0)
      if !$scope.bar.shown
        $scope.bar.shown = true
        if !$scope.$$digest
          $scope.$apply()
      
    $scope.lastScrollPos = $ionicScrollDelegate.getScrollPosition().top

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Event Listeners
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ###

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Init
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.init = ->
    $scope.info = ''

    $scope.cache = Search.getCache("searchCache")

    $scope.intPhotosPerPage = 36
    $scope.page = $scope.cache.page || 0
    $scope.totalResults = $scope.cache.totalResults || 0
    
    $scope.bar = {
      'shown' : true;
    }    

    $scope.lastResults = []
    $scope.items = $scope.cache.items || []
    $scope.searchvar = {
      'hasMoreData' : true,
      'noDataAtAll' : false,
      'connectionError' : false,
      'keyword': $scope.cache.lastSearchPattern || ""
      'lastSearchTerm': ''
    }    
    
        
    $scope.pictures = {
      'maxColumns' : 3, #constant
      'minPictureDim' : 150, #constant
      'maxPictureDim' : 300, #constant
      'picturesMargin' : 0,
      'containerPadding' : 0,
      'containerDim' : 0, 
      'picturesDim' : 0
    }
    
    angular.element(window).bind('resize', ->
      $scope.setDimensions(true)
    ) 
    $scope.setDimensions()
    
    $scope.$on 'pictures.reload', ->
      $scope.searchvar.keyword = ''
      $scope.search("")      
      $scope.$apply()

    ###
    # Translations
    ### 

    $translate([
               'CONNECTION_ERROR', 
               'SEARCH_NEWEST_PICTURES',
               'SEARCH_NO_RESULTS',
               'SEARCH_RESULTS_FOR'
               ])
    .then((translations) -> 
      $scope.translations = translations
      if $scope.items.length > 0
        $scope.setInfo($scope.searchvar.keyword, $scope.totalResults)
    )

  $scope.init() 
)