###-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureSearchMyCtrl             #
#   -> picture-search-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-###
angular.module("DocCheckPictures.controllers").controller('PictureSearchMyCtrl', 
(
  $scope,  
  $rootScope,
  $controller, 
  $translate, 
  $ionicViewService, 
  $ionicScrollDelegate, 
  $stateParams,
  Popup, 
  Loading,   
  Pictures, 
  Login, 
  Search,
  Network
) ->

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Inheritance
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $controller('PictureSearchCtrl', {$scope: $scope})

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Service-link functions & state transitions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  # Transfer the current items to the Pictures service to make them accessible for other views.
  $scope.setItemsInService = (id) ->
    Pictures.setItems($scope.items, id, 'my')
    Pictures.ownItems(true)

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Scope functions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.search = (searchQuery="", page=0) ->
    if $scope.dot.loggedIn  
      $scope.searchvar.connectionError = false
      append = true

      if Loading.inProgress()
        return
      else 
        Loading.start()
        
      # Load additional items for the current keyword
      if searchQuery == "search.more" 
        $scope.searchvar.hasMoreData = true
        $scope.searchvar.noDataAtAll = false

        searchQuery = ""
        $scope.page++
      # Initiate a new search     
      else 
        $scope.clearItems()
        $scope.page = 1    
        $ionicScrollDelegate.scrollTop()

        append = false
          
      try 
        # Start the actual search request
        Search.getUserPictures($scope.page, $scope.intPhotosPerPage)
          .success((response) ->                   
            $scope.searchSuccess(response)
          ).error((error) ->
            $scope.searchError(error)
          )         
      catch e 
        return

  $scope.searchSuccess = (response) ->
    if response._meta.item_count == 0 
      # No data found for keyword
      $scope.searchvar.hasMoreData = false
      $scope.searchvar.noDataAtAll = true
    else 
      # Data found
      $scope.setSearchResults(response)
      $scope.setItems(true)              
      $scope.searchvar.noDataAtAll = false
      if response._links.next == undefined then $scope.searchvar.hasMoreData = false else $scope.searchvar.hasMoreData = true
    # Finish the search
    $scope.$broadcast('scroll.resize')
    $scope.$broadcast('scroll.infiniteScrollComplete')         
    $scope.clearResults()
    Loading.stop()
    return

  $scope.searchError = (error) ->
    # No connection
    $scope.searchvar.hasMoreData = false
    $scope.searchvar.connectionError = true
    $scope.clearResults()            
    Loading.stop()

    # Stop loading & inform the user
    $scope.$broadcast('scroll.infiniteScrollComplete')

    if(!Login.isAuthenticated())
      Popup.show(
        $scope.translations.CONNECTION_ERROR, $scope.translations.OFFLINE, 3000, ->
          $ionicViewService.getBackView().go()
      ) 
    return

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # UI
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Event Listeners
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.$on 'event:pictures-uploadFinished', ->
    $scope.search('', 0)

  $rootScope.$on 'event:auth-loginConfirmed', ->
    $scope.dot.loggedIn = true
    $scope.search('', 0)

  $rootScope.$on 'event:auth-loginRequired', ->
    $scope.dot.loggedIn = false

  $scope.$on('modal.hidden', ->
    if(!Login.isAuthenticated())
      Popup.show(
        $scope.translations.LOGIN_REQUIRED, $scope.translations.SEARCH_OWN_LOGIN_REQUIRED, 2000, ->
          $ionicViewService.getBackView().go()
      )    
  )

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Init
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.init = ->    
    $scope.login = {
      'noConnection' : !Network.isConnected()
    }

    $scope.intPhotosPerPage = 36
    $scope.page = 0
    $scope.searchvar = {
      'hasMoreData' : true,
      'noDataAtAll' : false,
      'connectionError' : false
    }

    $scope.dot = {
      'loggedIn' : Login.isAuthenticated()
    }

    $scope.totalResults = 0
    $scope.lastResults = []
    $scope.items = []
        
    $scope.pictures = {
      'maxColumns' : 3, #constant
      'minPictureDim' : 150, #constant
      'maxPictureDim' : 300, #constant
      'picturesMargin' : 0,
      'containerPadding' : 0,
      'containerDim' : 0, 
      'picturesDim' : 0
    }
    
    angular.element(window).bind('resize', ->
      $scope.setDimensions(true)
    ) 
    #$scope.$watch('searchbar.shown', (newValue, oldValue) ->
    $scope.setDimensions()
    #)

    if Login.getRequiredFor() == "camera"
      $scope.dot.message = 'LOGIN_REQUIRED_FOR_CAMERA'
    else 
      $scope.dot.message = 'LOGIN_REQUIRED_FOR_OWN'

    $translate([
      'CONNECTION_ERROR'
      'OFFLINE'
      'SEARCH_CONNECTION_INFO'
      'SEARCH_OWN_PICTURES'
      'SEARCH_OWN_LOGIN_REQUIRED'
      'LOGIN_REQUIRED'
    ])
    .then((translations) -> 
      $scope.translations = translations
    )

  $scope.init() 
)