###-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  AppCtrl                         #
#   -> tab-view.html               ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-###
#
# Controller of tab view. Its scope 
# is therefore inherited to other
# controllers and allows accessing 
# elements of the superior tab view.
#

angular.module("DocCheckPictures.controllers").controller('TabCtrl', 
(
  $scope,
  $rootScope,
  $translate, 
  $ionicPopup,
  $state,
  $interval,
  $ionicViewService,
  Popup, 
  Loading, 
  LoginModal, 
  Camera, 
  Login, 
  authService, 
  Network, 
  LocalStorage, 
  UserPictures, 
  UpdateTimer,
  Settings
) ->

  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Service-link functions & state transitions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.goTo = (state) ->
    $state.go(state)

  # go back
  $scope.back = ->
    $ionicViewService.getBackView().go()

  $scope.toOwnPictures = ->
    $state.go('app.settings.main').then(->
      $state.go('app.picturemy.searchmy')
    )

  $scope.isAndroid = ->
    return ionic.Platform.isAndroid()

  # Check if loading is in progress
  $scope.isLoading = ->
    return Loading.inProgress()



  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Scope functions
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  # iframe handling
  window.responseReceived = (iurl, modal) ->  
    if modal
      iframe = angular.element(document.getElementById("loginFrame"))
    else
      iframe = angular.element(document.getElementById("loginFrameSettings"))

    url = iurl
    if(iurl.indexOf("nothing") >= 0)
      iframe[0].src = "https://login.doccheck.com/code/"+Settings.getLanguage(true)+"/2000000006987/s_mobile/response_type=token/_self?dc_force_logout=1"
      return
    $scope.login.noConnection = false
    if(iurl.indexOf("access_token=") >= 0 && iurl.indexOf("error") < 0)
      accessToken = iurl.substring(iurl.indexOf("access_token=")+("access_token=").length)
      accessToken = accessToken.substring(0, accessToken.indexOf("&"))
      expiresIn = iurl.substring(iurl.indexOf("expires_in=")+("expires_in=").length)
      if expiresIn.indexOf('&') >= 0
        expiresIn = expiresIn.substring(0, expiresIn.indexOf('&'))
      
      expiresIn = 60 * 60 * 24 * 31 * 4;

      Login.setToken(accessToken, expiresIn)
      if modal
        $scope.loginModal.hide()
    else if(iurl.indexOf("error") >= 0)
      $ionicPopup.alert({
         title: $scope.tabTranslations.LOGIN_FAILED,
         template: $scope.tabTranslations.LOGIN_FAILED_CONTENT
      })
      .then(-> 
      )
      
      iframe[0].src = "https://login.doccheck.com/code/"+Settings.getLanguage(true)+"/2000000006987/s_mobile/response_type=token/_self?dc_force_logout=1"
      $scope.loginFrame.loading = false
      Login.setLoginFailed(true)
    else if(iurl.indexOf("http") < 0)
      $scope.login.noConnection = true
      $scope.loginModal.hide()
      Login.loginCancelled()  
      document.addEventListener("online", ->
        $scope.login.noConnection = false
        iframe[0].src = "https://login.doccheck.com/code/"+Settings.getLanguage(true)+"/2000000006987/s_mobile/response_type=token/_self?dc_force_logout=1"
      , false)    
    else
      $scope.loginFrame.loading = false
      $scope.$apply()
    Loading.stop()

  ### -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
  # App-wide function for functions requiring authentication
  # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= ### 
  $scope.authAction = (actionCallback, requiredFor='', needsConnection=true) ->
    if(!$scope.tabs.hidden && !$scope.tabs.partly)
      if(!needsConnection || Network.isConnected())
        # Perform authentification check
        # Login.setActionCallback(actionCallback)
        if !Login.isAuthenticated() # if auth check failed, initiate authentication
          Loading.start()
          $scope.login.noConnection = false
          #if $state.current.name != 'app.picturemy.searchmy'
          Login.setRequiredFor(requiredFor)
          $rootScope.$broadcast('event:auth-loginRequired') 
        else # else proceed
          actionCallback()
      else
        $ionicPopup.alert({
         title: $scope.tabTranslations.NO_CONNECTION_HEADING
         template: $scope.tabTranslations.NO_CONNECTION_CONTENT
        })
        .then(-> 
        )

  ### -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
  # App-wide functions for camera & upload handling
  # -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-= ### 
  # Photos
  $scope.getPhotoFromLibrary = ($event) ->
    if(!Loading.inProgress())
      $scope.getPicture(0)

  $scope.takePhoto = ($event) ->
    if(!Loading.inProgress())
      $scope.getPicture(1) 

  $scope.getPicture = (source) ->
    Camera.getPicture({
      sourceType: source, 
      destinationType: 0, 
      mediaType: 0, 
      encodingType: 0,
      correctOrientation: true,
      allowEdit: true,
      saveToPhotoAlbum: true
    }).then ((imageURI) ->
      UserPictures.upload imageURI
        , (event) ->
          Loading.start()
          $scope.popup = Popup.show($scope.tabTranslations.UPLOAD_IN_PROGRESS_HEADING, $scope.tabTranslations.UPLOAD_IN_PROGRESS_CONTENT, 0)
        , (event) ->
          Loading.stop()
          Popup.hide()
          if $state.current.name != "app.picturemy.searchmy"
            $state.go "app.picturemy.searchmy"
          Popup.show($scope.tabTranslations.UPLOAD_SUCCESS_HEADING, $scope.tabTranslations.UPLOAD_SUCCESS_CONTENT, 2000, ->
            $rootScope.$broadcast('event:pictures-uploadFinished')
          )
        , (event) ->
          if event.lengthComputable
            percentComplete = Math.round(event.loaded * 100 / event.total);
        , (event) ->
          Loading.stop()
          Popup.hide()
          Popup.show($scope.tabTranslations.UPLOAD_FAILURE_HEADING, $scope.tabTranslations.UPLOAD_FAILURE_CONTENT)
    )

  $scope.initiateUpload = ->
    $scope.setOverlayButtons()
    $scope.upload.selection = true
    return

  $scope.cancelUpload = ->
    $scope.upload.selection = false
    return

  $scope.toggleUpload = ->
    $scope.setOverlayButtons()
    $scope.upload.selection = !$scope.upload.selection
    return  



  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # UI
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.updateTranslations = ->
    console.log "updating"
    $translate([
               'NO_CONNECTION_HEADING'
               'NO_CONNECTION_CONTENT'
               'LOGIN_REQUIRED'
               'LOGIN_REQUIRED_CONTENT'
               'LOGIN_INCORRECT'
               'LOGIN_FAILED'
               'LOGIN_FAILED_CONTENT'
               'NO_CONNECTION'
               'UPLOAD_SUCCESS_HEADING'
               'UPLOAD_SUCCESS_CONTENT'
               'UPLOAD_FAILURE_HEADING'
               'UPLOAD_FAILURE_CONTENT'
               'UPLOAD_IN_PROGRESS_HEADING'
               'UPLOAD_IN_PROGRESS_CONTENT'
               'CAMERA_DIALOG_HEADING'
               'CAMERA_DIALOG_CONTENT'
               'UPDATE'
               ])
    .then((translations) -> 
      $scope.tabTranslations = translations
    )

  $scope.getButtonStyle = ->
    # camera button width 
    # TODO: get width directly from element...
    dim = (window.innerWidth - 80) / 4
    
    maxDim = 48
    margin = (dim - maxDim) / 2 

    return {
      'width' : maxDim + 'px'
      'height' : maxDim + 'px'
      'margin' : '0px ' + margin + 'px 20px'
      'line-height' : maxDim + 'px'
    }

  $scope.refreshLoginFrame = ->
    iframe = angular.element(document.getElementById("loginFrameSettings"))
    if iframe[0]?
      iframe[0].src = "https://login.doccheck.com/code/"+Settings.getLanguage(true)+"/2000000006987/s_mobile/response_type=token/_self?dc_force_logout=1"
    return

  $scope.setOverlayButtons = ->
    height = window.innerHeight - 75 # nav bar

    if window.innerWidth > window.innerHeight # landscape
      dim = height / 3
      $scope.overlay.dim = $scope.overlay.dim = dim
      $scope.overlay.camera.top = $scope.overlay.gallery.top = height / 2 - dim / 2

      $scope.overlay.camera.left = window.innerWidth / 4 - dim / 2
      $scope.overlay.gallery.left = window.innerWidth * 3 / 4 - dim / 2

    else # portrait
      dim = window.innerWidth / 3
      $scope.overlay.dim = $scope.overlay.dim = dim
      $scope.overlay.camera.left = $scope.overlay.gallery.left = window.innerWidth / 2 - dim / 2

      $scope.overlay.gallery.top = height / 4 - dim / 2
      $scope.overlay.camera.top = height * 3 / 4 - dim / 2

  $scope.hideTabs = ->
    $scope.tabs.hidden = true

  $scope.showTabsPartly = ->
    $scope.tabs.hidden = false
    $scope.tabs.partly = true

  $scope.showTabs = ->
    $scope.tabs.hidden = false
    $scope.tabs.partly = false



  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Event Listeners
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  # Login required
  $scope.$on 'event:auth-loginRequired', (e, rejection) ->
    Login.unsetToken()    
    Loading.stop()

    $scope.login.noConnection = false

    if($state.current.name == 'app.picturemy.searchmy')
      # Popup.show($scope.tabTranslations.LOGIN_REQUIRED, $scope.tabTranslations.LOGIN_REQUIRED_CONTENT)
      Login.cancelActionCallback()
    ###
    $state.go('app.settings.main').then(->
      $state.go('app.picturemy.searchmy')
    )###

    $state.go('app.settings.main').then(->
      $state.go('app.picturemy.searchmy')
    )
    ###
    if(Network.isConnected())
      $scope.openModal()
    else
      Popup.show($scope.tabTranslations.NO_CONNECTION_HEADING, $scope.tabTranslations.NO_CONNECTION_CONTENT)
    ###
  
  #_#_#_#_#_#_#_#_#_#_#
  # Login confirmed
  $scope.$on 'event:auth-loginConfirmed', ->
    Login.executeActionCallback()
    $scope.loginModal.hide()
  
  #_#_#_#_#_#_#_#_#_#_#
  # Login failed
  $scope.$on 'event:auth-login-failed', (e, status) ->
    Loading.stop()
    Login.cancelActionCallback()
    error = $scope.tabTranslations.LOGIN_FAILED
    if (status == 401) 
      error = $scope.tabTranslations.LOGIN_INCORRECT
    $scope.message = error
  
  # Logout completed
  $scope.$on 'event:auth-logout-complete', ->
    Loading.stop()



  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Debug
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ### 

  $scope.devChanges = ->
    if($scope.dev.testserver)
      Network.switchToTest()
    $scope.$watch('dev.testserver', (newVersion, oldVersion) ->
      if newVersion
        Network.switchToTest()
      else
        Network.switchToLive()
    )



  ### -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  # Init
  # -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/ ###

  $scope.init = ->
    $scope.dev = {
      'active' : false,
      'oldoverlay' : false,
      'testserver' : false
    }
    if $scope.dev.active
      $scope.devChanges()


    LoginModal.init()
    $scope.upload = {saveToPhotoAlbum : true, selection : false}
    $scope.login = {noConnection : false}
    $scope.loginFrame = {loading : true}
    
    if !LocalStorage.isSet('privacySetting')
      LocalStorage.set('privacySetting', 0)
    if !LocalStorage.isSet('rightsSetting')
      LocalStorage.set('rightsSetting', 0)
    if !LocalStorage.isSet('ccSetting')
      LocalStorage.set('ccSetting', 0)

    $scope.overlay = {
      dim: 0,
      gallery: {
        top: 0,
        left: 0
      }
      camera: {
        top: 0,
        left: 0
      }
    }

    $scope.tabs = {
      'hidden' : false
      'partly' : false
    }

    angular.element(window).bind('resize', ->
      if $scope.upload.selection
        $scope.setOverlayButtons()
    ) 

  ionic.Platform.ready( -> 
    $translate([
               'NO_CONNECTION_HEADING'
               'NO_CONNECTION_CONTENT'
               'LOGIN_REQUIRED'
               'LOGIN_REQUIRED_CONTENT'
               'LOGIN_INCORRECT'
               'LOGIN_FAILED'
               'LOGIN_FAILED_CONTENT'
               'NO_CONNECTION'
               'UPLOAD_SUCCESS_HEADING'
               'UPLOAD_SUCCESS_CONTENT'
               'UPLOAD_FAILURE_HEADING'
               'UPLOAD_FAILURE_CONTENT'
               'UPLOAD_IN_PROGRESS_HEADING'
               'UPLOAD_IN_PROGRESS_CONTENT'
               'CAMERA_DIALOG_HEADING'
               'CAMERA_DIALOG_CONTENT'
               'UPDATE'
               ])
    .then((translations) -> 
      $scope.tabTranslations = translations

      #if(!$scope.isAndroid())
        #UpdateTimer.start($scope.tabTranslations.UPDATE)
    )

    $rootScope.$on('$stateChangeStart', (event, toState, toParams, fromState, fromParams) ->
        $scope.showTabs()
    )
  )

  $scope.init()

  $scope.message = ""

)