angular.module("DocCheckPictures.services").factory "Login", ($rootScope, $http, $ionicPopup, authService, LocalStorage, Loading, Settings)->

  actionCallback = undefined
  loginFailed = false
  requiredFor = ''

  # ASK

  url             = 'https://login.doccheck.com/'
  tokenDomain     = 'service/oauth/access_token/'

  loginId         = '2000000007624' # formerly 2000000006987, but replaced for JSON response login
  clientSecret    = 'xyz'
  strDcLanguage   = Settings.getLanguage(true)
  grantType       = 'authorization_code'
  intialized      = false


  logout:  ->
    LocalStorage.unset('accessToken')
    delete $http.defaults.headers.common.Authorization
    if window.AppGroupsUserDefaults
      options = {
        key: "accessToken",
        value: '',
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
      options = {
        key: "loginTime",
        value: '',
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
      options = {
        key: "validityDuration",
        value: '',
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
    
    $rootScope.$broadcast('event:auth-logout-complete')

  loginCancelled: -> 
    authService.loginCancelled();

  isAuthenticated: ->
    if $http.defaults.headers.common.Authorization != undefined && $http.defaults.headers.common.Authorization != ""
      gap = (new Date().getTime()) - parseInt(LocalStorage.get('loginTime'))
      if LocalStorage.isSet('loginTime') && gap <= parseInt(LocalStorage.get('validityDuration'))
        return true
    return false
            

  loginFailed: (failed = true) ->
    lastLoginAttemptFailed = failed

  didLastLoginFail: ->
    return lastLoginAttemptFailed

  # Action Callback
  setActionCallback: (callback) ->
    actionCallback = callback

  getActionCallback: ->
    return actionCallback

  executeActionCallback: ->
    if actionCallback
      actionCallback()
      actionCallback = undefined

  cancelActionCallback: ->
    actionCallback = undefined

  # Token handling
  setToken: (token, expiresIn) ->
    loginFailed = false
    prefixedToken = "Bearer " + token
    loginTime = new Date().getTime()
    expiresInMillis = parseInt(expiresIn) * 1000

    LocalStorage.set('accessToken', prefixedToken)
    LocalStorage.set('loginTime', loginTime)
    LocalStorage.set('validityDuration', expiresInMillis)
    $http.defaults.headers.common.Authorization = prefixedToken

    if window.AppGroupsUserDefaults
      options = {
        key: "accessToken",
        value: prefixedToken,
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
      options = {
        key: "loginTime",
        value: loginTime,
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
      options = {
        key: "validityDuration",
        value: expiresInMillis,
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
    
    authService.loginConfirmed()

  didTokenTimeout: ->
    if (!LocalStorage.isSet('loginTime') || (new Date().getTime()) - LocalStorage.get('loginTime')) > LocalStorage.get('validityDuration')
      unsetToken()
      return true
    return false

  unsetToken: ->
    LocalStorage.unset('accessToken')
    if window.AppGroupsUserDefaults
      options = {
        key: "accessToken",
        value: '',
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
      options = {
        key: "loginTime",
        value: '',
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
      options = {
        key: "validityDuration",
        value: '',
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)

  getToken: ->
    return LocalStorage.get('accessToken')

  didLoginFail: ->
    return loginFailed

  setLoginFailed: (fail) ->
    loginFailed = fail

  setRequiredFor: (rfor) ->
    requiredFor = rfor

  getRequiredFor: ->
    rf = requiredFor
    requiredFor = ''
    return rf

  ###
  # Ask Service Integration
  ###

  ###
  # Login
  ###

  ###
  # Collect token
  ###



  init : ->
    if !@initialized 
      console.log 'Initializing Login'

      $http.defaults.headers.post['Content-Type'] = false
      $http.defaults.headers.post['Allow-Control-Allow-Origin'] = '*'
      $http.defaults.headers.common['Accept'] = 'application/json'

      console.log '#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#'
      
      if LocalStorage.isSet('dc_ask_access_token')
        $http.defaults.headers.common['Authorization'] = LocalStorage.get('dc_ask_access_token')
        console.log '# Restored oAuth token from local storage'

      console.log '# Current authorization setting: '
      console.log '# ' + $http.defaults.headers.common.Authorization
      console.log '#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#'

  collectToken : (code) ->
    return $http({
      url: url + tokenDomain
      method: "POST"
      cache: false
      params: 
        client_id : loginId
        client_secret : clientSecret
        grant_type : grantType
        code : code
    })

  saveToken : (token) ->
    loginFailed = false

    loginTime = new Date().getTime()
    expiresIn = 1000 * 60 * 60 * 24* 31 * 6

    LocalStorage.set('accessToken', token)
    LocalStorage.set('loginTime', loginTime)
    LocalStorage.set('validityDuration', expiresIn)

    $http.defaults.headers.common.Authorization = token

    if window.AppGroupsUserDefaults
      options = {
        key: "accessToken",
        value: token,
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
      options = {
        key: "loginTime",
        value: loginTime,
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
      options = {
        key: "validityDuration",
        value: expiresIn,
        suite: "group.dcpictures"
      }
      window.AppGroupsUserDefaults.save(options, undefined, undefined)
    
    authService.loginConfirmed()

  errorFunction : ->
    Loading.stop()

    @unsetToken()
    delete $http.defaults.headers.common.Authorization

  sendLoginRequest : (username, password, successCallback, errorCallback) ->
    Loading.start()

    self = @

    $http({
      url: url 
      method: "POST"
      cache: false
      params: {
        login_id      : loginId
        strDcLanguage : strDcLanguage
        username      : username
        password      : password
      }
    }).success((data, status, headers, config) ->

      if data.boolSuccess

        self.collectToken(data.arrUrlParams.code).success((data, status, headers, config) ->

          token = data.token_type + " " + data.access_token

          console.log '#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#'
          console.log '# New access token: '
          console.log '# ' + token
          console.log '#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#'

          self.saveToken(token)

          Loading.stop()
          successCallback?(data, status, headers, config)

        ).error((data, status, headers, config) ->

          self.errorFunction()

          errorCallback?(data, status, headers, config)
          authService.loginCancelled()
        )

      else

        self.errorFunction()

        errorCallback?(data, status, headers, config)
        authService.loginCancelled()

    ).error((data, status, headers, config) ->

      self.errorFunction()

      errorCallback?(data, status, headers, config)
      authService.loginCancelled()

    )  
