'use strict'
# Ionic Starter App

# angular.module is a global place for creating, registering and retrieving Angular modules
# 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
# the 2nd parameter is an array of 'requires'
# 'starter.services' is found in services.js
# 'starter.controllers' is found in controllers.js

# Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
# for form inputs)

# org.apache.cordova.statusbar required
angular.module("DocCheckPictures", ["ionic",
                                    'ui.router',
                                    "DocCheckPictures.controllers", 
                                    "DocCheckPictures.services",
                                    "DocCheckPictures.directives", 
                                    "DocCheckPictures.translations",
                                    "base64",
                                    "http-auth-interceptor",
                                    "http-auth-interceptor-buffer",
                                    ])
.run(($ionicPlatform, $cacheFactory, $http, $translate, LocalStorage, $ionicPopup, Login, Settings) ->
  $ionicPlatform.ready ->
    
    Login.init()

    if !LocalStorage.isSet('language')
      availableLangs = Settings.getAvailableLanguages()
      if navigator.language
        
        if(navigator.language.indexOf('-') > 0 || navigator.language.indexOf('_') > 0)
          language = navigator.language.replace('-', '_')
          langPre  = language.substring(0, language.indexOf('_'))
          if (langPre in availableLangs)
            langPost = language.substring(language.indexOf('_')).toUpperCase()
            language = langPre + langPost
          else
            language = 'en_EN'
        else
          if (navigator.language in availableLangs)
            language = navigator.language + "_" + navigator.language.toUpperCase()
          else
            language = 'en_EN'

        if language.indexOf('GB') >= 0
          language = language.replace('GB', 'EN')
        else if language.indexOf('gb') >= 0
          language = language.replace('gb', 'en')

        if language.indexOf('US') >= 0
          language = language.replace('US', 'EN')
        else if language.indexOf('us') >= 0
          language = language.replace('us', 'en')

      else         
        language = 'en_EN'

      console.log(language)
      $translate.use(language)
    else
      language = LocalStorage.get('language')
      $translate.use(LocalStorage.get('language')+'_'+LocalStorage.get('language').toUpperCase())

    ionic.DomUtil.ready(->
      Settings.setLanguage(language)  
    )

    if StatusBar != undefined
      StatusBar.hide()

    if cordova != undefined && cordova.plugins.Keyboard
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar()
      ionic.Platform.isFullScreen = true
      #cordova.plugins.Keyboard.disableScroll(true)
    if navigator.splashscreen
      navigator.splashscreen.hide()

    $cacheFactory("PictureCache", {
      capacity: 100,
      cacheFlushInterval: 1,
      maxAge: 60000, # 1 minute
      deleteOnExpire: 'aggressive',
      recycleFreq: 1000, # check each second
      disabled: true
    })

    $cacheFactory("PictureDetailCache", {
      capacity: 100,
      maxAge: 3600000,
      cacheFlushInterval: 60000,      
      storageMode: 'localStorage'
    })

    $http.defaults.cache = $cacheFactory.get('PictureCache')
    $http.defaults.headers.post['Content-Type'] = false
    $http.defaults.headers.post['Allow-Control-Allow-Origin'] = '*'
    $http.defaults.headers.common['Accept'] = 'application/json'
    if(LocalStorage.isSet('accessToken'))
      $http.defaults.headers.common.Authorization = LocalStorage.get('accessToken')
          
)
.config ($stateProvider, $urlRouterProvider) ->
    $stateProvider.state("app", {
      url: "/app"
      abstract: true
      templateUrl: "templates/tab-view.html"
      controller:"TabCtrl"
      # =~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
      # HOME
      # =~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
    }).state("app.home", {
      url: "/home"
      abstract: true
      views:
        "home":
          template: "<ion-nav-view></ion-nav-view>"
    }).state("app.home.search", {
      url: "/search"
      templateUrl: "templates/picture-home-view.html"
      controller: "PictureHomeCtrl"
    }).state("app.home.detail", {
      url: "/detail"
      templateUrl: "templates/picture-detail-view.html"
      controller: "PictureDetailCtrl"
    }).state("app.home.info", {
      url: "/info/:pictureId"
      templateUrl: "templates/picture-detail-info-view.html"
      controller: "PictureDetailInfoCtrl"
    }).state("app.home.edit", {
      url: "/edit"
      templateUrl: "templates/picture-edit-view.html"
      controller: "PictureEditCtrl"
      # =~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
      # SEARCH
      # =~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
    }).state("app.picture", {
      url: "/picture"
      abstract: true
      views:
        "picture":
          template: "<ion-nav-view></ion-nav-view>"
      }).state("app.picture.search", {
        url: "/search"
        templateUrl: "templates/picture-search-view.html"
        controller: "PictureSearchCtrl"
      }).state("app.picture.detail", {
        url: "/detail"
        templateUrl: "templates/picture-detail-view.html"
        controller: "PictureDetailCtrl"
      }).state("app.picture.info", {
        url: "/info/:pictureId"
        templateUrl: "templates/picture-detail-info-view.html"
        controller: "PictureDetailInfoCtrl"
      }).state("app.picture.edit", {
        url: "/edit"
        templateUrl: "templates/picture-edit-view.html"
        controller: "PictureEditCtrl"
      # =~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
      # USER PICS
      # =~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
    }).state("app.picturemy", {
      url: "/picturemy"
      abstract: true
      views:
        "picturemy":
          template: "<ion-nav-view></ion-nav-view>"
      }).state("app.picturemy.searchmy", {
        url: "/searchmy?from"
        templateUrl: "templates/picture-searchmy-view.html"
        controller: "PictureSearchMyCtrl"
      }).state("app.picturemy.detailmy", {
        url: "/detailmy"
        templateUrl: "templates/picture-detail-view.html"
        controller: "PictureDetailCtrl"
      }).state("app.picturemy.info", {
        url: "/infomy/:pictureId"
        templateUrl: "templates/picture-detail-info-view.html"
        controller: "PictureDetailInfoCtrl"
      }).state("app.picturemy.editmy", {
        url: "/editmy"
        templateUrl: "templates/picture-edit-view.html"
        controller: "PictureEditCtrl"
      # =~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
      # SETTINGS
      # =~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~=~
    }).state("app.settings", {
      url: "/settings"
      abstract: true
      views:
        "settings":
          template: "<ion-nav-view></ion-nav-view>"
      }).state("app.settings.main", {
        url: "/main"
        templateUrl: "templates/settings-view.html"
        controller: "SettingsCtrl"
      }).state("app.settings.help", {
        url: "/help"
        templateUrl: "templates/help-view.html"
        controller: "SubSettingsCtrl"
      }).state("app.settings.feedback", {
        url: "/feedback"
        templateUrl: "templates/feedback-view.html"
        controller: "SubSettingsCtrl"
      }).state("app.settings.privacy", {
        url: "/privacy"
        templateUrl: "templates/privacy-view.html"
        controller: "PrivacyCtrl"
        controllerAs: "privacy"
      }).state("app.settings.promotion", {
        url: "/promotion"
        templateUrl: "templates/promotion-view.html"
        controller: "PromotionCtrl"
      }).state("app.settings.disclaimer", {
        url: "/disclaimer"
        templateUrl: "templates/disclaimer-view.html"
        controller: "SubSettingsCtrl"
      })
    .state("nothing", {
      url:"/nothing"
      template:"nothing.html"
    })

    $urlRouterProvider.otherwise('/app/home/search')

