'use strict';
var indexOf = [].indexOf || function(item) { for (var i = 0, l = this.length; i < l; i++) { if (i in this && this[i] === item) return i; } return -1; };

angular.module("DocCheckPictures", ["ionic", 'ui.router', "DocCheckPictures.controllers", "DocCheckPictures.services", "DocCheckPictures.directives", "DocCheckPictures.translations", "base64", "http-auth-interceptor", "http-auth-interceptor-buffer"]).run(function($ionicPlatform, $cacheFactory, $http, $translate, LocalStorage, $ionicPopup, Login, Settings) {
  return $ionicPlatform.ready(function() {
    var availableLangs, langPost, langPre, language, ref;
    Login.init();
    if (!LocalStorage.isSet('language')) {
      availableLangs = Settings.getAvailableLanguages();
      if (navigator.language) {
        if (navigator.language.indexOf('-') > 0 || navigator.language.indexOf('_') > 0) {
          language = navigator.language.replace('-', '_');
          langPre = language.substring(0, language.indexOf('_'));
          if ((indexOf.call(availableLangs, langPre) >= 0)) {
            langPost = language.substring(language.indexOf('_')).toUpperCase();
            language = langPre + langPost;
          } else {
            language = 'en_EN';
          }
        } else {
          if ((ref = navigator.language, indexOf.call(availableLangs, ref) >= 0)) {
            language = navigator.language + "_" + navigator.language.toUpperCase();
          } else {
            language = 'en_EN';
          }
        }
        if (language.indexOf('GB') >= 0) {
          language = language.replace('GB', 'EN');
        } else if (language.indexOf('gb') >= 0) {
          language = language.replace('gb', 'en');
        }
        if (language.indexOf('US') >= 0) {
          language = language.replace('US', 'EN');
        } else if (language.indexOf('us') >= 0) {
          language = language.replace('us', 'en');
        }
      } else {
        language = 'en_EN';
      }
      console.log(language);
      $translate.use(language);
    } else {
      language = LocalStorage.get('language');
      $translate.use(LocalStorage.get('language') + '_' + LocalStorage.get('language').toUpperCase());
    }
    ionic.DomUtil.ready(function() {
      return Settings.setLanguage(language);
    });
    if (StatusBar !== void 0) {
      StatusBar.hide();
    }
    if (cordova !== void 0 && cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar();
      ionic.Platform.isFullScreen = true;
    }
    if (navigator.splashscreen) {
      navigator.splashscreen.hide();
    }
    $cacheFactory("PictureCache", {
      capacity: 100,
      cacheFlushInterval: 1,
      maxAge: 60000,
      deleteOnExpire: 'aggressive',
      recycleFreq: 1000,
      disabled: true
    });
    $cacheFactory("PictureDetailCache", {
      capacity: 100,
      maxAge: 3600000,
      cacheFlushInterval: 60000,
      storageMode: 'localStorage'
    });
    $http.defaults.cache = $cacheFactory.get('PictureCache');
    $http.defaults.headers.post['Content-Type'] = false;
    $http.defaults.headers.post['Allow-Control-Allow-Origin'] = '*';
    $http.defaults.headers.common['Accept'] = 'application/json';
    if (LocalStorage.isSet('accessToken')) {
      return $http.defaults.headers.common.Authorization = LocalStorage.get('accessToken');
    }
  });
}).config(function($stateProvider, $urlRouterProvider) {
  $stateProvider.state("app", {
    url: "/app",
    abstract: true,
    templateUrl: "templates/tab-view.html",
    controller: "TabCtrl"
  }).state("app.home", {
    url: "/home",
    abstract: true,
    views: {
      "home": {
        template: "<ion-nav-view></ion-nav-view>"
      }
    }
  }).state("app.home.search", {
    url: "/search",
    templateUrl: "templates/picture-home-view.html",
    controller: "PictureHomeCtrl"
  }).state("app.home.detail", {
    url: "/detail",
    templateUrl: "templates/picture-detail-view.html",
    controller: "PictureDetailCtrl"
  }).state("app.home.info", {
    url: "/info/:pictureId",
    templateUrl: "templates/picture-detail-info-view.html",
    controller: "PictureDetailInfoCtrl"
  }).state("app.home.edit", {
    url: "/edit",
    templateUrl: "templates/picture-edit-view.html",
    controller: "PictureEditCtrl"
  }).state("app.picture", {
    url: "/picture",
    abstract: true,
    views: {
      "picture": {
        template: "<ion-nav-view></ion-nav-view>"
      }
    }
  }).state("app.picture.search", {
    url: "/search",
    templateUrl: "templates/picture-search-view.html",
    controller: "PictureSearchCtrl"
  }).state("app.picture.detail", {
    url: "/detail",
    templateUrl: "templates/picture-detail-view.html",
    controller: "PictureDetailCtrl"
  }).state("app.picture.info", {
    url: "/info/:pictureId",
    templateUrl: "templates/picture-detail-info-view.html",
    controller: "PictureDetailInfoCtrl"
  }).state("app.picture.edit", {
    url: "/edit",
    templateUrl: "templates/picture-edit-view.html",
    controller: "PictureEditCtrl"
  }).state("app.picturemy", {
    url: "/picturemy",
    abstract: true,
    views: {
      "picturemy": {
        template: "<ion-nav-view></ion-nav-view>"
      }
    }
  }).state("app.picturemy.searchmy", {
    url: "/searchmy?from",
    templateUrl: "templates/picture-searchmy-view.html",
    controller: "PictureSearchMyCtrl"
  }).state("app.picturemy.detailmy", {
    url: "/detailmy",
    templateUrl: "templates/picture-detail-view.html",
    controller: "PictureDetailCtrl"
  }).state("app.picturemy.info", {
    url: "/infomy/:pictureId",
    templateUrl: "templates/picture-detail-info-view.html",
    controller: "PictureDetailInfoCtrl"
  }).state("app.picturemy.editmy", {
    url: "/editmy",
    templateUrl: "templates/picture-edit-view.html",
    controller: "PictureEditCtrl"
  }).state("app.settings", {
    url: "/settings",
    abstract: true,
    views: {
      "settings": {
        template: "<ion-nav-view></ion-nav-view>"
      }
    }
  }).state("app.settings.main", {
    url: "/main",
    templateUrl: "templates/settings-view.html",
    controller: "SettingsCtrl"
  }).state("app.settings.help", {
    url: "/help",
    templateUrl: "templates/help-view.html",
    controller: "SubSettingsCtrl"
  }).state("app.settings.feedback", {
    url: "/feedback",
    templateUrl: "templates/feedback-view.html",
    controller: "SubSettingsCtrl"
  }).state("app.settings.privacy", {
    url: "/privacy",
    templateUrl: "templates/privacy-view.html",
    controller: "PrivacyCtrl",
    controllerAs: "privacy"
  }).state("app.settings.promotion", {
    url: "/promotion",
    templateUrl: "templates/promotion-view.html",
    controller: "PromotionCtrl"
  }).state("app.settings.disclaimer", {
    url: "/disclaimer",
    templateUrl: "templates/disclaimer-view.html",
    controller: "SubSettingsCtrl"
  }).state("nothing", {
    url: "/nothing",
    template: "nothing.html"
  });
  return $urlRouterProvider.otherwise('/app/home/search');
});

angular.module('DocCheckPictures.controllers', []);

angular.module('DocCheckPictures.directives', []);

angular.module("DocCheckPictures.services", []);

angular.module("DocCheckPictures.translations", ['pascalprecht.translate']);

angular.module("DocCheckPictures.controllers").controller('FeedbackCtrl', function() {});

angular.module("DocCheckPictures.controllers").controller('HelpCtrl', function() {});


/*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureDetailCtrl               #
 *   -> picture-detail-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
 */
angular.module("DocCheckPictures.controllers").controller('PictureDetailCtrl', function($scope, $state, $ionicSlideBoxDelegate, $ionicGesture, $translate, $ionicPopup, $ionicViewService, $ionicScrollDelegate, $cacheFactory, Popup, Loading, Pictures, UserPictures, Search) {

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Service-link functions & state transitions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.toEdit = function() {
    if ($scope.currentItem.title.length > 0) {
      Pictures.setCurrentIndex($scope.currentIndex, "my");
      Pictures.setCurrentPicture($scope.currentItem);
      return $state.go('app.picturemy.editmy');
    }
  };
  $scope.toInfo = function() {
    var location, state;
    if ($scope.currentItem.title.length > 0) {
      if ($state.current.name.indexOf('home') > 0) {
        location = 'home';
      } else if ($state.current.name.indexOf('picturemy') > 0) {
        location = 'my';
      } else if ($state.current.name.indexOf('picture') > 0) {
        location = 'search';
      }
      Pictures.setCurrentIndex($scope.currentIndex, location);
      Pictures.setItems($scope.details.items, $scope.currentItem.id);
      state = $state.current.name.substring(0, $state.current.name.lastIndexOf('.'));
      return $state.go(state + '.info', {
        'pictureId': $scope.currentItem.id
      });
    }
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Scope functions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.loadItemInfoFor = function(index) {
    $scope.currentItem.title = '';
    $scope.currentIndex = index % $scope.details.items.length;
    Loading.start();
    return Search.getPictureDetailByQuery($scope.details.items[index].id, $cacheFactory.get('PictureDetailCache')).success(function(response) {
      $scope.currentItem = response;
      $scope.overlay.show = true;
      return Loading.stop();
    }).error(function(error) {
      Loading.stop();
      return $scope.currentItem.title = '';
    });
  };
  $scope.dc = {
    deletePopup: function() {
      $scope.hideTabs();
      return $scope.dc.confirmPopup = true;
    },
    deletePositive: function(result) {
      $scope.dc.confirmPopup = false;
      $scope.showTabs();
      return $scope.deletePicture();
    },
    deleteNegative: function(result) {
      $scope.dc.confirmPopup = false;
      $scope.showTabs();
      return console.log("negative");
    },
    confirmPopup: false
  };
  $scope.deletePicture = function(id) {
    if (id == null) {
      id = $scope.currentItem.id;
    }
    Loading.start();
    return UserPictures["delete"](id).success(function(response) {
      return $scope.deleteSuccess(response);
    }).error(function(error) {
      return $scope.deleteError(error);
    });

    /*
    confirmPopup = $ionicPopup.confirm({
      title: $scope.translations.DETAIL_DELETE_CHECK_HEADING
      template: $scope.translations.DETAIL_DELETE_CHECK_CONTENT
      buttons: [
        { 
          text: '' #$scope.translations.YES
          type: 'dc-confirm-button'
          onTap: ->
            if !Loading.inProgress()
              Loading.start()
              UserPictures.delete(id)
              .success((response) -> $scope.deleteSuccess(response))
              .error((error) -> $scope.deleteError(error))            
        },
        { 
          text: '' 
          type: 'dc-cancel-button'
        } #$scope.translations.NO }
      ]
    })
     */
  };
  $scope.deleteSuccess = function(response) {
    $scope.details.items.splice($scope.currentIndex, 1);
    Loading.stop();
    return $ionicViewService.getBackView().go();
  };
  $scope.deleteError = function(error) {
    if ($scope.currentItem.title.length > 0) {
      Loading.stop();
      return Popup.show($scope.translations.DETAIL_DELETE_FAILURE_HEADING, $scope.translations.DETAIL_DELETE_FAILURE_CONTENT);
    }
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * UI
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.calculateButtonWidth = function() {
    return $scope.buttons.width = (window.innerWidth - 91) / 4;
  };
  $scope.isSlideHidden = function($index) {
    var len;
    len = $scope.details.items.length;
    if (($index + len - $scope.currentIndex) % len > 1 && ($scope.currentIndex + len - $index) % len > 1) {
      return true;
    }
    return false;
  };
  $scope.showOverlay = function(show) {
    return $scope.overlay.show = show && !Loading.inProgress();
  };
  $scope.toggleOverlay = function() {
    return $scope.overlay.show = !$scope.overlay.show && !Loading.inProgress();
  };
  $scope.checkZoomLevel = function() {
    if ($ionicScrollDelegate.getScrollView().__zoomLevel <= 1) {
      return $ionicSlideBoxDelegate.enableSlide(true);
    } else {
      return $ionicSlideBoxDelegate.enableSlide(false);
    }
  };
  $scope.triggerZoom = function(e) {
    var pos;
    pos = e.gesture.srcEvent.changedTouches[0];
    if ($ionicScrollDelegate.getScrollView().__zoomLevel > 3.0) {
      return $ionicScrollDelegate.zoomTo(1.0, true, pos.clientX, pos.clientY);
    } else {
      return $ionicScrollDelegate.zoomBy(3.0, true, pos.clientX, pos.clientY);
    }
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Init
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.init = function() {
    var element, linkedItem, location;
    $scope.loaded = false;
    $scope.overlay = {
      'show': true
    };
    linkedItem = Pictures.getLinkedPicture();
    if (linkedItem.id) {
      $scope.details = {
        items: [linkedItem],
        'editable': false
      };
      $scope.currentIndex = 0;
    } else {
      if ($state.current.name.indexOf('home') > 0) {
        location = 'home';
      } else if ($state.current.name.indexOf('picturemy') > 0) {
        location = 'my';
      } else if ($state.current.name.indexOf('picture') > 0) {
        location = 'search';
      }
      $scope.details = {
        items: Pictures.getItems(location),
        'editable': location === 'my'
      };
      $scope.currentIndex = Pictures.getCurrentIndex(location) || 0;
    }
    $scope.currentItem = {
      'title': ''
    };
    element = angular.element(document.querySelector('#pictureScroll'));
    $ionicGesture.on('doubletap', $scope.triggerZoom, element);

    /*
     * Due to the fact that the Ionic slide box is currently not capable of building up dynamically and 
     * slide to a given index afterwards, timeouts need to be used at the moment.
     * TODO: Keep an eye on updates.
     */
    setTimeout(function() {
      $scope.loadItemInfoFor($scope.currentIndex);
      return setTimeout(function() {
        $scope.loaded = true;
        return $ionicSlideBoxDelegate.update();
      }, 150);
    }, 100);
    $scope.buttons = {
      'width': 0
    };
    $scope.calculateButtonWidth();
    angular.element(window).bind('resize', function() {
      return $scope.calculateButtonWidth();
    });
    return $translate(['DETAIL_DELETE_CHECK_HEADING', 'DETAIL_DELETE_CHECK_CONTENT', 'DETAIL_DELETE_SUCCESS_HEADING', 'DETAIL_DELETE_SUCCESS_CONTENT', 'DETAIL_DELETE_FAILURE_HEADING', 'DETAIL_DELETE_FAILURE_CONTENT', 'DETAIL_PICINFO_FAILURE_CONTENT', 'CONNECTION_ERROR', 'YES', 'NO']).then(function(translations) {
      return $scope.translations = translations;
    });
  };
  return $scope.init();
});


/*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureDetailCtrl               #
 *   -> picture-detail-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
 */
angular.module("DocCheckPictures.controllers").controller('PictureDetailInfoCtrl', function($scope, $state, $stateParams, $ionicViewService, $cacheFactory, $translate, Loading, Pictures, Search, UserPictures) {

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Service-link functions & state transitions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.toEdit = function() {
    if ($scope.currentItem.title.length > 0) {
      Pictures.setCurrentIndex($scope.currentIndex, "my");
      Pictures.setCurrentPicture($scope.currentItem);
      return $state.go('app.picturemy.editmy');
    }
  };
  $scope.searchFor = function(tag) {
    Search.setLastSearchPattern(tag);
    return $state.go('app.picture.search');
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Scope functions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.dc = {
    deletePopup: function() {
      $scope.hideTabs();
      return $scope.dc.confirmPopup = true;
    },
    deletePositive: function(result) {
      $scope.dc.confirmPopup = false;
      $scope.showTabs();
      return $scope.deletePicture();
    },
    deleteNegative: function(result) {
      $scope.dc.confirmPopup = false;
      $scope.showTabs();
      return console.log("negative");
    },
    confirmPopup: false
  };
  $scope.setRating = function($index) {
    if ($scope.rating === $index) {
      return $scope.rating = $scope.rating - 1;
    } else {
      return $scope.rating = $index;
    }
  };
  $scope.getNumber = function(num) {
    return new Array(num);
  };
  $scope.loadItemInfo = function(pId) {
    Loading.start();
    return Search.getPictureDetailByQuery(pId, $cacheFactory.get('PictureDetailCache')).success(function(response) {
      var i, isIn, j, tags;
      console.log(response);
      $scope.currentItem = response;
      tags = $scope.currentItem.tags;
      $scope.currentItem.tags = [];
      i = 0;
      while (i < tags.length) {
        j = 0;
        isIn = false;
        while (j < $scope.currentItem.tags.length) {
          if (tags[i] === $scope.currentItem.tags[j]) {
            isIn = true;
          }
          j++;
        }
        if (!isIn) {
          $scope.currentItem.tags.push(tags[i]);
        }
        i++;
      }
      Loading.stop();
      if (!$scope.$$phase) {
        return $scope.$apply();
      }
    }).error(function(error) {
      $scope.currentItem.title = $scope.translations.CONNECTION_ERROR;
      return Loading.stop();
    });
  };

  /*
   * Editing
   */
  $scope.deletePicture = function(id) {
    if (id == null) {
      id = $scope.currentItem.id;
    }
    Loading.start();
    return UserPictures["delete"](id).success(function(response) {
      return $scope.deleteSuccess(response);
    }).error(function(error) {
      return $scope.deleteError(error);
    });
  };
  $scope.deleteSuccess = function(response) {
    Loading.stop();
    $ionicViewService.nextViewOptions({
      disableBack: true
    });
    return $state.go('app.picturemy.searchmy');
  };
  $scope.deleteError = function(error) {
    if ($scope.currentItem.title.length > 0) {
      Loading.stop();
      return Popup.show($scope.translations.DETAIL_DELETE_FAILURE_HEADING, $scope.translations.DETAIL_DELETE_FAILURE_CONTENT);
    }
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * UI
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.isFilled = function($index) {
    if ($index <= $scope.currentItem.rating_value) {
      return "filled ion-ios7-star";
    }
    return "notfilled ion-ios7-star-outline";
  };
  $scope.calculateButtonWidth = function() {
    return $scope.buttons.width = (window.innerWidth - 91) / 4;
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Init
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /*
   * Basic Utility
   */
  $scope.init = function() {
    $scope.buttons = {
      'width': 0
    };
    $scope.calculateButtonWidth();
    $scope.loadItemInfo($stateParams.pictureId);
    $scope.formatted = {
      'tags': ''
    };
    $scope.info = {
      'editable': $state.current.name.indexOf('my') >= 0
    };
    document.onclick = function(e) {
      var element, href, i, id;
      if (e.target.href !== void 0 || e.srcElement.href !== void 0) {
        e = e || window.event;
        element = e.target || e.srcElement;
        if (element.href.indexOf('pictures.doccheck.com') >= 0 || element.href.indexOf('../') === 0 || element.href.indexOf('file://') >= 0 && element.href.indexOf('/photos/') > 0) {
          e.preventDefault();
          e.stopPropagation();
          href = element.href;
          if (href.lastIndexOf('/') + 1 === href.length) {
            href = href.substring(0, href.length - 1);
          }
          id = href.substring(href.lastIndexOf('/') + 1);
          i = 0;
          while (i < id.length) {
            if (id.charAt(i) < '0' || id.charAt(i) > '9') {
              break;
            }
            i++;
          }
          id = id.substring(0, i);
          return Search.getPictureDetailByQuery(id, $cacheFactory.get('PictureDetailCache')).success(function(response) {
            var state;
            Pictures.setLinkedPicture(response);
            state = $state.current.name.substring(0, $state.current.name.lastIndexOf('.'));
            return $state.go(state + '.detail');
          });
        } else if (element.tagName === 'A' && element.href !== void 0 && element.href !== "" && (element.href.indexOf("http") > -1 || element.href.indexOf("www") > -1) && element.href.indexOf("#/app") === -1) {
          window.open(element.href, "_blank", "location=yes");
          return false;
        }
      }
    };
    return $translate(['CONNECTION_ERROR', 'LOADING']).then(function(translations) {
      $scope.translations = translations;
      if (!$scope.currentItem || !$scope.currentItem.title) {
        return $scope.currentItem = {
          'title': $scope.translations.LOADING
        };
      }
    });
  };
  return $scope.init();
});


/*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureEditCtrl                 #
 *   -> picture-edit-view           ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
 */
angular.module("DocCheckPictures.controllers").controller('PictureEditCtrl', function($scope, $ionicViewService, $translate, $cacheFactory, Popup, Loading, Pictures, UserPictures, Settings) {

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Service-link functions & state transitions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Scope functions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.addTag = function() {
    var i, isIn, newTag;
    isIn = false;
    newTag = $scope.form.tag.trim();
    if (newTag !== "") {
      i = 0;
      while (i < $scope.form.tags.length) {
        if ($scope.form.tags[i] === newTag) {
          isIn = true;
        }
        i++;
      }
      if (!isIn) {
        $scope.form.tags.push(newTag);
      }
      return $scope.form.tag = '';
    }
  };
  $scope.removeTag = function(tag) {
    var i, results;
    i = 0;
    results = [];
    while (i < $scope.form.tags.length) {
      if ($scope.form.tags[i] === tag) {
        $scope.form.tags.splice(i, 1);
      }
      results.push(i++);
    }
    return results;
  };
  $scope.submitEdit = function() {
    var pictureObj;
    if (!Loading.inProgress()) {
      $scope.showTabsPartly();
      pictureObj = {
        'id': $scope.currentPicture.id,
        'title': $scope.form.title,
        'description': $scope.form.desc,
        'visibility': $scope.form.visibility,
        'tags': $scope.form.tags,
        'language': Settings.getLanguage()
      };
      $scope.dot.submitting = true;
      Loading.start();
      UserPictures.update(pictureObj).success(function(response) {
        $scope.showTabs();
        Loading.stop();
        return Popup.show($scope.translations.EDIT_CHANGES_SUCCESS_HEADING, $scope.translations.EDIT_CHANGES_SUCCESS_CONTENT, 2000, function() {
          return $ionicViewService.getBackView().go();
        });
      }).error(function(error) {
        $scope.showTabs();
        Loading.stop();
        $scope.dot.submitting = false;
        return Popup.show($scope.translations.EDIT_CHANGES_FAILURE_HEADING, $scope.translations.EDIT_CHANGES_FAILURE_CONTENT);
      });
      return $cacheFactory.get("PictureDetailCache").removeAll();
    }
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * UI
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Init
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.init = function() {
    $scope.currentPicture = Pictures.getCurrentPicture();
    $scope.hideTabs();
    $scope.form = {
      'title': $scope.currentPicture.title,
      'desc': $scope.currentPicture.description,
      'visibility': $scope.currentPicture.visibility,
      'tags': $scope.currentPicture.tags
    };
    $scope.dot = {
      'submitting': false
    };
    $scope.$on('$destroy', function() {
      return $scope.showTabs();
    });
    return $translate(['EDIT_CHANGES_SUCCESS_HEADING', 'EDIT_CHANGES_SUCCESS_CONTENT', 'EDIT_CHANGES_FAILURE_HEADING', 'EDIT_CHANGES_FAILURE_CONTENT']).then(function(translations) {
      return $scope.translations = translations;
    });
  };
  return $scope.init();
});


/*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureHomeCtrl                 #
 *   -> picture-search-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
 */
angular.module("DocCheckPictures.controllers").controller('PictureHomeCtrl', function($scope, $controller, $ionicScrollDelegate, $ionicSlideBoxDelegate, $interval, $timeout, $state, Loading, Pictures, Search, Network, SlideTimer) {
  $controller('PictureSearchCtrl', {
    $scope: $scope
  });

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Service-link functions & state transitions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.toInfo = function(itemId) {
    var index, state;
    index = $ionicSlideBoxDelegate.$getByHandle("homeSlide").currentIndex();
    if (!itemId) {
      itemId = $scope.items[index].id;
    }
    Pictures.setCurrentIndex(index, "home");
    Pictures.setItems($scope.items, itemId);
    state = $state.current.name.substring(0, $state.current.name.lastIndexOf('.'));
    return $state.go(state + '.info', {
      'pictureId': itemId
    });
  };
  $scope.goToSearch = function() {
    Search.setLastSearchPattern($scope.searchvar.keyword);
    return $state.go("app.picture.search");
  };
  $scope.setItemsInService = function(id) {
    Pictures.setItems($scope.items, id, 'home');
    return Pictures.ownItems(false);
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Scope functions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /*
   * Search - adjusted for home view
   */
  $scope.search = function(searchQuery, page) {
    var append, e;
    if (searchQuery == null) {
      searchQuery = "";
    }
    if (page == null) {
      page = 0;
    }
    $scope.searchvar.connectionError = false;
    append = true;
    if (searchQuery.length > 2 || searchQuery.length === 0) {
      Loading.start();
      if (searchQuery === "search.more") {
        $scope.searchvar.hasMoreData = true;
        $scope.searchvar.noDataAtAll = false;
        $scope.page++;
      } else {
        $scope.clearItems();
        $scope.page = 1;
        $ionicScrollDelegate.scrollTop();
        append = false;
      }
      try {
        return Search.getPicturesByQuery(searchQuery, $scope.page, 20, 1).success(function(response) {
          return $scope.searchSuccess(response, append);
        }).error(function(data, status, headers, config) {
          return $scope.searchFailure(data, status, headers, config);
        });
      } catch (_error) {
        e = _error;
      }
    }
  };
  $scope.searchSuccess = function(response, append) {
    if (response._meta.item_count === 0) {
      $scope.searchvar.hasMoreData = false;
      $scope.searchvar.noDataAtAll = true;
    } else {
      $scope.setSearchResults(response);
      $scope.setItems(append);
      Search.setCache("homeCache", $scope.page, $scope.items, response._meta.item_count);
      $scope.searchvar.noDataAtAll = false;
      if (response._links.next === void 0) {
        $scope.searchvar.hasMoreData = false;
      } else {
        $scope.searchvar.hasMoreData = true;
      }
    }
    $scope.$broadcast('scroll.resize');
    $scope.$broadcast('scroll.infiniteScrollComplete');
    $scope.clearResults();
    $scope.load = true;
    Loading.stop();
  };
  $scope.searchFailure = function(data, status, headers, config) {
    $scope.searchvar.hasMoreData = false;
    $scope.searchvar.connectionError = true;
    $scope.clearResults();
    Loading.stop();
    document.addEventListener("online", function() {
      $scope.search("search.more");
      return document.removeEventListener("online");
    }, false);
    $scope.$broadcast('scroll.infiniteScrollComplete');
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * UI
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.setDimensions = function(update) {
    $scope.pictures.width = window.innerWidth;
    $scope.pictures.height = Math.round(window.innerWidth / 2);
    if (!$scope.$$phase) {
      return $scope.$apply();
    }
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Init
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.init = function() {
    $scope.cache = Search.getCache("homeCache");
    $scope.currentSlide = Pictures.getCurrentIndex("home") || 0;
    $scope.pictures = {
      'width': 0,
      'height': 0
    };
    $scope.searchvar = {
      'hasMoreData': true,
      'noDataAtAll': false,
      'connectionError': false,
      'keyword': ''
    };
    $scope.items = $scope.cache.items || [];
    $scope.page = $scope.cache.page || 0;
    $scope.totalResults = $scope.cache.totalResults || 0;
    if ($scope.items.length === 0) {
      $timeout(function() {
        Search.clearCaches();
        return $scope.search("");
      }, 500);
    }
    $scope.lastResults = [];
    $scope.setDimensions();
    $scope.load = false;
    Loading.start();
    $timeout(function() {
      $scope.load = true;
      Loading.stop();
      if (!$scope.searchvar.connectionError) {
        SlideTimer.start(function() {
          $ionicSlideBoxDelegate.$getByHandle("homeSlide").slide(($ionicSlideBoxDelegate.$getByHandle("homeSlide").currentIndex() + 1) % $ionicSlideBoxDelegate.$getByHandle("homeSlide").slidesCount(), 1000);
          return $ionicSlideBoxDelegate.$getByHandle("homeSlide").enableSlide(false);
        }, 4000);
      }
      return $timeout(function() {
        return $ionicSlideBoxDelegate.$getByHandle("homeSlide").enableSlide(false);
      });
    }, 1500);
    $scope.$on('$destroy', function() {
      return Loading.stop();
    });
    return angular.element(window).bind('resize', function() {
      return $scope.setDimensions(true);
    });
  };
  return $scope.init();
});


/*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureSearchCtrl               #
 *   -> picture-search-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
 */
angular.module("DocCheckPictures.controllers").controller('PictureSearchCtrl', function($scope, $state, $translate, $ionicScrollDelegate, $http, $timeout, Loading, Pictures, Camera, LocalStorage, Login, Search) {

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Service-link functions & state transitions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.setItemsInService = function(id) {
    return Pictures.setItems($scope.items, id, 'search');
  };
  $scope.goHome = function() {
    return $state.go('app.home.search');
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Scope functions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.setItems = function(append) {
    if (append == null) {
      append = false;
    }
    if (!append) {
      $scope.clearItems();
    }
    return $scope.items.push.apply($scope.items, $scope.lastResults);
  };
  $scope.clearItems = function() {
    var results1;
    results1 = [];
    while ($scope.items.length > 0) {
      results1.push($scope.items.pop());
    }
    return results1;
  };
  $scope.setSearchResults = function(response) {
    var i, j, photo, ref;
    if (response && response._items && response._items.pictures_photo.length !== 0) {
      for (i = j = 0, ref = response._items.pictures_photo.length - 1; 0 <= ref ? j <= ref : j >= ref; i = 0 <= ref ? ++j : --j) {
        photo = response._items.pictures_photo[i];
        photo.i = i;
        photo.thumbnails.mq = photo.thumbnails.mq.replace("/photos/", "/images/");
        photo.thumbnails.l = photo.thumbnails.l.replace("/photos/", "/images/");
        $scope.lastResults.push(photo);
      }
    }
    return $scope.totalResults = parseInt(response._meta.item_count, 10);
  };
  $scope.clearResults = function() {
    return $scope.lastResults = [];
  };
  $scope.search = function(searchQuery, page) {
    var append, e;
    if (searchQuery == null) {
      searchQuery = "";
    }
    if (page == null) {
      page = 0;
    }
    console.log("search");
    $scope.searchvar.connectionError = false;
    $scope.searchPattern = searchQuery;
    append = true;
    if (searchQuery.length > 2 || searchQuery.length === 0) {
      if (Loading.inProgress()) {
        return;
      } else {
        Loading.start();
      }
      if (searchQuery === "search.more") {
        $scope.searchvar.hasMoreData = true;
        $scope.searchvar.noDataAtAll = false;
        searchQuery = Search.getLastSearchPattern();
        $scope.page++;
      } else {
        $scope.clearItems();
        $scope.page = 1;
        $ionicScrollDelegate.scrollTop();
        append = false;
        Search.setLastSearchPattern(searchQuery);
      }
      try {
        return Search.getPicturesByQuery(searchQuery, $scope.page, $scope.intPhotosPerPage).success(function(response) {
          return $scope.searchSuccess(response, append);
        }).error(function(data, status, headers, config) {
          return $scope.searchFailure(data, status, headers, config);
        });
      } catch (_error) {
        e = _error;
      }
    }
  };
  $scope.searchSuccess = function(response, append) {
    $timeout.cancel($scope.refreshTimeout);
    document.removeEventListener("online");
    if (response._meta.item_count === 0) {
      $scope.searchvar.hasMoreData = false;
      $scope.searchvar.noDataAtAll = true;
    } else {
      $scope.setSearchResults(response);
      $scope.setItems(append);
      Search.setCache("searchCache", $scope.page, $scope.items, response._meta.item_count);
      $scope.searchvar.noDataAtAll = false;
      if (response._links.next === void 0) {
        $scope.searchvar.hasMoreData = false;
      } else {
        $scope.searchvar.hasMoreData = true;
      }
    }
    $scope.$broadcast('scroll.resize');
    $scope.$broadcast('scroll.infiniteScrollComplete');
    $scope.setInfo(Search.getLastSearchPattern(), response._meta.item_count);
    $scope.clearResults();
    Loading.stop();
  };
  $scope.searchFailure = function(data, status, headers, config) {
    $scope.searchvar.hasMoreData = false;
    $scope.searchvar.connectionError = true;
    $scope.clearResults();
    Loading.stop();
    $scope.page--;
    document.addEventListener("online", function() {
      document.removeEventListener("online");
      return $timeout(function() {
        Loading.stop();
        $scope.search("search.more");
        if (!$scope.$$phase) {
          return $scope.$apply();
        }
      }, 500);
    }, false);
    $scope.refreshTimeout = $timeout(function() {
      return $scope.search("search.more");
    }, 5000);
    $scope.$broadcast('scroll.infiniteScrollComplete');
    $scope.setInfo(Search.getLastSearchPattern(), 0);
  };
  $scope.setDimensions = function(update) {
    var columns, rows;
    columns = Math.floor(window.innerWidth / $scope.pictures.minPictureDim);
    if (columns > $scope.pictures.maxColumns) {
      columns = $scope.pictures.maxColumns;
    }
    $scope.pictures.containerDim = window.innerWidth / columns;
    rows = Math.round(window.innerHeight / $scope.pictures.containerDim);
    $scope.intPhotosPerPage = rows * columns;
    if ($scope.pictures.containerDim > $scope.pictures.maxPictureDim) {
      $scope.pictures.picturesDim = $scope.pictures.maxPictureDim;
    } else {
      $scope.pictures.picturesDim = Math.round($scope.pictures.containerDim - 2);
    }
    return $scope.pictures.picturesMargin = ($scope.pictures.containerDim - $scope.pictures.picturesDim) / 2;
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * UI
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.loseFocus = function($event) {
    var formElement;
    formElement = $event.currentTarget;
    return formElement.children[0].children[0].blur();
  };
  $scope.setInfo = function(keyword, results) {
    if ($scope.searchvar.connectionError && $scope.items.length > 0) {
      return $scope.info = $scope.translations.CONNECTION_ERROR;
    } else if (keyword === '') {
      return $scope.info = $scope.translations.SEARCH_NEWEST_PICTURES;
    } else if ($scope.searchvar.noDataAtAll) {
      return $scope.info = $scope.translations.SEARCH_NO_RESULTS;
    } else if ($scope.items.length > 0) {
      return $scope.info = results + ' ' + $scope.translations.SEARCH_RESULTS_FOR + ' "' + keyword + '"';
    } else {
      return $scope.clearInfo();
    }
  };
  $scope.clearInfo = function() {
    return $scope.info = '';
  };
  $scope.clearSearch = function() {
    return $scope.searchvar.keyword = '';
  };
  $scope.scroll = function() {
    if ($scope.lastScrollPos > $ionicScrollDelegate.getScrollPosition().top) {
      if (!$scope.bar.shown) {
        $scope.bar.shown = true;
        if (!$scope.$$digest) {
          $scope.$apply();
        }
      }
    } else if ($scope.lastScrollPos < $ionicScrollDelegate.getScrollPosition().top) {
      if ($scope.bar.shown) {
        $scope.bar.shown = false;
        if (!$scope.$$digest) {
          $scope.$apply();
        }
      }
    } else if ($ionicScrollDelegate.getScrollPosition().top === 0) {
      if (!$scope.bar.shown) {
        $scope.bar.shown = true;
        if (!$scope.$$digest) {
          $scope.$apply();
        }
      }
    }
    return $scope.lastScrollPos = $ionicScrollDelegate.getScrollPosition().top;
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Event Listeners
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Init
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.init = function() {
    $scope.info = '';
    $scope.cache = Search.getCache("searchCache");
    $scope.intPhotosPerPage = 36;
    $scope.page = $scope.cache.page || 0;
    $scope.totalResults = $scope.cache.totalResults || 0;
    $scope.bar = {
      'shown': true
    };
    $scope.lastResults = [];
    $scope.items = $scope.cache.items || [];
    $scope.searchvar = {
      'hasMoreData': true,
      'noDataAtAll': false,
      'connectionError': false,
      'keyword': $scope.cache.lastSearchPattern || "",
      'lastSearchTerm': ''
    };
    $scope.pictures = {
      'maxColumns': 3,
      'minPictureDim': 150,
      'maxPictureDim': 300,
      'picturesMargin': 0,
      'containerPadding': 0,
      'containerDim': 0,
      'picturesDim': 0
    };
    angular.element(window).bind('resize', function() {
      return $scope.setDimensions(true);
    });
    $scope.setDimensions();
    $scope.$on('pictures.reload', function() {
      $scope.searchvar.keyword = '';
      $scope.search("");
      return $scope.$apply();
    });

    /*
     * Translations
     */
    return $translate(['CONNECTION_ERROR', 'SEARCH_NEWEST_PICTURES', 'SEARCH_NO_RESULTS', 'SEARCH_RESULTS_FOR']).then(function(translations) {
      $scope.translations = translations;
      if ($scope.items.length > 0) {
        return $scope.setInfo($scope.searchvar.keyword, $scope.totalResults);
      }
    });
  };
  return $scope.init();
});


/*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureSearchMyCtrl             #
 *   -> picture-search-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
 */
angular.module("DocCheckPictures.controllers").controller('PictureSearchMyCtrl', function($scope, $rootScope, $controller, $translate, $ionicViewService, $ionicScrollDelegate, $stateParams, Popup, Loading, Pictures, Login, Search, Network) {

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Inheritance
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $controller('PictureSearchCtrl', {
    $scope: $scope
  });

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Service-link functions & state transitions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.setItemsInService = function(id) {
    Pictures.setItems($scope.items, id, 'my');
    return Pictures.ownItems(true);
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Scope functions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.search = function(searchQuery, page) {
    var append, e;
    if (searchQuery == null) {
      searchQuery = "";
    }
    if (page == null) {
      page = 0;
    }
    if ($scope.dot.loggedIn) {
      $scope.searchvar.connectionError = false;
      append = true;
      if (Loading.inProgress()) {
        return;
      } else {
        Loading.start();
      }
      if (searchQuery === "search.more") {
        $scope.searchvar.hasMoreData = true;
        $scope.searchvar.noDataAtAll = false;
        searchQuery = "";
        $scope.page++;
      } else {
        $scope.clearItems();
        $scope.page = 1;
        $ionicScrollDelegate.scrollTop();
        append = false;
      }
      try {
        return Search.getUserPictures($scope.page, $scope.intPhotosPerPage).success(function(response) {
          return $scope.searchSuccess(response);
        }).error(function(error) {
          return $scope.searchError(error);
        });
      } catch (_error) {
        e = _error;
      }
    }
  };
  $scope.searchSuccess = function(response) {
    if (response._meta.item_count === 0) {
      $scope.searchvar.hasMoreData = false;
      $scope.searchvar.noDataAtAll = true;
    } else {
      $scope.setSearchResults(response);
      $scope.setItems(true);
      $scope.searchvar.noDataAtAll = false;
      if (response._links.next === void 0) {
        $scope.searchvar.hasMoreData = false;
      } else {
        $scope.searchvar.hasMoreData = true;
      }
    }
    $scope.$broadcast('scroll.resize');
    $scope.$broadcast('scroll.infiniteScrollComplete');
    $scope.clearResults();
    Loading.stop();
  };
  $scope.searchError = function(error) {
    $scope.searchvar.hasMoreData = false;
    $scope.searchvar.connectionError = true;
    $scope.clearResults();
    Loading.stop();
    $scope.$broadcast('scroll.infiniteScrollComplete');
    if (!Login.isAuthenticated()) {
      Popup.show($scope.translations.CONNECTION_ERROR, $scope.translations.OFFLINE, 3000, function() {
        return $ionicViewService.getBackView().go();
      });
    }
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * UI
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Event Listeners
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.$on('event:pictures-uploadFinished', function() {
    return $scope.search('', 0);
  });
  $rootScope.$on('event:auth-loginConfirmed', function() {
    $scope.dot.loggedIn = true;
    return $scope.search('', 0);
  });
  $rootScope.$on('event:auth-loginRequired', function() {
    return $scope.dot.loggedIn = false;
  });
  $scope.$on('modal.hidden', function() {
    if (!Login.isAuthenticated()) {
      return Popup.show($scope.translations.LOGIN_REQUIRED, $scope.translations.SEARCH_OWN_LOGIN_REQUIRED, 2000, function() {
        return $ionicViewService.getBackView().go();
      });
    }
  });

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Init
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.init = function() {
    $scope.login = {
      'noConnection': !Network.isConnected()
    };
    $scope.intPhotosPerPage = 36;
    $scope.page = 0;
    $scope.searchvar = {
      'hasMoreData': true,
      'noDataAtAll': false,
      'connectionError': false
    };
    $scope.dot = {
      'loggedIn': Login.isAuthenticated()
    };
    $scope.totalResults = 0;
    $scope.lastResults = [];
    $scope.items = [];
    $scope.pictures = {
      'maxColumns': 3,
      'minPictureDim': 150,
      'maxPictureDim': 300,
      'picturesMargin': 0,
      'containerPadding': 0,
      'containerDim': 0,
      'picturesDim': 0
    };
    angular.element(window).bind('resize', function() {
      return $scope.setDimensions(true);
    });
    $scope.setDimensions();
    if (Login.getRequiredFor() === "camera") {
      $scope.dot.message = 'LOGIN_REQUIRED_FOR_CAMERA';
    } else {
      $scope.dot.message = 'LOGIN_REQUIRED_FOR_OWN';
    }
    return $translate(['CONNECTION_ERROR', 'OFFLINE', 'SEARCH_CONNECTION_INFO', 'SEARCH_OWN_PICTURES', 'SEARCH_OWN_LOGIN_REQUIRED', 'LOGIN_REQUIRED']).then(function(translations) {
      return $scope.translations = translations;
    });
  };
  return $scope.init();
});

angular.module("DocCheckPictures.controllers").controller('PrivacyCtrl', function($scope, $translate, $timeout, Loading, LocalStorage) {

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  	 * Service-link functions & state transitions
  	 * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.setPrivacyOption = function() {
    return LocalStorage.set('privacySetting', $scope.privacyOptions.indexOf($scope.settings.currentPSetting));
  };
  $scope.setCCOption = function() {
    return LocalStorage.set('ccSetting', $scope.ccOptions.indexOf($scope.settings.currentCCSetting));
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  	 * Scope functions
  	 * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.setRightsOption = function() {
    var index;
    index = $scope.rightsOptions.indexOf($scope.settings.currentRSetting);
    LocalStorage.set('rightsSetting', index);
    return $timeout(function() {
      return $scope.show.ccOptions = index === 1;
    }, 100);
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  	 * UI
  	 * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  	 * Init
  	 * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.init = function() {
    $scope.hideTabs();
    $scope.$on('$destroy', function() {
      return $scope.showTabs();
    });
    $scope.settings = {
      'currentPrivacySetting': LocalStorage.get('privacySetting'),
      'currentRightsSetting': LocalStorage.get('rightsSetting'),
      'currentCCSetting': LocalStorage.get('ccSetting')
    };
    $scope.show = {
      'ccOptions': parseInt($scope.settings.currentRightsSetting) === 1
    };
    console.log($scope.settings.currentRightsSetting);
    console.log($scope.settings.currentRightsSetting === 1);
    console.log($scope.show.ccOptions);
    return $translate(['EDIT_VISIBILITY_PRIVATE', 'EDIT_VISIBILITY_PUBLIC', 'EDIT_VISIBILITY_DCMEMBER', 'EDIT_VISIBILITY_MEDIC', 'PRIVACY_ALL_RIGHTS_RESERVED', 'PRIVACY_CREATIVE_COMMONS', 'PRIVACY_CC_ATTR', 'PRIVACY_CC_ATTR_NODER', 'PRIVACY_CC_ATTR_SHARE', 'PRIVACY_CC_ATTR_NONCOMM', 'PRIVACY_CC_ATTR_NONCOMM_NODER', 'PRIVACY_CC_ATTR_NONCOMM_SHARE', 'PRIVACY_PUBLIC_DOMAIN']).then(function(translations) {
      $scope.translations = translations;
      $scope.privacyOptions = [translations.EDIT_VISIBILITY_PRIVATE, translations.EDIT_VISIBILITY_PUBLIC, translations.EDIT_VISIBILITY_DCMEMBER, translations.EDIT_VISIBILITY_MEDIC];
      $scope.rightsOptions = [translations.PRIVACY_ALL_RIGHTS_RESERVED, translations.PRIVACY_CREATIVE_COMMONS, translations.PRIVACY_PUBLIC_DOMAIN];
      $scope.ccOptions = [translations.PRIVACY_CC_ATTR, translations.PRIVACY_CC_ATTR_NODER, translations.PRIVACY_CC_ATTR_SHARE, translations.PRIVACY_CC_ATTR_NONCOMM, translations.PRIVACY_CC_ATTR_NONCOMM_NODER, translations.PRIVACY_CC_ATTR_NONCOMM_SHARE];
      $scope.settings.currentPSetting = $scope.privacyOptions[$scope.settings.currentPrivacySetting];
      $scope.settings.currentRSetting = $scope.rightsOptions[$scope.settings.currentRightsSetting];
      return $scope.settings.currentCCSetting = $scope.ccOptions[$scope.settings.currentCCSetting];
    });
  };
  return $scope.init();
});


/*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  PictureSearchCtrl               #
 *   -> picture-search-view         ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
 */
angular.module("DocCheckPictures.controllers").controller('PromotionCtrl', function($scope, $state, $ionicScrollDelegate, Loading, $http, Network, Pictures, Camera, LocalStorage, Login) {

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Service-link functions & state transitions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.openLink = function(link) {
    return window.open(link, "_system", "location=no");
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Scope functions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * UI
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.setDimensions = function(update) {
    var columns, rows;
    columns = Math.floor(window.innerWidth / $scope.pictures.minPictureDim);
    if (columns > $scope.pictures.maxColumns) {
      columns = $scope.pictures.maxColumns;
    }
    $scope.pictures.containerDim = window.innerWidth / columns;
    rows = Math.round(window.innerHeight / $scope.pictures.containerDim);
    $scope.intPhotosPerPage = rows * columns;
    if ($scope.pictures.containerDim > $scope.pictures.maxPictureDim) {
      $scope.pictures.picturesDim = $scope.pictures.maxPictureDim;
    } else {
      $scope.pictures.picturesDim = Math.round($scope.pictures.containerDim * 0.9);
    }
    $scope.pictures.picturesMargin = ($scope.pictures.containerDim - $scope.pictures.picturesDim) / 2;
    if (!$scope.$$phase) {
      return $scope.$apply();
    }
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Init
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.init = function() {
    $scope.hideTabs();
    $scope.$on('$destroy', function() {
      return $scope.showTabs();
    });
    $scope.pictures = {
      'maxColumns': 5,
      'minPictureDim': 100,
      'maxPictureDim': 220,
      'picturesMargin': 0,
      'containerPadding': 0,
      'containerDim': 0,
      'picturesDim': 0
    };
    angular.element(window).bind('resize', function() {
      return $scope.setDimensions(true);
    });
    return $scope.setDimensions();
  };
  return $scope.init();
});


/*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  SettingsCtrl                    #
 *   -> settings-view               ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
 */
angular.module("DocCheckPictures.controllers").controller('SettingsCtrl', function($scope, $translate, Login, Settings, Search, Popup, UpdateTimer, Network) {

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Service-link functions & state transitions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.isAuthenticated = function() {
    return Login.isAuthenticated();
  };
  $scope.didLoginFail = function() {
    return Login.didLoginFail();
  };
  $scope.submitLogout = function() {
    return Login.logout({});
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Scope functions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.load = function() {
    var iframe;
    iframe = angular.element(document.getElementById("loginFrameSettings"));
    if (iframe[0] !== void 0) {
      iframe[0].addEventListener('onbeforeunload', function() {});
      iframe[0].addEventListener('onunload', function() {});
      return iframe[0].addEventListener('onload', function() {});
    }
  };
  $scope.setLanguage = function() {
    var language;
    language = $scope.settings.language.toLowerCase() + "_" + $scope.settings.language;
    console.log(language);
    $translate.use(language);
    if (Settings.setLanguage(language)) {
      Search.clearCaches();
    }
    $scope.updateTranslations();
    $scope.refreshLoginFrame();
    return $translate(['UPDATE']).then(function(translations) {
      return UpdateTimer.setText(translations.UPDATE);
    });
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * UI
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  ionic.DomUtil.ready($scope.load);

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Init
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.init = function() {
    $scope.login = {
      'noConnection': !Network.isConnected()
    };
    $scope.languages = ['DE', 'EN'];
    return $scope.settings = {
      currentLanguage: $scope.languages.indexOf(Settings.getLanguage().toUpperCase()),
      'subview': false
    };
  };
  return $scope.init();
});

angular.module("DocCheckPictures.controllers").controller('SubSettingsCtrl', function($scope, $translate) {

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  	 * Service-link functions & state transitions
  	 * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  	 * Scope functions
  	 * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  	 * UI
  	 * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
  	 * Init
  	 * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.init = function() {
    $scope.hideTabs();
    return $scope.$on('$destroy', function() {
      return $scope.showTabs();
    });
  };
  return $scope.init();
});


/*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
##  AppCtrl                         #
 *   -> tab-view.html               ##
#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
 */
angular.module("DocCheckPictures.controllers").controller('TabCtrl', function($scope, $rootScope, $translate, $ionicPopup, $state, $interval, $ionicViewService, Popup, Loading, LoginModal, Camera, Login, authService, Network, LocalStorage, UserPictures, UpdateTimer, Settings) {

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Service-link functions & state transitions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.goTo = function(state) {
    return $state.go(state);
  };
  $scope.back = function() {
    return $ionicViewService.getBackView().go();
  };
  $scope.toOwnPictures = function() {
    return $state.go('app.settings.main').then(function() {
      return $state.go('app.picturemy.searchmy');
    });
  };
  $scope.isAndroid = function() {
    return ionic.Platform.isAndroid();
  };
  $scope.isLoading = function() {
    return Loading.inProgress();
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Scope functions
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  window.responseReceived = function(iurl, modal) {
    var accessToken, expiresIn, iframe, url;
    if (modal) {
      iframe = angular.element(document.getElementById("loginFrame"));
    } else {
      iframe = angular.element(document.getElementById("loginFrameSettings"));
    }
    url = iurl;
    if (iurl.indexOf("nothing") >= 0) {
      iframe[0].src = "https://login.doccheck.com/code/" + Settings.getLanguage(true) + "/2000000006987/s_mobile/response_type=token/_self?dc_force_logout=1";
      return;
    }
    $scope.login.noConnection = false;
    if (iurl.indexOf("access_token=") >= 0 && iurl.indexOf("error") < 0) {
      accessToken = iurl.substring(iurl.indexOf("access_token=") + "access_token=".length);
      accessToken = accessToken.substring(0, accessToken.indexOf("&"));
      expiresIn = iurl.substring(iurl.indexOf("expires_in=") + "expires_in=".length);
      if (expiresIn.indexOf('&') >= 0) {
        expiresIn = expiresIn.substring(0, expiresIn.indexOf('&'));
      }
      expiresIn = 60 * 60 * 24 * 31 * 4;
      Login.setToken(accessToken, expiresIn);
      if (modal) {
        $scope.loginModal.hide();
      }
    } else if (iurl.indexOf("error") >= 0) {
      $ionicPopup.alert({
        title: $scope.tabTranslations.LOGIN_FAILED,
        template: $scope.tabTranslations.LOGIN_FAILED_CONTENT
      }).then(function() {});
      iframe[0].src = "https://login.doccheck.com/code/" + Settings.getLanguage(true) + "/2000000006987/s_mobile/response_type=token/_self?dc_force_logout=1";
      $scope.loginFrame.loading = false;
      Login.setLoginFailed(true);
    } else if (iurl.indexOf("http") < 0) {
      $scope.login.noConnection = true;
      $scope.loginModal.hide();
      Login.loginCancelled();
      document.addEventListener("online", function() {
        $scope.login.noConnection = false;
        return iframe[0].src = "https://login.doccheck.com/code/" + Settings.getLanguage(true) + "/2000000006987/s_mobile/response_type=token/_self?dc_force_logout=1";
      }, false);
    } else {
      $scope.loginFrame.loading = false;
      $scope.$apply();
    }
    return Loading.stop();
  };

  /* -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   * App-wide function for functions requiring authentication
   * -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   */
  $scope.authAction = function(actionCallback, requiredFor, needsConnection) {
    if (requiredFor == null) {
      requiredFor = '';
    }
    if (needsConnection == null) {
      needsConnection = true;
    }
    if (!$scope.tabs.hidden && !$scope.tabs.partly) {
      if (!needsConnection || Network.isConnected()) {
        if (!Login.isAuthenticated()) {
          Loading.start();
          $scope.login.noConnection = false;
          Login.setRequiredFor(requiredFor);
          return $rootScope.$broadcast('event:auth-loginRequired');
        } else {
          return actionCallback();
        }
      } else {
        return $ionicPopup.alert({
          title: $scope.tabTranslations.NO_CONNECTION_HEADING,
          template: $scope.tabTranslations.NO_CONNECTION_CONTENT
        }).then(function() {});
      }
    }
  };

  /* -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   * App-wide functions for camera & upload handling
   * -=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   */
  $scope.getPhotoFromLibrary = function($event) {
    if (!Loading.inProgress()) {
      return $scope.getPicture(0);
    }
  };
  $scope.takePhoto = function($event) {
    if (!Loading.inProgress()) {
      return $scope.getPicture(1);
    }
  };
  $scope.getPicture = function(source) {
    return Camera.getPicture({
      sourceType: source,
      destinationType: 0,
      mediaType: 0,
      encodingType: 0,
      correctOrientation: true,
      allowEdit: true,
      saveToPhotoAlbum: true
    }).then((function(imageURI) {
      return UserPictures.upload(imageURI, function(event) {
        Loading.start();
        return $scope.popup = Popup.show($scope.tabTranslations.UPLOAD_IN_PROGRESS_HEADING, $scope.tabTranslations.UPLOAD_IN_PROGRESS_CONTENT, 0);
      }, function(event) {
        Loading.stop();
        Popup.hide();
        if ($state.current.name !== "app.picturemy.searchmy") {
          $state.go("app.picturemy.searchmy");
        }
        return Popup.show($scope.tabTranslations.UPLOAD_SUCCESS_HEADING, $scope.tabTranslations.UPLOAD_SUCCESS_CONTENT, 2000, function() {
          return $rootScope.$broadcast('event:pictures-uploadFinished');
        });
      }, function(event) {
        var percentComplete;
        if (event.lengthComputable) {
          return percentComplete = Math.round(event.loaded * 100 / event.total);
        }
      }, function(event) {
        Loading.stop();
        Popup.hide();
        return Popup.show($scope.tabTranslations.UPLOAD_FAILURE_HEADING, $scope.tabTranslations.UPLOAD_FAILURE_CONTENT);
      });
    }));
  };
  $scope.initiateUpload = function() {
    $scope.setOverlayButtons();
    $scope.upload.selection = true;
  };
  $scope.cancelUpload = function() {
    $scope.upload.selection = false;
  };
  $scope.toggleUpload = function() {
    $scope.setOverlayButtons();
    $scope.upload.selection = !$scope.upload.selection;
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * UI
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.updateTranslations = function() {
    console.log("updating");
    return $translate(['NO_CONNECTION_HEADING', 'NO_CONNECTION_CONTENT', 'LOGIN_REQUIRED', 'LOGIN_REQUIRED_CONTENT', 'LOGIN_INCORRECT', 'LOGIN_FAILED', 'LOGIN_FAILED_CONTENT', 'NO_CONNECTION', 'UPLOAD_SUCCESS_HEADING', 'UPLOAD_SUCCESS_CONTENT', 'UPLOAD_FAILURE_HEADING', 'UPLOAD_FAILURE_CONTENT', 'UPLOAD_IN_PROGRESS_HEADING', 'UPLOAD_IN_PROGRESS_CONTENT', 'CAMERA_DIALOG_HEADING', 'CAMERA_DIALOG_CONTENT', 'UPDATE']).then(function(translations) {
      return $scope.tabTranslations = translations;
    });
  };
  $scope.getButtonStyle = function() {
    var dim, margin, maxDim;
    dim = (window.innerWidth - 80) / 4;
    maxDim = 48;
    margin = (dim - maxDim) / 2;
    return {
      'width': maxDim + 'px',
      'height': maxDim + 'px',
      'margin': '0px ' + margin + 'px 20px',
      'line-height': maxDim + 'px'
    };
  };
  $scope.refreshLoginFrame = function() {
    var iframe;
    iframe = angular.element(document.getElementById("loginFrameSettings"));
    if (iframe[0] != null) {
      iframe[0].src = "https://login.doccheck.com/code/" + Settings.getLanguage(true) + "/2000000006987/s_mobile/response_type=token/_self?dc_force_logout=1";
    }
  };
  $scope.setOverlayButtons = function() {
    var dim, height;
    height = window.innerHeight - 75;
    if (window.innerWidth > window.innerHeight) {
      dim = height / 3;
      $scope.overlay.dim = $scope.overlay.dim = dim;
      $scope.overlay.camera.top = $scope.overlay.gallery.top = height / 2 - dim / 2;
      $scope.overlay.camera.left = window.innerWidth / 4 - dim / 2;
      return $scope.overlay.gallery.left = window.innerWidth * 3 / 4 - dim / 2;
    } else {
      dim = window.innerWidth / 3;
      $scope.overlay.dim = $scope.overlay.dim = dim;
      $scope.overlay.camera.left = $scope.overlay.gallery.left = window.innerWidth / 2 - dim / 2;
      $scope.overlay.gallery.top = height / 4 - dim / 2;
      return $scope.overlay.camera.top = height * 3 / 4 - dim / 2;
    }
  };
  $scope.hideTabs = function() {
    return $scope.tabs.hidden = true;
  };
  $scope.showTabsPartly = function() {
    $scope.tabs.hidden = false;
    return $scope.tabs.partly = true;
  };
  $scope.showTabs = function() {
    $scope.tabs.hidden = false;
    return $scope.tabs.partly = false;
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Event Listeners
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.$on('event:auth-loginRequired', function(e, rejection) {
    Login.unsetToken();
    Loading.stop();
    $scope.login.noConnection = false;
    if ($state.current.name === 'app.picturemy.searchmy') {
      Login.cancelActionCallback();
    }

    /*
    $state.go('app.settings.main').then(->
      $state.go('app.picturemy.searchmy')
    )
     */
    return $state.go('app.settings.main').then(function() {
      return $state.go('app.picturemy.searchmy');
    });

    /*
    if(Network.isConnected())
      $scope.openModal()
    else
      Popup.show($scope.tabTranslations.NO_CONNECTION_HEADING, $scope.tabTranslations.NO_CONNECTION_CONTENT)
     */
  });
  $scope.$on('event:auth-loginConfirmed', function() {
    Login.executeActionCallback();
    return $scope.loginModal.hide();
  });
  $scope.$on('event:auth-login-failed', function(e, status) {
    var error;
    Loading.stop();
    Login.cancelActionCallback();
    error = $scope.tabTranslations.LOGIN_FAILED;
    if (status === 401) {
      error = $scope.tabTranslations.LOGIN_INCORRECT;
    }
    return $scope.message = error;
  });
  $scope.$on('event:auth-logout-complete', function() {
    return Loading.stop();
  });

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Debug
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.devChanges = function() {
    if ($scope.dev.testserver) {
      Network.switchToTest();
    }
    return $scope.$watch('dev.testserver', function(newVersion, oldVersion) {
      if (newVersion) {
        return Network.switchToTest();
      } else {
        return Network.switchToLive();
      }
    });
  };

  /* -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   * Init
   * -/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/-/
   */
  $scope.init = function() {
    $scope.dev = {
      'active': false,
      'oldoverlay': false,
      'testserver': false
    };
    if ($scope.dev.active) {
      $scope.devChanges();
    }
    LoginModal.init();
    $scope.upload = {
      saveToPhotoAlbum: true,
      selection: false
    };
    $scope.login = {
      noConnection: false
    };
    $scope.loginFrame = {
      loading: true
    };
    if (!LocalStorage.isSet('privacySetting')) {
      LocalStorage.set('privacySetting', 0);
    }
    if (!LocalStorage.isSet('rightsSetting')) {
      LocalStorage.set('rightsSetting', 0);
    }
    if (!LocalStorage.isSet('ccSetting')) {
      LocalStorage.set('ccSetting', 0);
    }
    $scope.overlay = {
      dim: 0,
      gallery: {
        top: 0,
        left: 0
      },
      camera: {
        top: 0,
        left: 0
      }
    };
    $scope.tabs = {
      'hidden': false,
      'partly': false
    };
    return angular.element(window).bind('resize', function() {
      if ($scope.upload.selection) {
        return $scope.setOverlayButtons();
      }
    });
  };
  ionic.Platform.ready(function() {
    $translate(['NO_CONNECTION_HEADING', 'NO_CONNECTION_CONTENT', 'LOGIN_REQUIRED', 'LOGIN_REQUIRED_CONTENT', 'LOGIN_INCORRECT', 'LOGIN_FAILED', 'LOGIN_FAILED_CONTENT', 'NO_CONNECTION', 'UPLOAD_SUCCESS_HEADING', 'UPLOAD_SUCCESS_CONTENT', 'UPLOAD_FAILURE_HEADING', 'UPLOAD_FAILURE_CONTENT', 'UPLOAD_IN_PROGRESS_HEADING', 'UPLOAD_IN_PROGRESS_CONTENT', 'CAMERA_DIALOG_HEADING', 'CAMERA_DIALOG_CONTENT', 'UPDATE']).then(function(translations) {
      return $scope.tabTranslations = translations;
    });
    return $rootScope.$on('$stateChangeStart', function(event, toState, toParams, fromState, fromParams) {
      return $scope.showTabs();
    });
  });
  $scope.init();
  return $scope.message = "";
});

angular.module("DocCheckPictures.controllers").controller('DcButtonCtrl', function($scope) {
  return $scope.onClick = function() {
    return $scope.action();
  };
});

angular.module("DocCheckPictures.directives").directive('dcButton', function() {
  return {
    restrict: 'E',
    scope: {
      text: '@',
      action: '&'
    },
    templateUrl: 'templates/DcButtonTemplate.html',
    controller: 'DcButtonCtrl'
  };
});

angular.module('DocCheckPictures.directives').directive('dcConfirmPopup', function() {
  return {
    restrict: 'E',
    templateUrl: 'templates/dc-confirm-popup.html',
    scope: {
      positive: '@',
      negative: '@',
      positiveCallback: '&',
      negativeCallback: '&'
    },
    link: function(scope, el, attrs) {}
  };
});

angular.module("DocCheckPictures.controllers").controller('DcInputCtrl', function($scope) {
  return console.log($scope.required);
});

angular.module("DocCheckPictures.directives").directive('dcInput', function() {
  return {
    restrict: 'E',
    templateUrl: 'templates/DcInputTemplate.html',
    scope: {
      labelText: '@',
      hintText: '@',
      requiredHintText: '@',
      icon: '@',
      iconAction: '&',
      required: '=',
      model: '='
    },
    controller: 'DcInputCtrl',
    transclude: true

    /*
    		labelBlock 				= element.find('div.dclabel')
    		iconBlock 				= element.find('div.dcicon')
    		inputBlock				= element.find('div.dcinput')
    		transcludedBlock  = element.find('div.transcluded')
    		transcludedElems  = transcludedBlock.children()
    
    		angular.forEach(transcludedElems , (elem) ->
    
    			if elem.tagName == 'INPUT' || elem.tagName == 'TEXTAREA'
    				inputBlock.append(elem)
    
    				if attrs.icon && attrs.icon.length > 0
    					iconbutton = '<button class="button button-icon fa ' + attrs.icon + '"'
    
    					if attrs.iconaction && attrs.iconaction.length > 0
    						iconbutton += ' ng-click="' + attrs.iconaction + '"'
    
    					iconbutton += '></button>'
    
    					inputBlock.append(iconbutton)
    
    			if attrs.labeltext && attrs.labeltext.length > 0
    				labelBlock[0].innerHTML = attrs.labeltext
    
    		)
    
    
    		transcludedBlock.remove()
     */
  };
});

angular.module("DocCheckPictures.controllers").controller('DcLoginCtrl', function($scope, $timeout, Login, Settings) {
  $scope.form = {
    user: '',
    pw: '',
    hint: {
      user: false,
      pw: false
    }
  };
  $scope.submitLogin = function() {
    if ($scope.form.user && $scope.form.pw) {
      $scope.hideRequiredHints();
      return Login.sendLoginRequest($scope.form.user, $scope.form.pw, function(data, status, headers, config) {}, function(data, status, headers, config) {
        $scope.form.hint.user = true;
        $scope.form.hint.pw = true;
        $timeout(function() {
          return $scope.hideRequiredHints();
        }, 6000);
        return $scope.failureText = 'Inkorrekt!';
      });
    } else {
      return $scope.showRequiredHint();
    }
  };
  $scope.showRequiredHint = function() {
    $scope.form.hint.user = !$scope.form.user || $scope.form.user.length === 0;
    return $scope.form.hint.pw = !$scope.form.pw || $scope.form.pw.length;
  };
  $scope.hideRequiredHints = function() {
    $scope.form.hint.user = false;
    return $scope.form.hint.pw = false;
  };
  $scope.openUrl = function(url) {
    var ref;
    if (typeof cordova !== "undefined" && cordova !== null) {
      ref = window.open(url, "_system");
      return console.log(ref);
    } else {
      window.open(url, "_blank");
      console.log("[Seperate implementation for browser]");
      return Settings.getLanguage(true);
    }
  };
  $scope.getReminderUrl = function() {
    return 'https://www.doccheck.com/' + Settings.getLanguage(true) + '/account/password/reminder/';
  };
  return $scope.getRegistrationUrl = function() {
    return 'https://www.doccheck.com/' + Settings.getLanguage(true) + '/account/register/';
  };
});

angular.module("DocCheckPictures.directives").directive('dcLogin', function() {
  return {
    restrict: 'E',
    require: '',
    scope: {
      infoText: '@'
    },
    templateUrl: 'templates/DcLoginTemplate.html',
    controller: 'DcLoginCtrl'
  };
});

angular.module('DocCheckPictures.directives').directive('focus', function($timeout) {
  return {
    restrict: 'A',
    link: function(scope, element, attrs) {
      return $timeout(function() {
        return function() {};
      }, 500);
    }
  };
});

angular.module('DocCheckPictures.directives').directive('HideKeyboardOnSubmit', function() {
  return function(scope, element, attr) {
    var form;
    form = $(element).children('input[type=search]');
    return $(element).submit(function() {
      return form.blur();
    });
  };
});

angular.module('DocCheckPictures.directives').directive('starrating', function() {
  return {
    restrict: 'E',
    templateUrl: 'templates/star-rating-element.html'
  };
});

angular.module('DocCheckPictures.directives').directive('dctag', function() {
  return {
    restrict: 'E',
    scope: {
      'link': '=',
      'icon': '=?',
      'pick': '&onPick'
    },
    controller: function($scope) {
      return $scope.icon = $scope.icon || "no-icon";
    },
    templateUrl: "templates/tag-dir.html"
  };
});

angular.module("DocCheckPictures.translations").config(function($translateProvider) {
  return $translateProvider.translations('de_DE', {

    /*
    #
     * 888888   8888888
     * 88   88  88
     * 88    88 88
     * 88    88 8888
     * 88    88 88
     * 88   88  88
     * 888888   8888888
    #
     */
    'DC_PICTURES': 'DocCheck Pictures',
    'SEARCH_PLACEHOLDER': 'Stichwort...',
    'SEARCH_CONNECTION_INFO': 'Verbindung zu DocCheck Pictures konnte nicht hergestellt werden.',
    'SEARCH_NEWEST_PICTURES': 'Neue Bilder',
    'SEARCH_NO_RESULTS': 'Keine Treffer für diesen Begriff',
    'SEARCH_RESULTS_FOR': 'Ergebnisse für',
    'DETAIL_HEADING': 'Detailansicht',
    'DETAIL_DELETE_CHECK_HEADING': 'Bild löschen',
    'DETAIL_DELETE_CHECK_CONTENT': 'Bist Du sicher, dass Du dieses Bild löschen möchtest?',
    'DETAIL_DELETE_SUCCESS_HEADING': 'Löschen erfolgreich',
    'DETAIL_DELETE_SUCCESS_CONTENT': 'Das Bild wurde gelöscht.',
    'DETAIL_DELETE_FAILURE_HEADING': 'Löschen fehlgeschlagen',
    'DETAIL_DELETE_FAILURE_CONTENT': 'Das Bild konnte nicht gelöscht werden. Bitte überprüfe Deine Verbindung oder versuche es später erneut.',
    'DETAIL_PICINFO_FAILURE_CONTENT': 'Die Bildinformationen konnten nicht abgerufen werden. Bitte überprüfe Deine Verbindung oder versuche es später erneut.',
    'EDIT_TITLE': 'Bild bearbeiten',
    'EDIT_PLACEHOLDER_DESCRIPTION': 'Beschreibung',
    'EDIT_PLACEHOLDER_TAG': 'Tag hinzufügen',
    'EDIT_PLACEHOLDER_TITLE': 'Titel',
    'EDIT_CHANGES_SUCCESS_HEADING': 'Änderungen erfolgreich',
    'EDIT_CHANGES_SUCCESS_CONTENT': 'Deine Änderungen wurden gespeichert.',
    'EDIT_CHANGES_FAILURE_HEADING': 'Änderungen fehlgeschlagen',
    'EDIT_CHANGES_FAILURE_CONTENT': 'Deine Änderungen konnten nicht übernommen werden. Überprüfe Deine Verbindung oder versuche es später erneut.',
    'EDIT_VISIBILITY_LABEL': 'Sichtbarkeit',
    'EDIT_VISIBILITY_PRIVATE': 'privat',
    'EDIT_VISIBILITY_PUBLIC': 'öffentlich',
    'EDIT_VISIBILITY_DCMEMBER': 'DocCheck Nutzer',
    'EDIT_VISIBILITY_MEDIC': 'Medizinische Fachkreise',
    'EDIT_BUTTON_SAVE': 'Speichern',
    'EDIT_BUTTON_ADD_TAG': 'Hinzufügen',
    'SEARCH_OWN_PICTURES': 'Meine Bilder',
    'SEARCH_OWN_LOGIN_REQUIRED': 'Logge Dich ein, um Deine eigenen Bilder zu sehen.',
    'FEEDBACK_TITLE': 'Feedback senden',
    'HELP_TITLE': 'Hilfe &amp; Tipps',
    'HELP_CONTENT': '<b style="color:#000">Was ist die Pictures App?</b><br /> DocCheck Pictures ist das kostenlose medizinische Bildarchiv von Europas größter Healthcare-Community. Das Archiv enthält u.a. Fallbeispiele, Befunddokumentationen, Mikrofotografien, bildgebende Verfahren der Medizin und schematische Darstellungen. Stöbere in über 20.000 Medizinbildern und teile Deine interessanten Fälle mit über 1.000.000 Kollegen. <br /> Mit der kostenlosen App hast Du das Bildarchiv immer dabei und kannst Fälle ganz einfach per Knopfdruck teilen. <br /> <br /> <b style="color:#000">Wie kann ich ein Bild hochladen?</b><br /> Wenn Du auf die Kamera in der Mitte unten klickst, kannst Du auswählen, ob Du Bilder aus Deinem Archiv hochladen willst oder direkt ein Foto aufnehmen willst. Das frisch aufgenommene Foto wird dann automatisch bei DocCheck hochgeladen.<br /> <br /> <b style="color:#000">Wer kann meine Bilder sehen?</b><br /> Das kommt ganz auf Deine Sichtbarkeitseinstellungen an. Diese kannst Du ändern, wenn Du in den Einstellungen auf „Standard-Datenschutz“ klickst.<br /> <br /> <b style="color:#000">Was muss ich bei der Veröffentlichung von Patientenbildern beachten?</b><br /> Da gerade bei Bildern die Erkennbarkeit der Patienten nicht vollkommen ausgeschlossen werden kann und Bilder von Krankheiten die Intimsphäre des Patienten betreffen, ist eine Einwilligung des Patienten erforderlich. Bitte sorge in jedem Fall dafür, dass die Gesichter der Patienten nicht abgebildet werden und veröffentliche keine Namen Deiner Patienten.',
    'PRIVACY_TITLE': 'Datenschutz',
    'SETTINGS_TITLE': 'Einstellungen',
    'SETTINGS_NOTIFICATIONS': 'Benachrichtigungen',
    'SETTINGS_SAVE_LOCALLY': 'In Aufnahmen sichern',
    'SETTINGS_SIGN_OUT': 'Abmelden',
    'SETTINGS_HELP': 'Hilfe &amp; Tipps',
    'SETTINGS_PRIVACY': 'Datenschutz',
    'SETTINGS_FEEDBACK': 'Feedback senden',
    'SETTINGS_PROMOTION': 'Mehr Informationen',
    'CONNECTION_ERROR': 'Verbindung fehlgeschlagen',
    'NO_CONNECTION_HEADING': 'Keine Verbindung',
    'NO_CONNECTION_CONTENT': 'Keine Internetverbindung verfügbar. Bitte verbinde Dein Gerät mit dem Internet und versuche es erneut.',
    'YES': 'Ja',
    'NO': 'Nein',
    'CONFIRM': 'Okay',
    'CANCEL': 'Abbrechen',
    'SUBMIT': 'Abschicken',
    'LOADING': 'Wird geladen...',
    'LOGIN_REQUIRED': 'Login erforderlich',
    'LOGIN_REQUIRED_CONTENT': 'Bitte logge Dich ein, um diese Funktion zu nutzen.',
    'LOGIN_FAILED': 'Login fehlgeschlagen',
    'LOGIN_FAILED_CONTENT': 'Nutzername oder Passwort nicht korrekt.',
    'LOGIN_INCORRECT': 'Ungültige Kombination aus Nutzername und Passwort.',
    'UPLOAD_SUCCESS_HEADING': 'Upload abgeschlossen',
    'UPLOAD_SUCCESS_CONTENT': 'Dein Bild wurde hochgeladen.',
    'UPLOAD_FAILURE_HEADING': 'Upload abgebrochen',
    'UPLOAD_FAILURE_CONTENT': 'Das Bild konnte nicht hochgeladen werden. Bitte überpüfe Deine Internetverbindung oder das Bildformat.',
    'UPLOAD_IN_PROGRESS_HEADING': 'Upload',
    'UPLOAD_IN_PROGRESS_CONTENT': 'Dein Bild wird hochgeladen...',
    'DISCLAIMER_TITLE': 'Disclaimer',
    'SETTINGS_DISCLAIMER': 'Disclaimer',
    'IMPRESS': 'Impressum',
    'LANGUAGE': 'Sprache',
    'ADDITIONAL_INFORMATION': 'Mehr Informationen',
    'OFFLINE': 'Leider ist ein Fehler beim Laden der Bilder aufgetreten.<br /> Bitte überprüfe Deine Internetverbindung und versuche es erneut.',
    'SEARCH_OWN_NO_ITEMS': 'Du hast noch keine eigenen Bilder hochgeladen. Klicke auf die Kamera unten und lege gleich los!',
    'PRIVACY_VISIBILITY_TEXT': 'Hier kannst Du einstellen, wer Deine Bilder sehen darf.',
    'PRIVACY_RIGHTS_LABEL': 'Copyright',
    'PRIVACY_RIGHTS_TEXT': 'Welche Rechte liegen auf deinen Bildern?',
    'PRIVACY_ALL_RIGHTS_RESERVED': 'Alle Rechte vorbehalten',
    'PRIVACY_CREATIVE_COMMONS': 'Creative Commons',
    'PRIVACY_CC_ATTR': 'Namensnennung',
    'PRIVACY_CC_ATTR_NODER': 'Namensnennung, keine Bearbeitung',
    'PRIVACY_CC_ATTR_SHARE': 'Namensnennung, Weitergabe unter gleichen Bedingungen',
    'PRIVACY_CC_ATTR_NONCOMM': 'Namensnennung, nicht-kommerziell',
    'PRIVACY_CC_ATTR_NONCOMM_NODER': 'Namensnennung, nicht-kommerziell, keine Bearbeitung',
    'PRIVACY_CC_ATTR_NONCOMM_SHARE': 'Namensnennung, nicht-kommerziell, Weitergabe unter gleichen Bedingungen',
    'PRIVACY_PUBLIC_DOMAIN': 'Kein Urheberrechtsschutz (Gemeinfreiheit, public domain)',
    'OVERLAY_TAKE_PHOTO': 'Foto aufnehmen',
    'OVERLAY_OPEN_GALLERY': 'Aus Album auswählen',
    'PRIVACY_IN_FUTURE': 'Hier wirst Du zukünftig ebenfalls die standardmäßigen Rechteeinstellungen festlegen können.',
    'DETAIL_INFO': 'Details',
    'LOGIN_REQUIRED_REF': 'Logge Dich ein, um noch mehr spannende Bilder zu sehen.',
    'UPDATE': 'Dies ist eine Vorabversion der neuen DocCheck Pictures App und wird keine weiteren Updates erhalten. Installiere in ein paar Tagen also auch die <a href=\"https://itunes.apple.com/de/app/doccheck-pictures/id454491104?mt=8&uo=4\" target=\"itunes_store\">offizielle Pictures App aus dem AppStore</a>, um immer auf dem aktuellen Stand zu sein.',
    'LOGIN_REQUIRED_FOR_CAMERA': 'Logge Dich ein, um eigene Bilder hochzuladen.',
    'LOGIN_REQUIRED_FOR_OWN': 'Logge Dich ein, um auf Deine eigenen Bilder zuzugreifen.',
    'DISCLAIMER_CONTENT': 'DocCheck® Pictures ist ein offenes Medizinbildarchiv, das ausschließlich der Aus- und Weiterbildung von Angehörigen und Studenten der medizinischen Fachkreise (z.B. Ärzte, Apotheker, Tierärzte, Zahnärzte) dient. Es bietet keine Anleitung zur Selbsttherapie und kein Ersatz für eine ärztliche Beratung oder Behandlung.<br /> <br /> DocCheck Pictures wird von den teilnehmenden Autoren nach bestem Wissen gepflegt. Da es "offen" ist, kann es jedoch falsche, unvollständige oder sogar irreführende Informationen enthalten. Als Nutzer sollten Sie deshalb alle enthaltenen Informationen kritisch prüfen und mit weiteren Quellen vergleichen.<br /> <br /> Die Autoren und die Betreiber von DocCheck Pictures übernehmen keine Haftung für Schäden, die durch unreflektierte bzw. nicht-kontrollierte Anwendung von Empfehlungen, Inhalten oder Meinungsäußerungen entstehen, die bei DocCheck Pictures zu Lehr- oder Demonstrationszwecken publiziert sind.<br /> <br /> Bilder und Artikel, die Angaben zum Einsatz und zur Dosierung von Medikamenten machen, sind die persönliche Einschätzung der Autoren. Sie sind kein Ersatz für die Empfehlungen des Herstellers oder des behandelnden Arztes oder Apothekers.',
    'DC_LOGIN_USERNAME': 'Nutzername',
    'DC_LOGIN_PASSWORD': 'Passwort',
    'DC_LOGIN_PASSWORDFORGOTTEN': 'Passwort vergessen?',
    'DC_LOGIN_REGISTER': 'Kostenlos registrieren',
    'DC_LOGIN_SUBMIT': 'Einloggen'
  });
});

angular.module("DocCheckPictures.translations").config(function($translateProvider) {
  return $translateProvider.translations('en_EN', {

    /*
    #
     * 8888888 888     88 
     * 88      8888    88
     * 88      88 88   88
     * 8888    88  88  88
     * 88      88   88 88
     * 88      88    8888
     * 8888888 88     888
    #
     */
    'DC_PICTURES': 'DocCheck Pictures',
    'SEARCH_PLACEHOLDER': 'Keyword...',
    'SEARCH_CONNECTION_INFO': 'Couldn\'t connect to DocCheck Pictures.',
    'SEARCH_NEWEST_PICTURES': 'New pictures',
    'SEARCH_NO_RESULTS': 'No results for your search',
    'SEARCH_RESULTS_FOR': 'results for',
    'DETAIL_HEADING': 'Detailed view',
    'DETAIL_DELETE_CHECK_HEADING': 'Confirm deletion',
    'DETAIL_DELETE_CHECK_CONTENT': 'Are you sure you want to delete this picture?',
    'DETAIL_DELETE_SUCCESS_HEADING': 'Deletion successful',
    'DETAIL_DELETE_SUCCESS_CONTENT': 'The picture has been deleted successfully.',
    'DETAIL_DELETE_FAILURE_HEADING': 'Deletion failed',
    'DETAIL_DELETE_FAILURE_CONTENT': 'The picture couldn\'t be deleted. Please check your connection or try again later.',
    'DETAIL_PICINFO_FAILURE_CONTENT': 'The information for this picture couldn\'t be loaded. Please check your connection or try again later.',
    'EDIT_TITLE': 'Edit picture',
    'EDIT_PLACEHOLDER_DESCRIPTION': 'Description',
    'EDIT_PLACEHOLDER_TAG': 'Add tag',
    'EDIT_PLACEHOLDER_TITLE': 'Title',
    'EDIT_CHANGES_SUCCESS_HEADING': 'Changes successful',
    'EDIT_CHANGES_SUCCESS_CONTENT': 'Your changes have been saved successfully.',
    'EDIT_CHANGES_FAILURE_HEADING': 'Changes failed',
    'EDIT_CHANGES_FAILURE_CONTENT': 'Your changes couldn\'t be saved. Please check your connection or try again later.',
    'EDIT_VISIBILITY_LABEL': 'Visibility',
    'EDIT_VISIBILITY_PRIVATE': 'private',
    'EDIT_VISIBILITY_PUBLIC': 'public',
    'EDIT_VISIBILITY_DCMEMBER': 'DocCheck-member',
    'EDIT_VISIBILITY_MEDIC': 'medical member',
    'EDIT_BUTTON_SAVE': 'Save',
    'EDIT_BUTTON_ADD_TAG': 'Add',
    'SEARCH_OWN_PICTURES': 'My pictures',
    'SEARCH_OWN_LOGIN_REQUIRED': 'Please log in to see your own pictures.',
    'FEEDBACK_TITLE': 'Send feedback',
    'HELP_TITLE': 'Help &amp; tips',
    'HELP_CONTENT': '<b style="color:#000">What is the Pictures App?</b><br /> DocCheck Pictures is the free medical picture library of Europe\'s largest Healthcare-Community. The library contains among other things findings, case studies and clinical material. Search in over 20.000 medical pictures and share your interesting cases with over a million colleagues. <br /> With our free app the archive is always with you and you can easily share your cases at the push of a button. <br /> <br /> <b style="color:#000">How do I upload images?</b><br /> Just click on the camera down in the middle. You can choose between uploading images from your camera roll or taking a picture. The freshly taken picture will be uploaded automatically on DocCheck.<br /> <br /> <b style="color:#000">Who can see my images?</b><br /> That depends on the visibility you chose. You can change these by clicking on "Privacy" in the settings.<br /> <br /> <b style="color:#000">What to consider uploading images of patients?</b><br /> Especially on pictures it is easy to identify a person. So you need an agreement from your patient. Please take care, that faces of patients can\'t be recognized and names of your patient aren\'t published.',
    'PRIVACY_TITLE': 'Privacy',
    'SETTINGS_TITLE': 'Settings',
    'SETTINGS_NOTIFICATIONS': 'Notifications',
    'SETTINGS_SAVE_LOCALLY': 'Save locally',
    'SETTINGS_SIGN_OUT': 'Sign out',
    'SETTINGS_HELP': 'Help &amp; tips',
    'SETTINGS_PRIVACY': 'Privacy',
    'SETTINGS_FEEDBACK': 'Send feedback',
    'SETTINGS_PROMOTION': 'Additional information',
    'CONNECTION_ERROR': 'Connection failed',
    'NO_CONNECTION_HEADING': 'No connection',
    'NO_CONNECTION_CONTENT': 'No internet connection available. Please connect your device to the internet and try again.',
    'YES': 'Yes',
    'NO': 'No',
    'CONFIRM': 'Okay',
    'CANCEL': 'Cancel',
    'SUBMIT': 'Submit',
    'LOADING': 'Loading...',
    'LOGIN_REQUIRED': 'Login required',
    'LOGIN_REQUIRED_CONTENT': 'Please log in first to use this function.',
    'LOGIN_FAILED': 'Login failed',
    'LOGIN_FAILED_CONTENT': 'Username or password not correct.',
    'LOGIN_INCORRECT': 'Invalid combination of username and password.',
    'UPLOAD_SUCCESS_HEADING': 'Upload finished',
    'UPLOAD_SUCCESS_CONTENT': 'The upload was finished successfully.',
    'UPLOAD_FAILURE_HEADING': 'Upload canceled',
    'UPLOAD_FAILURE_CONTENT': 'The upload couldn\'t be finished. Please check your connection or try again later.',
    'UPLOAD_IN_PROGRESS_HEADING': 'Upload...',
    'UPLOAD_IN_PROGRESS_CONTENT': 'Picture is being uploaded...',
    'DISCLAIMER_TITLE': 'Disclaimer',
    'SETTINGS_DISCLAIMER': 'Disclaimer',
    'IMPRESS': 'Impress',
    'LANGUAGE': 'Language',
    'ADDITIONAL_INFORMATION': 'Additional information',
    'OFFLINE': 'An error occured while loading.<br /> Please check your Internet connection and try again.',
    'SEARCH_OWN_NO_ITEMS': 'You haven\'t uploaded any images yet. Click on the camrea below and start right now!',
    'PRIVACY_VISIBILITY_TEXT': 'Choose here, who can see your images.',
    'PRIVACY_RIGHTS_LABEL': 'Copyright',
    'PRIVACY_RIGHTS_TEXT': 'What rights are reserved for your images?',
    'PRIVACY_ALL_RIGHTS_RESERVED': 'All rights reserved',
    'PRIVACY_CREATIVE_COMMONS': 'Creative Commons',
    'PRIVACY_CC_ATTR': 'Attribution',
    'PRIVACY_CC_ATTR_NODER': 'Attribution-NoDerivs',
    'PRIVACY_CC_ATTR_SHARE': 'Attribution-ShareAlike',
    'PRIVACY_CC_ATTR_NONCOMM': 'Attribution-NonCommercial',
    'PRIVACY_CC_ATTR_NONCOMM_NODER': 'Attribution-NonCommercial-NoDerivs',
    'PRIVACY_CC_ATTR_NONCOMM_SHARE': 'Attribution-NonCommercial-ShareAlike',
    'PRIVACY_PUBLIC_DOMAIN': 'Public Domain Dedication',
    'OVERLAY_TAKE_PHOTO': 'Take photo',
    'OVERLAY_OPEN_GALLERY': 'Pick from gallery',
    'PRIVACY_IN_FUTURE': 'Soon you will also be able to change your default rights settings here.',
    'DETAIL_INFO': 'Details',
    'LOGIN_REQUIRED_REF': 'Sign in to see more exciting pictures.',
    'UPDATE': 'This is a pre-version of the new DocCheck pictures app and won\'t receive any further updates. So please install the <a href=\"https://itunes.apple.com/en/app/doccheck-pictures/id454491104?mt=8&uo=4\" target=\"itunes_store\">official Pictures App from the AppStore</a> as well in a few days to keep up to date.',
    'LOGIN_REQUIRED_FOR_CAMERA': 'Sign in to upload new pictures.',
    'LOGIN_REQUIRED_FOR_OWN': 'Sign in to access your own pictures.',
    'DISCLAIMER_CONTENT': '',
    'DC_LOGIN_USERNAME': 'Username',
    'DC_LOGIN_PASSWORD': 'Password',
    'DC_LOGIN_PASSWORDFORGOTTEN': 'Passwort forgotten?',
    'DC_LOGIN_REGISTER': 'Apply for a password',
    'DC_LOGIN_SUBMIT': 'Sign In'
  });
});

angular.module("DocCheckPictures.translations").config(function($translateProvider) {
  return $translateProvider.translations('es_ES', {

    /*
    #
     * 8888888 8888888
     * 88      88
     * 88      88
     * 8888    8888888
     * 88           88
     * 88           88
     * 8888888 8888888
    #
     */
    'DC_PICTURES': 'Doc<b>Check</b> Pictures',
    'SEARCH_PLACEHOLDER': 'Buscar',
    'SEARCH_CONNECTION_INFO': 'Connection to DocCheck Pictures couldn\'t be established.',
    'SEARCH_NEWEST_PICTURES': 'Imágenes más recientes',
    'SEARCH_NO_RESULTS': 'No results for this keyword',
    'SEARCH_RESULTS_FOR': 'resultados por',
    'DETAIL_DELETE_CHECK_HEADING': 'Borrar imagen',
    'DETAIL_DELETE_CHECK_CONTENT': '¿Estás seguro de que quieres borrar este imagen?',
    'DETAIL_DELETE_SUCCESS_HEADING': 'Deleted successfully',
    'DETAIL_DELETE_SUCCESS_CONTENT': 'The picture has been deleted successfully.',
    'DETAIL_DELETE_FAILURE_HEADING': 'Deletion failed',
    'DETAIL_DELETE_FAILURE_CONTENT': 'The picture couldn\'t be deleted. Please check your connection or try again later.',
    'DETAIL_PICINFO_FAILURE_CONTENT': 'The information concerning this picture couldn\'t be loaded. Please check your connection or try again later.',
    'EDIT_TITLE': 'Editar imagen',
    'EDIT_PLACEHOLDER_DESCRIPTION': 'Descripción',
    'EDIT_PLACEHOLDER_TAG': 'Añadir etiqueta',
    'EDIT_PLACEHOLDER_TITLE': 'Título',
    'EDIT_CHANGES_SUCCESS_HEADING': 'Changes successful',
    'EDIT_CHANGES_SUCCESS_CONTENT': 'Your changes have been performed successfully.',
    'EDIT_CHANGES_FAILURE_HEADING': 'Changes failed',
    'EDIT_CHANGES_FAILURE_CONTENT': 'Your changes couldn\'t be submitted. Please check your connection or try again later.',
    'EDIT_VISIBILITY_LABEL': 'Visibilidad',
    'EDIT_VISIBILITY_PRIVATE': 'privado',
    'EDIT_VISIBILITY_PUBLIC': 'público',
    'EDIT_VISIBILITY_DCMEMBER': 'DocCheck-member',
    'EDIT_VISIBILITY_MEDIC': 'medical member',
    'SEARCH_OWN_PICTURES': 'Mis imágenes',
    'SEARCH_OWN_LOGIN_REQUIRED': 'To view your own pictures please log in first.',
    'FEEDBACK_TITLE': 'Send feedback',
    'HELP_TITLE': 'Help &amp; tips',
    'HELP_CONTENT': '<b style="color:#000">What is the Pictures App?</b><br /> DocCheck Pictures is the free medical picture library of Europe\s largest Healthcare-Community. The library contains enthält u.a. Fallbeispiele, Befunddokumentationen, Mikrofotografien, bildgebende Verfahren der Medizin und schematische Darstellungen. Stöbern Sie in über 20.000 Medizinbildern und teilen Sie Ihre interessanten Fälle mit über 1.000.000 Kollegen. <br /> Mit der kostenlosen App haben Sie das Bildarchiv immer dabei und können Fälle ganz einfach per Knopfdruck teilen. <br /> <br /> <b style="color:#000">Wie kann ich ein Bild hochladen?</b><br /> Wenn Sie auf die Kamera in der Mitte unten klicken, können Sie auswählen, ob Sie Bilder aus Ihrem Archiv hochladen wollen oder direkt ein Foto aufnehmen wollen. Das frisch aufgenommene Foto wird dann automatisch direkt bei DocCheck hochgeladen.<br /> <br /> <b style="color:#000">Wer kann meine Bilder sehen?</b><br /> Das kommt ganz auf Ihre Sichtbarkeitseinstellungen an. Diese können Sie ändern, wenn Sie in den Einstellungen auf „Standard-Datenschutz“ klicken.<br /> <br /> <b style="color:#000">Was muss ich bei der Veröffentlichung von Patientenbildern beachten?</b><br /> Da gerade bei Bildern die Erkennbarkeit der Patienten nicht vollkommen ausgeschlossen werden kann und Bilder von Krankheiten die Intimsphäre des Patienten betreffen, ist eine Einwilligung des Patienten erforderlich. Bitte sorgen Sie in jedem Fall dafür, dass die Gesichter der Patienten nicht abgebildet werden und veröffentlichen Sie keine Namen Ihrer Patienten.',
    'PRIVACY_TITLE': 'Privacy',
    'SETTINGS_TITLE': 'Settings',
    'SETTINGS_NOTIFICATIONS': 'Notifications',
    'SETTINGS_SAVE_LOCALLY': 'Save locally',
    'SETTINGS_SIGN_OUT': 'Sign out',
    'SETTINGS_HELP': 'Help &amp; tips',
    'SETTINGS_PRIVACY': 'Privacy',
    'SETTINGS_FEEDBACK': 'Send feedback',
    'SETTINGS_PROMOTION': 'Additional information',
    'CONNECTION_ERROR': 'Connection failed',
    'NO_CONNECTION_HEADING': 'No connection',
    'NO_CONNECTION_CONTENT': 'No internet connection available. Please connect your device to the Internet and try again.',
    'YES': 'Sí',
    'NO': 'No',
    'CONFIRM': 'Okay',
    'CANCEL': 'Cancel',
    'SUBMIT': 'Submit',
    'LOADING': 'Loading...',
    'LOGIN_REQUIRED': 'Login required',
    'LOGIN_REQUIRED_CONTENT': 'Please log in first to use this function.',
    'LOGIN_FAILED': 'Login failed',
    'LOGIN_FAILED_CONTENT': 'Username or password not correct.',
    'LOGIN_INCORRECT': 'Invalid combination of username and password.',
    'UPLOAD_SUCCESS_HEADING': 'Upload finished',
    'UPLOAD_SUCCESS_CONTENT': 'The upload has finished successfully.',
    'UPLOAD_FAILURE_HEADING': 'Upload canceled',
    'UPLOAD_FAILURE_CONTENT': 'The upload couldn\'t be finished. Please check your connection or try again later.',
    'UPLOAD_IN_PROGRESS_HEADING': 'Upload...',
    'UPLOAD_IN_PROGRESS_CONTENT': 'Picture is being uploaded...',
    'DISCLAIMER_TITLE': 'Disclaimer',
    'SETTINGS_DISCLAIMER': 'Disclaimer',
    'IMPRESS': 'Impress',
    'LANGUAGE': 'Language',
    'ADDITIONAL_INFORMATION': 'Additional information',
    'OFFLINE': 'An error occured while loading.<br /> Please check your Internet connection and try again.',
    'SEARCH_OWN_NO_ITEMS': 'You haven\'t uploaded any images yet. Click on the camrea below and start right now!',
    'PRIVACY_VISIBILITY_TEXT': 'Hier kannst Du einstellen, wer Deine Bilder sehen darf.',
    'PRIVACY_RIGHTS_LABEL': 'Rights',
    'PRIVACY_RIGHTS_TEXT': 'Welche Rechte liegen auf deinen Bildern?',
    'PRIVACY_ALL_RIGHTS_RESERVED': 'All rights reserved',
    'PRIVACY_CREATIVE_COMMONS': 'Creative Commons',
    'PRIVACY_CC_ATTR': 'Attribution',
    'PRIVACY_CC_ATTR_NODER': 'Attribution-NoDerivs',
    'PRIVACY_CC_ATTR_SHARE': 'Attribution-ShareAlike',
    'PRIVACY_CC_ATTR_NONCOMM': 'Attribution-NonCommercial',
    'PRIVACY_CC_ATTR_NONCOMM_NODER': 'Attribution-NonCommercial-NoDerivs',
    'PRIVACY_CC_ATTR_NONCOMM_SHARE': 'Attribution-NonCommercial-ShareAlike',
    'PRIVACY_PUBLIC_DOMAIN': 'Public Domain Dedication',
    'OVERLAY_TAKE_PHOTO': 'Take photo',
    'OVERLAY_OPEN_GALLERY': 'Pick from gallery',
    'PRIVACY_IN_FUTURE': 'Soon you will also be able to change your default rights settings here.',
    'DETAIL_INFO': 'Details',
    'LOGIN_REQUIRED_REF': 'Sign in to see more exciting pictures and to upload your own.',
    'DISCLAIMER_CONTENT': ''
  });
});

angular.module("DocCheckPictures.translations").config(function($translateProvider) {
  return $translateProvider.translations('fr_FR', {

    /*
    #
     * 88888888 8888888
     * 88       88    88
     * 88       88    88
     * 88888    8888888
     * 88       88   88
     * 88       88    88
     * 88       88     88
    #
     */
    'DC_PICTURES': 'Doc<b>Check</b> Pictures',
    'SEARCH_PLACEHOLDER': 'Chercher',
    'SEARCH_CONNECTION_INFO': 'Connexion à DocCheck Pictures n\'a pas pu être établie.',
    'SEARCH_NEWEST_PICTURES': 'Dernières photos',
    'SEARCH_NO_RESULTS': 'Pas de résultats pour ce terme',
    'SEARCH_RESULTS_FOR': 'Résultats pour',
    'DETAIL_DELETE_CHECK_HEADING': 'Effacer photo',
    'DETAIL_DELETE_CHECK_CONTENT': 'Es-tu sûr de vouloir supprimer cette image ?',
    'DETAIL_DELETE_SUCCESS_HEADING': 'Supprimé avec succès',
    'DETAIL_DELETE_SUCCESS_CONTENT': 'The picture has been deleted successfully.',
    'DETAIL_DELETE_FAILURE_HEADING': 'Effacement a échoué.',
    'DETAIL_DELETE_FAILURE_CONTENT': 'Les informations d\'image n’ont pas pu être retirés. S’il te plaît contrôle ta connexion et réessaye plus tard.',
    'DETAIL_PICINFO_FAILURE_CONTENT': 'Les informations d\'image n’ont pas pu être chargés. S’il te plaît contrôle ta connexion et réessaye plus tard.',
    'EDIT_TITLE': 'Modifier photo',
    'EDIT_PLACEHOLDER_DESCRIPTION': 'Description',
    'EDIT_PLACEHOLDER_TAG': 'Ajouter tag',
    'EDIT_PLACEHOLDER_TITLE': 'Titre',
    'EDIT_CHANGES_SUCCESS_HEADING': 'Changements enregistrés avec succès',
    'EDIT_CHANGES_SUCCESS_CONTENT': 'Tes changements ont été enregistrés.',
    'EDIT_CHANGES_FAILURE_HEADING': 'Changements échoués.',
    'EDIT_CHANGES_FAILURE_CONTENT': 'Tes changements ne pouvaient pas être appliqués. Vérifie ta connexion ou réessaye plus tard.',
    'EDIT_VISIBILITY_LABEL': 'Visibilité',
    'EDIT_VISIBILITY_PRIVATE': 'privé',
    'EDIT_VISIBILITY_PUBLIC': 'publique',
    'EDIT_VISIBILITY_DCMEMBER': 'DocCheck-membre',
    'EDIT_VISIBILITY_MEDIC': 'membre médical',
    'SEARCH_OWN_PICTURES': 'Mes images',
    'SEARCH_OWN_LOGIN_REQUIRED': 'Connecte-toi pour voir tes images.',
    'FEEDBACK_TITLE': 'Envoyer feedback',
    'HELP_TITLE': 'Aide &amp; tuyau',
    'HELP_CONTENT': '<b style="color:#000">Qu’est-ce que c’est l’application Pictures ?</b><br /> DocCheck Pictures est l’archive d’images gratuite de la plus grande communauté des professionnels de la santé en Europe. L’archive contient, en autre, des études de cas, des documentations des résultats, des microphotographies, l’imagerie en médecine et des schémas. Trifouille dans plus de 20.000 images médicales et partage tes cas intéressants avec plus de 1.000.000 collègues. <br /> Avec l’application gratuite tu as l’archive d’images sur toi toujours et tu peux partagez tes cas facilement en appuyant sur un seul button. <br /> <br /> <b style="color:#000">Comment puis-je télécharger une image ?</b><br /> Si tu cliques sur la caméra au milieu ci-dessus, tu peux choisir si tu souhaites télécharger des images à partir de ta bibliothèque ou si tu souhaites prendre une photo directement. La nouvelle image est automatiquement téléchargée directement sur DocCheck.<br /> <br /> <b style="color:#000">Qui peut voir mes images ?</b><br /> Cela dépend de vos paramètres de visibilité. Vous pouvez changer cela en cliquant dans les paramètres « protection des données standard ».<br /> <br /> <b style="color:#000">Que dois-je prendre en considération en ce qui concerne la publication des images des patients ?</b><br /> Chez les photos la récognition des patients ne peut pas être complètement exclu et des images de maladies affectent la vie privée des patients. Donc, le consentement du patient est nécessaire. S’il te plaît prend soin en tout cas que les visages des patients ne sont pas visible et ne publie pas les noms de tes patients.',
    'PRIVACY_TITLE': 'Protection des données',
    'SETTINGS_TITLE': 'Paramètres',
    'SETTINGS_NOTIFICATIONS': 'Notifications',
    'SETTINGS_SAVE_LOCALLY': 'Enregistrer locale',
    'SETTINGS_SIGN_OUT': 'Déconnecter',
    'SETTINGS_HELP': 'Aide &amp; tuyau',
    'SETTINGS_PRIVACY': 'Protection des données',
    'SETTINGS_FEEDBACK': 'Envoyer feedback',
    'SETTINGS_PROMOTION': 'Plus d’informations',
    'CONNECTION_ERROR': 'Connexion a échoué',
    'NO_CONNECTION_HEADING': 'Pas de connection',
    'NO_CONNECTION_CONTENT': 'Pas de connexion internet disponible. S’il te plaît connecte ton appareil à l’internet et essaye à nouveau.',
    'YES': 'Oui',
    'NO': 'Non',
    'CONFIRM': 'Okay',
    'CANCEL': 'Annuler',
    'SUBMIT': 'Envoyer',
    'LOADING': 'Chargement…',
    'LOGIN_REQUIRED': 'Login nécessaire',
    'LOGIN_REQUIRED_CONTENT': 'S’il te plaît connecte-toi pour utiliser cette fonction.',
    'LOGIN_FAILED': 'Connexion a échoué',
    'LOGIN_FAILED_CONTENT': 'Nom d\'utilisateur ou mot de passe incorrect.',
    'LOGIN_INCORRECT': 'Combinaison de nom d\'utilisateur et mot de passe non invalide.',
    'UPLOAD_SUCCESS_HEADING': 'Téléchargement fini',
    'UPLOAD_SUCCESS_CONTENT': 'Ton image a été téléchargée.',
    'UPLOAD_FAILURE_HEADING': 'Téléchargement annulé',
    'UPLOAD_FAILURE_CONTENT': 'L\'image n\'a pas pu être téléchargé. S’il te plaît vérifie ta connexion internet ou le format de fichier',
    'UPLOAD_IN_PROGRESS_HEADING': 'Téléchargement…',
    'UPLOAD_IN_PROGRESS_CONTENT': 'Votre image sera téléchargée…',
    'DISCLAIMER_TITLE': 'Disclaimer',
    'SETTINGS_DISCLAIMER': 'Disclaimer',
    'IMPRESS': 'Impress',
    'LANGUAGE': 'Language',
    'ADDITIONAL_INFORMATION': 'Additional information',
    'OFFLINE': 'An error occured while loading.<br /> Please check your Internet connection and try again.',
    'SEARCH_OWN_NO_ITEMS': 'You haven\'t uploaded any images yet. Click on the camrea below and start right now!',
    'PRIVACY_VISIBILITY_TEXT': 'Hier kannst Du einstellen, wer Deine Bilder sehen darf.',
    'PRIVACY_RIGHTS_LABEL': 'Rights',
    'PRIVACY_RIGHTS_TEXT': 'Welche Rechte liegen auf deinen Bildern?',
    'PRIVACY_ALL_RIGHTS_RESERVED': 'All rights reserved',
    'PRIVACY_CREATIVE_COMMONS': 'Creative Commons',
    'PRIVACY_CC_ATTR': 'Attribution',
    'PRIVACY_CC_ATTR_NODER': 'Attribution-NoDerivs',
    'PRIVACY_CC_ATTR_SHARE': 'Attribution-ShareAlike',
    'PRIVACY_CC_ATTR_NONCOMM': 'Attribution-NonCommercial',
    'PRIVACY_CC_ATTR_NONCOMM_NODER': 'Attribution-NonCommercial-NoDerivs',
    'PRIVACY_CC_ATTR_NONCOMM_SHARE': 'Attribution-NonCommercial-ShareAlike',
    'PRIVACY_PUBLIC_DOMAIN': 'Public Domain Dedication',
    'OVERLAY_TAKE_PHOTO': 'Take photo',
    'OVERLAY_OPEN_GALLERY': 'Pick from gallery',
    'PRIVACY_IN_FUTURE': 'Soon you will also be able to change your default rights settings here.',
    'DETAIL_INFO': 'Details',
    'LOGIN_REQUIRED_REF': 'Sign in to see more exciting pictures and to upload your own.',
    'DISCLAIMER_CONTENT': ''
  });
});

angular.module("DocCheckPictures.translations").config(function($translateProvider) {
  return $translateProvider.translations('it_IT', {

    /*
    	  #
    	   * 88 88888888888
    	   * 88     88
    	   * 88     88
    	   * 88     88
    	   * 88     88
    	   * 88     88
    	   * 88     88
    	  #
     */
    'DC_PICTURES': 'DocCheck Pictures',
    'SEARCH_PLACEHOLDER': 'Search',
    'SEARCH_CONNECTION_INFO': 'Connection to DocCheck Pictures couldn\'t be established.',
    'SEARCH_NEWEST_PICTURES': 'Newest pictures',
    'SEARCH_NO_RESULTS': 'No results for this keyword',
    'SEARCH_RESULTS_FOR': 'results for',
    'DETAIL_DELETE_CHECK_HEADING': 'Confirm deletion',
    'DETAIL_DELETE_CHECK_CONTENT': 'Are you sure you want to delete this picture?',
    'DETAIL_DELETE_SUCCESS_HEADING': 'Deleted successfully',
    'DETAIL_DELETE_SUCCESS_CONTENT': 'The picture has been deleted successfully.',
    'DETAIL_DELETE_FAILURE_HEADING': 'Deletion failed',
    'DETAIL_DELETE_FAILURE_CONTENT': 'The picture couldn\'t be deleted. Please check your connection or try again later.',
    'DETAIL_PICINFO_FAILURE_CONTENT': 'The information concerning this picture couldn\'t be loaded. Please check your connection or try again later.',
    'EDIT_TITLE': 'Edit picture',
    'EDIT_PLACEHOLDER_DESCRIPTION': 'Description',
    'EDIT_PLACEHOLDER_TAG': 'Add tag',
    'EDIT_PLACEHOLDER_TITLE': 'Title',
    'EDIT_CHANGES_SUCCESS_HEADING': 'Changes successful',
    'EDIT_CHANGES_SUCCESS_CONTENT': 'Your changes have been performed successfully.',
    'EDIT_CHANGES_FAILURE_HEADING': 'Changes failed',
    'EDIT_CHANGES_FAILURE_CONTENT': 'Your changes couldn\'t be submitted. Please check your connection or try again later.',
    'EDIT_VISIBILITY_LABEL': 'Visibility',
    'EDIT_VISIBILITY_PRIVATE': 'private',
    'EDIT_VISIBILITY_PUBLIC': 'public',
    'EDIT_VISIBILITY_DCMEMBER': 'DocCheck-member',
    'EDIT_VISIBILITY_MEDIC': 'medical member',
    'SEARCH_OWN_PICTURES': 'I miei immagini',
    'SEARCH_OWN_LOGIN_REQUIRED': 'To view your own pictures please log in first.',
    'FEEDBACK_TITLE': 'Send feedback',
    'HELP_TITLE': 'Help &amp; tips',
    'HELP_CONTENT': '<b style="color:#000">What is the Pictures App?</b><br /> DocCheck Pictures is the free medical picture library of Europe\s largest Healthcare-Community. The library contains enthält u.a. Fallbeispiele, Befunddokumentationen, Mikrofotografien, bildgebende Verfahren der Medizin und schematische Darstellungen. Stöbern Sie in über 20.000 Medizinbildern und teilen Sie Ihre interessanten Fälle mit über 1.000.000 Kollegen. <br /> Mit der kostenlosen App haben Sie das Bildarchiv immer dabei und können Fälle ganz einfach per Knopfdruck teilen. <br /> <br /> <b style="color:#000">Wie kann ich ein Bild hochladen?</b><br /> Wenn Sie auf die Kamera in der Mitte unten klicken, können Sie auswählen, ob Sie Bilder aus Ihrem Archiv hochladen wollen oder direkt ein Foto aufnehmen wollen. Das frisch aufgenommene Foto wird dann automatisch direkt bei DocCheck hochgeladen.<br /> <br /> <b style="color:#000">Wer kann meine Bilder sehen?</b><br /> Das kommt ganz auf Ihre Sichtbarkeitseinstellungen an. Diese können Sie ändern, wenn Sie in den Einstellungen auf „Standard-Datenschutz“ klicken.<br /> <br /> <b style="color:#000">Was muss ich bei der Veröffentlichung von Patientenbildern beachten?</b><br /> Da gerade bei Bildern die Erkennbarkeit der Patienten nicht vollkommen ausgeschlossen werden kann und Bilder von Krankheiten die Intimsphäre des Patienten betreffen, ist eine Einwilligung des Patienten erforderlich. Bitte sorgen Sie in jedem Fall dafür, dass die Gesichter der Patienten nicht abgebildet werden und veröffentlichen Sie keine Namen Ihrer Patienten.',
    'PRIVACY_TITLE': 'Privacy',
    'SETTINGS_TITLE': 'Settings',
    'SETTINGS_NOTIFICATIONS': 'Notifications',
    'SETTINGS_SAVE_LOCALLY': 'Save locally',
    'SETTINGS_SIGN_OUT': 'Sign out',
    'SETTINGS_HELP': 'Help &amp; tips',
    'SETTINGS_PRIVACY': 'Privacy',
    'SETTINGS_FEEDBACK': 'Send feedback',
    'SETTINGS_PROMOTION': 'Additional information',
    'CONNECTION_ERROR': 'Connection failed',
    'NO_CONNECTION_HEADING': 'No connection',
    'NO_CONNECTION_CONTENT': 'No internet connection available. Please connect your device to the Internet and try again.',
    'YES': 'Yes',
    'NO': 'No',
    'CONFIRM': 'Okay',
    'CANCEL': 'Cancel',
    'SUBMIT': 'Submit',
    'LOADING': 'Loading...',
    'LOGIN_REQUIRED': 'Login required',
    'LOGIN_REQUIRED_CONTENT': 'Please log in first to use this function.',
    'LOGIN_FAILED': 'Login failed',
    'LOGIN_FAILED_CONTENT': 'Username or password not correct.',
    'LOGIN_INCORRECT': 'Invalid combination of username and password.',
    'UPLOAD_SUCCESS_HEADING': 'Upload finished',
    'UPLOAD_SUCCESS_CONTENT': 'The upload has finished successfully.',
    'UPLOAD_FAILURE_HEADING': 'Upload canceled',
    'UPLOAD_FAILURE_CONTENT': 'The upload couldn\'t be finished. Please check your connection or try again later.',
    'UPLOAD_IN_PROGRESS_HEADING': 'Upload...',
    'UPLOAD_IN_PROGRESS_CONTENT': 'Picture is being uploaded...',
    'DISCLAIMER_TITLE': 'Disclaimer',
    'SETTINGS_DISCLAIMER': 'Disclaimer',
    'IMPRESS': 'Impress',
    'LANGUAGE': 'Language',
    'ADDITIONAL_INFORMATION': 'Additional information',
    'OFFLINE': 'An error occured while loading.<br /> Please check your Internet connection and try again.',
    'SEARCH_OWN_NO_ITEMS': 'You haven\'t uploaded any images yet. Click on the camrea below and start right now!',
    'PRIVACY_VISIBILITY_TEXT': 'Hier kannst Du einstellen, wer Deine Bilder sehen darf.',
    'PRIVACY_RIGHTS_LABEL': 'Rights',
    'PRIVACY_RIGHTS_TEXT': 'Welche Rechte liegen auf deinen Bildern?',
    'PRIVACY_ALL_RIGHTS_RESERVED': 'All rights reserved',
    'PRIVACY_CREATIVE_COMMONS': 'Creative Commons',
    'PRIVACY_CC_ATTR': 'Attribution',
    'PRIVACY_CC_ATTR_NODER': 'Attribution-NoDerivs',
    'PRIVACY_CC_ATTR_SHARE': 'Attribution-ShareAlike',
    'PRIVACY_CC_ATTR_NONCOMM': 'Attribution-NonCommercial',
    'PRIVACY_CC_ATTR_NONCOMM_NODER': 'Attribution-NonCommercial-NoDerivs',
    'PRIVACY_CC_ATTR_NONCOMM_SHARE': 'Attribution-NonCommercial-ShareAlike',
    'PRIVACY_PUBLIC_DOMAIN': 'Public Domain Dedication',
    'OVERLAY_TAKE_PHOTO': 'Take photo',
    'OVERLAY_OPEN_GALLERY': 'Pick from gallery',
    'PRIVACY_IN_FUTURE': 'Soon you will also be able to change your default rights settings here.',
    'DETAIL_INFO': 'Details',
    'LOGIN_REQUIRED_REF': 'Sign in to see more exciting pictures and to upload your own.',
    'DISCLAIMER_CONTENT': ''
  });
});

angular.module("DocCheckPictures.translations").config(function($translateProvider) {
  return $translateProvider.translations('nl_NL', {

    /*
    	  #
    	   * 888     88 88
    	   * 8888    88 88
    	   * 88 88   88 88
    	   * 88  88  88 88
    	   * 88   88 88 88
    	   * 88    8888 88 
    	   * 88     888 8888888888
    	  #
     */
    'DC_PICTURES': 'DocCheck Pictures',
    'SEARCH_PLACEHOLDER': 'Search',
    'SEARCH_CONNECTION_INFO': 'Connection to DocCheck Pictures couldn\'t be established.',
    'SEARCH_NEWEST_PICTURES': 'Newest pictures',
    'SEARCH_NO_RESULTS': 'No results for this keyword',
    'SEARCH_RESULTS_FOR': 'results for',
    'DETAIL_DELETE_CHECK_HEADING': 'Confirm deletion',
    'DETAIL_DELETE_CHECK_CONTENT': 'Are you sure you want to delete this picture?',
    'DETAIL_DELETE_SUCCESS_HEADING': 'Deleted successfully',
    'DETAIL_DELETE_SUCCESS_CONTENT': 'The picture has been deleted successfully.',
    'DETAIL_DELETE_FAILURE_HEADING': 'Deletion failed',
    'DETAIL_DELETE_FAILURE_CONTENT': 'The picture couldn\'t be deleted. Please check your connection or try again later.',
    'DETAIL_PICINFO_FAILURE_CONTENT': 'The information concerning this picture couldn\'t be loaded. Please check your connection or try again later.',
    'EDIT_TITLE': 'Edit picture',
    'EDIT_PLACEHOLDER_DESCRIPTION': 'Description',
    'EDIT_PLACEHOLDER_TAG': 'Add tag',
    'EDIT_PLACEHOLDER_TITLE': 'Title',
    'EDIT_CHANGES_SUCCESS_HEADING': 'Changes successful',
    'EDIT_CHANGES_SUCCESS_CONTENT': 'Your changes have been performed successfully.',
    'EDIT_CHANGES_FAILURE_HEADING': 'Changes failed',
    'EDIT_CHANGES_FAILURE_CONTENT': 'Your changes couldn\'t be submitted. Please check your connection or try again later.',
    'EDIT_VISIBILITY_LABEL': 'Visibility',
    'EDIT_VISIBILITY_PRIVATE': 'private',
    'EDIT_VISIBILITY_PUBLIC': 'public',
    'EDIT_VISIBILITY_DCMEMBER': 'DocCheck-member',
    'EDIT_VISIBILITY_MEDIC': 'medical member',
    'SEARCH_OWN_PICTURES': 'Own pictures',
    'SEARCH_OWN_LOGIN_REQUIRED': 'To view your own pictures please log in first.',
    'FEEDBACK_TITLE': 'Send feedback',
    'HELP_TITLE': 'Help &amp; tips',
    'HELP_CONTENT': '<b style="color:#000">What is the Pictures App?</b><br /> DocCheck Pictures is the free medical picture library of Europe\s largest Healthcare-Community. The library contains enthält u.a. Fallbeispiele, Befunddokumentationen, Mikrofotografien, bildgebende Verfahren der Medizin und schematische Darstellungen. Stöbern Sie in über 20.000 Medizinbildern und teilen Sie Ihre interessanten Fälle mit über 1.000.000 Kollegen. <br /> Mit der kostenlosen App haben Sie das Bildarchiv immer dabei und können Fälle ganz einfach per Knopfdruck teilen. <br /> <br /> <b style="color:#000">Wie kann ich ein Bild hochladen?</b><br /> Wenn Sie auf die Kamera in der Mitte unten klicken, können Sie auswählen, ob Sie Bilder aus Ihrem Archiv hochladen wollen oder direkt ein Foto aufnehmen wollen. Das frisch aufgenommene Foto wird dann automatisch direkt bei DocCheck hochgeladen.<br /> <br /> <b style="color:#000">Wer kann meine Bilder sehen?</b><br /> Das kommt ganz auf Ihre Sichtbarkeitseinstellungen an. Diese können Sie ändern, wenn Sie in den Einstellungen auf „Standard-Datenschutz“ klicken.<br /> <br /> <b style="color:#000">Was muss ich bei der Veröffentlichung von Patientenbildern beachten?</b><br /> Da gerade bei Bildern die Erkennbarkeit der Patienten nicht vollkommen ausgeschlossen werden kann und Bilder von Krankheiten die Intimsphäre des Patienten betreffen, ist eine Einwilligung des Patienten erforderlich. Bitte sorgen Sie in jedem Fall dafür, dass die Gesichter der Patienten nicht abgebildet werden und veröffentlichen Sie keine Namen Ihrer Patienten.',
    'PRIVACY_TITLE': 'Privacy',
    'SETTINGS_TITLE': 'Settings',
    'SETTINGS_NOTIFICATIONS': 'Notifications',
    'SETTINGS_SAVE_LOCALLY': 'Save locally',
    'SETTINGS_SIGN_OUT': 'Sign out',
    'SETTINGS_HELP': 'Help &amp; tips',
    'SETTINGS_PRIVACY': 'Privacy',
    'SETTINGS_FEEDBACK': 'Send feedback',
    'SETTINGS_PROMOTION': 'Additional information',
    'CONNECTION_ERROR': 'Connection failed',
    'NO_CONNECTION_HEADING': 'No connection',
    'NO_CONNECTION_CONTENT': 'No internet connection available. Please connect your device to the Internet and try again.',
    'YES': 'Yes',
    'NO': 'No',
    'CONFIRM': 'Okay',
    'CANCEL': 'Cancel',
    'SUBMIT': 'Submit',
    'LOADING': 'Loading...',
    'LOGIN_REQUIRED': 'Login required',
    'LOGIN_REQUIRED_CONTENT': 'Please log in first to use this function.',
    'LOGIN_FAILED': 'Login failed',
    'LOGIN_FAILED_CONTENT': 'Username or password not correct.',
    'LOGIN_INCORRECT': 'Invalid combination of username and password.',
    'UPLOAD_SUCCESS_HEADING': 'Upload finished',
    'UPLOAD_SUCCESS_CONTENT': 'The upload has finished successfully.',
    'UPLOAD_FAILURE_HEADING': 'Upload canceled',
    'UPLOAD_FAILURE_CONTENT': 'The upload couldn\'t be finished. Please check your connection or try again later.',
    'UPLOAD_IN_PROGRESS_HEADING': 'Upload...',
    'UPLOAD_IN_PROGRESS_CONTENT': 'Picture is being uploaded...',
    'DISCLAIMER_TITLE': 'Disclaimer',
    'SETTINGS_DISCLAIMER': 'Disclaimer',
    'IMPRESS': 'Impress',
    'LANGUAGE': 'Language',
    'ADDITIONAL_INFORMATION': 'Additional information',
    'OFFLINE': 'An error occured while loading.<br /> Please check your Internet connection and try again.',
    'SEARCH_OWN_NO_ITEMS': 'You haven\'t uploaded any images yet. Click on the camrea below and start right now!',
    'PRIVACY_VISIBILITY_TEXT': 'Hier kannst Du einstellen, wer Deine Bilder sehen darf.',
    'PRIVACY_RIGHTS_LABEL': 'Rights',
    'PRIVACY_RIGHTS_TEXT': 'Welche Rechte liegen auf deinen Bildern?',
    'PRIVACY_ALL_RIGHTS_RESERVED': 'All rights reserved',
    'PRIVACY_CREATIVE_COMMONS': 'Creative Commons',
    'PRIVACY_CC_ATTR': 'Attribution',
    'PRIVACY_CC_ATTR_NODER': 'Attribution-NoDerivs',
    'PRIVACY_CC_ATTR_SHARE': 'Attribution-ShareAlike',
    'PRIVACY_CC_ATTR_NONCOMM': 'Attribution-NonCommercial',
    'PRIVACY_CC_ATTR_NONCOMM_NODER': 'Attribution-NonCommercial-NoDerivs',
    'PRIVACY_CC_ATTR_NONCOMM_SHARE': 'Attribution-NonCommercial-ShareAlike',
    'PRIVACY_PUBLIC_DOMAIN': 'Public Domain Dedication',
    'OVERLAY_TAKE_PHOTO': 'Take photo',
    'OVERLAY_OPEN_GALLERY': 'Pick from gallery',
    'PRIVACY_IN_FUTURE': 'Soon you will also be able to change your default rights settings here.',
    'DETAIL_INFO': 'Details',
    'LOGIN_REQUIRED_REF': 'Sign in to see more exciting pictures and to upload your own.',
    'DISCLAIMER_CONTENT': ''
  });
});

angular.module("DocCheckPictures.services").factory("Camera", [
  "$q", function($q) {
    return {
      getPicture: function(options) {
        var q;
        q = $q.defer();
        navigator.camera.getPicture((function(result) {
          q.resolve(result);
        }), (function(err) {
          q.reject(err);
        }), options);
        return q.promise;
      }
    };
  }
]);

angular.module("DocCheckPictures.services").factory("SlideTimer", function($interval, $state) {
  var timer;
  timer = void 0;
  return {
    start: function(callback, timeout) {
      if (timeout == null) {
        timeout = 4000;
      }
      if (!timer) {
        return timer = $interval(function() {
          if ($state.current.name === "app.home.search") {
            return callback();
          }
        }, timeout);
      }
    },
    stop: function() {
      return $interval.cancel(timer);
    }
  };
});

angular.module("DocCheckPictures.services").factory("Loading", function($rootScope, $http, $ionicPopup, authService, LocalStorage) {
  var isLoading;
  isLoading = false;
  return {
    start: function() {
      isLoading = true;
      if (!$rootScope.$$phase) {
        return $rootScope.$apply();
      }
    },
    stop: function() {
      isLoading = false;
      if (!$rootScope.$$phase) {
        return $rootScope.$apply();
      }
    },
    inProgress: function() {
      return isLoading;
    }
  };
});

angular.module("DocCheckPictures.services").factory("LocalStorage", [
  "$window", function($window) {
    return {
      set: function(key, value) {
        return $window.localStorage[key] = value;
      },
      get: function(key, defaultValue) {
        return $window.localStorage[key] || defaultValue;
      },
      unset: function(key) {
        return $window.localStorage[key] = '';
      },
      isSet: function(key) {
        return $window.localStorage[key] !== void 0 && $window.localStorage[key] !== '';
      },
      setObject: function(key, value) {
        return $window.localStorage[key] = JSON.stringify(value);
      },
      getObject: function(key) {
        return JSON.parse($window.localStorage[key] || "{}");
      }
    };
  }
]);

angular.module("DocCheckPictures.services").service('LoginModal', [
  '$ionicModal', '$rootScope', 'Login', function($ionicModal, $rootScope, Login) {
    var init;
    init = function($scope, tpl) {
      var promise;
      if (tpl == null) {
        tpl = 'templates/login-modal.html';
      }
      $scope = $rootScope;
      promise = $ionicModal.fromTemplateUrl(tpl, {
        scope: $scope,
        animation: 'fade-in'
      }).then(function(modal) {
        modal.focusFirstInput = true;
        $scope.loginModal = modal;
        return modal;
      });
      $scope.openModal = function() {
        if (screen.lockOrientation) {
          screen.lockOrientation('portrait');
        }
        return $scope.loginModal.show();
      };
      $scope.$on('modal.hidden', function() {
        if (screen.lockOrientation) {
          screen.unlockOrientation();
        }
        if (!Login.isAuthenticated()) {
          return Login.cancelActionCallback();
        }
      });
      $scope.closeModal = function() {
        if (screen.lockOrientation) {
          screen.unlockOrientation();
        }
        $scope.modal.hide();
        if (!Login.isAuthenticated()) {
          return Login.cancelActionCallback();
        }
      };
      $scope.$on('$destroy', function() {
        return $scope.modal.remove();
      });
      return promise;
    };
    return {
      init: init
    };
  }
]);

angular.module("DocCheckPictures.services").factory("Login", function($rootScope, $http, $ionicPopup, authService, LocalStorage, Loading, Settings) {
  var actionCallback, clientSecret, grantType, intialized, loginFailed, loginId, requiredFor, strDcLanguage, tokenDomain, url;
  actionCallback = void 0;
  loginFailed = false;
  requiredFor = '';
  url = 'https://login.doccheck.com/';
  tokenDomain = 'service/oauth/access_token/';
  loginId = '2000000007624';
  clientSecret = 'xyz';
  strDcLanguage = Settings.getLanguage(true);
  grantType = 'authorization_code';
  intialized = false;
  return {
    logout: function() {
      var options;
      LocalStorage.unset('accessToken');
      delete $http.defaults.headers.common.Authorization;
      if (window.AppGroupsUserDefaults) {
        options = {
          key: "accessToken",
          value: '',
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
        options = {
          key: "loginTime",
          value: '',
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
        options = {
          key: "validityDuration",
          value: '',
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
      }
      return $rootScope.$broadcast('event:auth-logout-complete');
    },
    loginCancelled: function() {
      return authService.loginCancelled();
    },
    isAuthenticated: function() {
      var gap;
      if ($http.defaults.headers.common.Authorization !== void 0 && $http.defaults.headers.common.Authorization !== "") {
        gap = (new Date().getTime()) - parseInt(LocalStorage.get('loginTime'));
        if (LocalStorage.isSet('loginTime') && gap <= parseInt(LocalStorage.get('validityDuration'))) {
          return true;
        }
      }
      return false;
    },
    loginFailed: function(failed) {
      var lastLoginAttemptFailed;
      if (failed == null) {
        failed = true;
      }
      return lastLoginAttemptFailed = failed;
    },
    didLastLoginFail: function() {
      return lastLoginAttemptFailed;
    },
    setActionCallback: function(callback) {
      return actionCallback = callback;
    },
    getActionCallback: function() {
      return actionCallback;
    },
    executeActionCallback: function() {
      if (actionCallback) {
        actionCallback();
        return actionCallback = void 0;
      }
    },
    cancelActionCallback: function() {
      return actionCallback = void 0;
    },
    setToken: function(token, expiresIn) {
      var expiresInMillis, loginTime, options, prefixedToken;
      loginFailed = false;
      prefixedToken = "Bearer " + token;
      loginTime = new Date().getTime();
      expiresInMillis = parseInt(expiresIn) * 1000;
      LocalStorage.set('accessToken', prefixedToken);
      LocalStorage.set('loginTime', loginTime);
      LocalStorage.set('validityDuration', expiresInMillis);
      $http.defaults.headers.common.Authorization = prefixedToken;
      if (window.AppGroupsUserDefaults) {
        options = {
          key: "accessToken",
          value: prefixedToken,
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
        options = {
          key: "loginTime",
          value: loginTime,
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
        options = {
          key: "validityDuration",
          value: expiresInMillis,
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
      }
      return authService.loginConfirmed();
    },
    didTokenTimeout: function() {
      if ((!LocalStorage.isSet('loginTime') || (new Date().getTime()) - LocalStorage.get('loginTime')) > LocalStorage.get('validityDuration')) {
        unsetToken();
        return true;
      }
      return false;
    },
    unsetToken: function() {
      var options;
      LocalStorage.unset('accessToken');
      if (window.AppGroupsUserDefaults) {
        options = {
          key: "accessToken",
          value: '',
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
        options = {
          key: "loginTime",
          value: '',
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
        options = {
          key: "validityDuration",
          value: '',
          suite: "group.dcpictures"
        };
        return window.AppGroupsUserDefaults.save(options, void 0, void 0);
      }
    },
    getToken: function() {
      return LocalStorage.get('accessToken');
    },
    didLoginFail: function() {
      return loginFailed;
    },
    setLoginFailed: function(fail) {
      return loginFailed = fail;
    },
    setRequiredFor: function(rfor) {
      return requiredFor = rfor;
    },
    getRequiredFor: function() {
      var rf;
      rf = requiredFor;
      requiredFor = '';
      return rf;
    },

    /*
     * Ask Service Integration
     */

    /*
     * Login
     */

    /*
     * Collect token
     */
    init: function() {
      if (!this.initialized) {
        console.log('Initializing Login');
        $http.defaults.headers.post['Content-Type'] = false;
        $http.defaults.headers.post['Allow-Control-Allow-Origin'] = '*';
        $http.defaults.headers.common['Accept'] = 'application/json';
        console.log('#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#');
        if (LocalStorage.isSet('dc_ask_access_token')) {
          $http.defaults.headers.common['Authorization'] = LocalStorage.get('dc_ask_access_token');
          console.log('# Restored oAuth token from local storage');
        }
        console.log('# Current authorization setting: ');
        console.log('# ' + $http.defaults.headers.common.Authorization);
        return console.log('#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#');
      }
    },
    collectToken: function(code) {
      return $http({
        url: url + tokenDomain,
        method: "POST",
        cache: false,
        params: {
          client_id: loginId,
          client_secret: clientSecret,
          grant_type: grantType,
          code: code
        }
      });
    },
    saveToken: function(token) {
      var expiresIn, loginTime, options;
      loginFailed = false;
      loginTime = new Date().getTime();
      expiresIn = 1000 * 60 * 60 * 24 * 31 * 6;
      LocalStorage.set('accessToken', token);
      LocalStorage.set('loginTime', loginTime);
      LocalStorage.set('validityDuration', expiresIn);
      $http.defaults.headers.common.Authorization = token;
      if (window.AppGroupsUserDefaults) {
        options = {
          key: "accessToken",
          value: token,
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
        options = {
          key: "loginTime",
          value: loginTime,
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
        options = {
          key: "validityDuration",
          value: expiresIn,
          suite: "group.dcpictures"
        };
        window.AppGroupsUserDefaults.save(options, void 0, void 0);
      }
      return authService.loginConfirmed();
    },
    errorFunction: function() {
      Loading.stop();
      this.unsetToken();
      return delete $http.defaults.headers.common.Authorization;
    },
    sendLoginRequest: function(username, password, successCallback, errorCallback) {
      var self;
      Loading.start();
      self = this;
      return $http({
        url: url,
        method: "POST",
        cache: false,
        params: {
          login_id: loginId,
          strDcLanguage: strDcLanguage,
          username: username,
          password: password
        }
      }).success(function(data, status, headers, config) {
        if (data.boolSuccess) {
          return self.collectToken(data.arrUrlParams.code).success(function(data, status, headers, config) {
            var token;
            token = data.token_type + " " + data.access_token;
            console.log('#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#');
            console.log('# New access token: ');
            console.log('# ' + token);
            console.log('#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#=-=#');
            self.saveToken(token);
            Loading.stop();
            return typeof successCallback === "function" ? successCallback(data, status, headers, config) : void 0;
          }).error(function(data, status, headers, config) {
            self.errorFunction();
            if (typeof errorCallback === "function") {
              errorCallback(data, status, headers, config);
            }
            return authService.loginCancelled();
          });
        } else {
          self.errorFunction();
          if (typeof errorCallback === "function") {
            errorCallback(data, status, headers, config);
          }
          return authService.loginCancelled();
        }
      }).error(function(data, status, headers, config) {
        self.errorFunction();
        if (typeof errorCallback === "function") {
          errorCallback(data, status, headers, config);
        }
        return authService.loginCancelled();
      });
    }
  };
});

angular.module("DocCheckPictures.services").factory("Network", function($base64, $http, $rootScope, $cacheFactory, Login, LocalStorage) {
  var dBarShown, dcapikey, hostUrl, userUrl;
  dBarShown = false;
  hostUrl = 'http://pictures.doccheck.com/api_photo';
  userUrl = 'http://pictures.doccheck.com/api_channel/token_owner';
  dcapikey = '12a8549da4f18604255d508f16805587f379b2f97efa4c5e';
  return {
    switchToTest: function() {
      console.log("Switched to Testserver!");
      hostUrl = 'http://pictures-dev0.dev53.antwerpes.de/api_photo';
      return userUrl = 'http://pictures-dev0.dev53.antwerpes.de/api_channel/token_owner';
    },
    switchToLive: function() {
      console.log("Switched to Liveserver!");
      hostUrl = 'http://pictures.doccheck.com/api_photo';
      return userUrl = 'http://pictures.doccheck.com/api_channel/token_owner';
    },
    getPhotoApiUrl: function() {
      return hostUrl;
    },
    getChannelUrl: function() {
      return userUrl;
    },
    getApiKey: function() {
      return dcapikey;
    },
    isConnected: function() {
      if (!navigator.connection) {
        return true;
      }
      return navigator.connection.type !== "none";
    }
  };
});

angular.module("DocCheckPictures.services").factory("Pictures", function() {
  var currentIndex, currentPicture, detailedPicture, items, itemsEditable, linkedPicture;
  detailedPicture = {};
  items = [];
  currentPicture = {};
  linkedPicture = {};
  currentIndex = [];
  itemsEditable = false;
  return {
    ownItems: function(bool) {
      if (bool !== void 0) {
        return itemsEditable = bool;
      } else {
        return itemsEditable;
      }
    },
    setPicture: function(picture) {
      return detailedPicture = picture;
    },
    getPicture: function() {
      return detailedPicture;
    },
    setLinkedPicture: function(picture) {
      return linkedPicture = picture;
    },
    getLinkedPicture: function() {
      var picture;
      picture = linkedPicture;
      linkedPicture = {};
      return picture;
    },
    setItems: function(pItems, pIndex, pScope) {
      var currentPictureId, results;
      items[pScope] = pItems.slice(0);
      currentPictureId = pIndex;
      currentIndex[pScope] = 0;
      results = [];
      while (("" + items[pScope][currentIndex[pScope]].id) !== ("" + currentPictureId)) {
        results.push(currentIndex[pScope]++);
      }
      return results;
    },
    getItems: function(pScope) {
      return items[pScope];
    },
    getCurrentPicture: function() {
      return currentPicture;
    },
    setCurrentPicture: function(picture) {
      return currentPicture = picture;
    },
    setCurrentIndex: function(index, pScope) {
      return currentIndex[pScope] = index;
    },
    getCurrentIndex: function(pScope) {
      var index;
      index = currentIndex[pScope];
      if (!index) {
        return 0;
      }
      return index;
    }
  };
});

angular.module("DocCheckPictures.services").factory("Platform", function() {
  var isAndroid, isAndroidPlatform;
  isAndroidPlatform = ~navigator.userAgent.indexOf('Android') > -1;
  return isAndroid = function() {
    return isAndroidPlatform;
  };
});

angular.module("DocCheckPictures.services").factory("Popup", function($rootScope, $ionicPopup) {
  var callback, popup;
  popup = void 0;
  callback = void 0;
  return {
    show: function(t, m, timeout, callback) {
      if (timeout == null) {
        timeout = 2000;
      }
      popup = $ionicPopup.show({
        title: t,
        template: m
      });
      if (timeout !== 0) {
        return setTimeout(function() {
          popup.close();
          if (callback) {
            return callback();
          }
        }, timeout);
      }
    },
    hide: function() {
      return popup.close();
    }
  };
});

angular.module("DocCheckPictures.services").factory("Rating", function() {
  var currentRating;
  currentRating = 0;
  return {
    setCurrentRating: function(rating) {
      return currentRating = rating;
    },
    getCurrentRating: function() {
      return currentRating;
    }
  };
});

angular.module("DocCheckPictures.services").factory("Search", function($base64, $http, $rootScope, $cacheFactory, Login, LocalStorage, Network, Settings) {

  /*
   * Manual caching of search results
   */
  var cache;
  cache = {
    "searchCache": {},
    "ownCache": {},
    "homeCache": {}
  };
  return {
    clearCaches: function() {
      cache = {
        "searchCache": {},
        "ownCache": {},
        "homeCache": {}
      };
      if ($cacheFactory.get('PictureCache')) {
        return $cacheFactory.get('PictureCache').removeAll();
      }
    },
    setCache: function(location, page, items, totalResults) {
      if (location == null) {
        location = "searchCache";
      }
      if (page == null) {
        page = 0;
      }
      if (items == null) {
        items = [];
      }
      if (totalResults == null) {
        totalResults = 0;
      }
      cache[location].page = page;
      cache[location].items = items;
      if (location === "searchCache") {
        cache[location].totalResults = totalResults;
        if (!cache[location].lastSearchPattern) {
          return cache[location].lastSearchPattern = "";
        }
      }
    },
    setLastSearchPattern: function(pattern) {
      if (pattern == null) {
        pattern = "";
      }
      if (pattern !== "search.more") {
        cache["searchCache"].lastSearchPattern = pattern;
        cache["searchCache"].page = 0;
        cache["searchCache"].items = [];
        return cache["searchCache"].totalResults = 0;
      }
    },
    getLastSearchPattern: function() {
      return cache['searchCache'].lastSearchPattern;
    },
    getCache: function(location) {
      if (location == null) {
        location = "searchCache";
      }
      return cache[location];
    },
    getPicturesByQuery: function(searchQuery, upage, intPhotosPerPage, excellent, cache) {
      var qParams, qUrl;
      if (searchQuery == null) {
        searchQuery = "";
      }
      if (upage == null) {
        upage = 1;
      }
      if (intPhotosPerPage == null) {
        intPhotosPerPage = 20;
      }
      if (excellent == null) {
        excellent = 0;
      }
      qUrl = Network.getPhotoApiUrl();
      qParams = {
        page: upage,
        epp: intPhotosPerPage * 2,
        term: searchQuery,
        dc_api_key: Network.getApiKey(),
        language: Settings.getLanguage(),
        excellent_flag: excellent
      };
      return $http({
        url: qUrl,
        method: 'GET',
        cache: $cacheFactory.get('PictureCache'),
        timeout: 10000,
        transformRequest: (function(_this) {
          return function(obj) {
            var p, str;
            str = [];
            for (p in obj) {
              str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]));
            }
            return str.join("&");
          };
        })(this),
        params: qParams
      });
    },
    getPictureDetailByQuery: function(id, pCache) {
      var qParams, qUrl;
      if (pCache == null) {
        pCache = false;
      }
      qUrl = Network.getPhotoApiUrl() + "/" + id;
      qParams = {
        dc_api_key: Network.getApiKey(),
        language: Settings.getLanguage()
      };
      return $http({
        url: qUrl,
        method: 'GET',
        cache: pCache,
        timeout: 10000,
        params: qParams
      });
    },
    getUserPictures: function(upage, intPhotosPerPage) {
      var qParams, qUrl;
      if (upage == null) {
        upage = 1;
      }
      if (intPhotosPerPage == null) {
        intPhotosPerPage = 20;
      }
      qUrl = Network.getChannelUrl();
      qParams = {
        page: upage,
        epp: intPhotosPerPage,
        dc_api_key: Network.getApiKey(),
        language: Settings.getLanguage()
      };
      return $http({
        url: qUrl,
        method: 'GET',
        cache: false,
        timeout: 10000,
        transformRequest: (function(_this) {
          return function(obj) {
            var p, str;
            str = [];
            for (p in obj) {
              str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]));
            }
            return str.join("&");
          };
        })(this),
        params: qParams
      });
    }
  };
});

angular.module("DocCheckPictures.services").factory("Settings", function(LocalStorage) {
  var selectedLanguage;
  selectedLanguage = void 0;
  return {
    getAvailableLanguages: function() {
      return ['DE', 'EN', 'de', 'en', 'de_DE', 'en_EN', 'de_de', 'en_en'];
    },
    setLanguage: function(l) {
      var options;
      console.log("SETLANGUAGE");
      console.log(l);
      if (l.indexOf('_') >= 0) {
        l = l.substring(0, l.indexOf('_'));
      }
      console.log(selectedLanguage);
      if (selectedLanguage !== l) {
        console.log("SET TO " + l);
        selectedLanguage = l;
        LocalStorage.set('language', l);
        console.log(selectedLanguage);
        if (selectedLanguage !== void 0 && selectedLanguage.length === 2 && window.AppGroupsUserDefaults) {
          options = {
            key: "dclang",
            value: selectedLanguage,
            suite: "group.dcpictures"
          };
          window.AppGroupsUserDefaults.save(options, void 0, void 0);
        }
        return true;
      }
      return false;
    },
    getLanguage: function(loginUrl) {
      if (loginUrl == null) {
        loginUrl = false;
      }
      if (!selectedLanguage) {
        selectedLanguage = LocalStorage.get('language');
      }
      if (loginUrl) {
        if (selectedLanguage === 'en') {
          return 'com';
        }
      }
      return selectedLanguage;
    }
  };
});

angular.module("DocCheckPictures.services").factory("UpdateTimer", function($timeout, $ionicPopup) {
  var text, timer;
  timer = void 0;
  text = void 0;
  return {
    start: function(text) {
      var self;
      if (text == null) {
        text = '';
      }
      this.text = text;
      if (!timer) {
        self = this;
        return $ionicPopup.alert({
          title: "",
          template: self.text
        }).then(function() {
          return self.startTimeout();
        });
      }
    },
    setText: function(text) {
      if (text == null) {
        text = '';
      }
      return this.text = text;
    },
    startTimeout: function() {
      var self;
      self = this;
      return timer = $timeout(function() {
        return $ionicPopup.alert({
          title: "",
          template: self.text
        });
      }, 86400000).then(function() {
        return self.startTimeout();
      });
    },
    stop: function() {
      return $interval.cancel(timer);
    }
  };
});

angular.module("DocCheckPictures.services").factory("UserPictures", function($base64, $http, $rootScope, $cacheFactory, Login, LocalStorage, Network, Settings) {
  return {
    upload: function(imageData, startedCallback, finishedCallback, progressCallback, errorCallback) {
      var createBlob, uploadFile;
      if (startedCallback == null) {
        startedCallback = void 0;
      }
      if (finishedCallback == null) {
        finishedCallback = void 0;
      }
      if (progressCallback == null) {
        progressCallback = void 0;
      }
      if (errorCallback == null) {
        errorCallback = void 0;
      }
      uploadFile = function(file) {
        var createFileName, fd, qData, qUrl, xhr;
        qUrl = Network.getPhotoApiUrl();
        qData = {
          Filedata: file,
          language: Settings.getLanguage()
        };
        createFileName = function() {
          var d;
          d = new Date();
          return "" + d.getFullYear() + "-" + (d.getMonth() + 1) + "-" + d.getDate() + "-" + d.getHours() + "-" + d.getMinutes() + "-" + d.getSeconds() + "-DcApp.jpeg";
        };
        fd = new FormData();
        fd.append('Filedata', file, createFileName());
        fd.append('language', Settings.getLanguage());
        fd.append('visibility', LocalStorage.get('privacySetting'));
        xhr = new XMLHttpRequest();
        xhr.upload.addEventListener('progress', function(e) {
          if (progressCallback) {
            return progressCallback(e);
          }
        }, false);
        xhr.addEventListener("load", function(e) {
          if (finishedCallback) {
            return finishedCallback(e);
          }
        }, false);
        xhr.addEventListener("error", function(e) {
          if (errorCallback) {
            return errorCallback(e);
          }
        }, false);
        xhr.addEventListener("abort", function(e) {
          if (errorCallback) {
            return errorCallback(e);
          }
        }, false);
        xhr.open('POST', qUrl);
        xhr.setRequestHeader('Cache-Control', 'no-cache');
        xhr.setRequestHeader('Authorization', Login.getToken());
        xhr.setRequestHeader('dc_api_key', Network.getApiKey());
        if (startedCallback) {
          startedCallback();
        }
        return xhr.send(fd);
      };
      createBlob = function(base64str) {
        var binary, blob, buffer, i, len, view;
        binary = atob(base64str.replace(/\s/g, ''));
        len = binary.length;
        buffer = new ArrayBuffer(len);
        view = new Uint8Array(buffer);
        i = 0;
        while (i < len) {
          view[i] = binary.charCodeAt(i);
          i++;
        }
        blob = new Blob([view], {
          type: "image/jpeg"
        });
        return blob;
      };
      return uploadFile(createBlob(imageData));
    },
    "delete": function(id) {
      var qParams, qUrl;
      qUrl = Network.getPhotoApiUrl() + "/" + id;
      qParams = {
        dc_api_key: Network.getApiKey()
      };
      return $http({
        url: qUrl,
        method: 'DELETE',
        params: qParams
      });
    },
    update: function(pictureObj) {
      var qParams, qUrl;
      qUrl = Network.getPhotoApiUrl() + "/" + pictureObj.id;
      qParams = {
        'language': Settings.getLanguage(),
        'title': pictureObj.title,
        'visibility': pictureObj.visibility,
        'description': pictureObj.description,
        'tags[]': pictureObj.tags,
        'dc_api_key': Network.getApiKey()
      };
      return $http({
        url: qUrl,
        method: 'PUT',
        params: qParams
      });
    }
  };
});
