'use strict';
angular.module("DocCheckPictures", ["ionic", "DocCheckPictures.controllers", "DocCheckPictures.services", "DocCheckPictures.directives", "base64"]).run(function($ionicPlatform, $cacheFactory, $http) {
  return $ionicPlatform.ready(function() {
    var _ref, _ref1, _ref2;
    $cacheFactory("PictureCache", {
      capacity: 10,
      cacheFlushInterval: 1,
      maxAge: 60000,
      deleteOnExpire: 'aggressive',
      recycleFreq: 1000,
      disabled: true
    });
    $http.defaults.cache = $cacheFactory.get('PictureCache');
    if ((_ref = window.cordova) != null) {
      if ((_ref1 = _ref.plugins.Keyboard) != null) {
        _ref1.hideKeyboardAccessoryBar();
      }
    }
    if ((_ref2 = window.StatusBar) != null) {
      _ref2.styleDefault();
    }
    return ionic.Platform.ready(function() {
      return StatusBar.hide();
    });
  });
}).config(function($stateProvider, $urlRouterProvider) {
  $stateProvider.state("app", {
    url: "/app",
    abstract: true,
    templateUrl: "templates/tab-view.html",
    controller: "AppCtrl"
  }).state("app.picture", {
    url: "/picture",
    abstract: true,
    views: {
      "picture": {
        template: "<ion-nav-view></ion-nav-view>"
      }
    }
  }).state("app.picture.search", {
    url: "/search",
    templateUrl: "templates/picture-search-view.html",
    controller: "PictureSearchCtrl"
  }).state("app.picture.detail", {
    url: "/detail",
    templateUrl: "templates/picture-detail-view.html",
    controller: "PictureDetailCtrl"
  }).state("app.settings", {
    url: "settings",
    views: {
      "settings": {
        templateUrl: "templates/settings-view.html",
        controller: "SettingsCtrl"
      }
    }
  });
  return $urlRouterProvider.otherwise('/app/picture/search');
});

angular.module('DocCheckPictures.controllers', []);

angular.module('DocCheckPictures.directives', []);

angular.module("DocCheckPictures.services", []);

angular.module("DocCheckPictures.controllers").controller('AppCtrl', function($scope, $http, $ionicLoading, Search, Pictures, Camera) {

  /*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
   *#  AppCtrl                         #
   *   -> tab-view.html               ##
   *-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
   */

  /*
   * Camera-Handling
   */
  $scope.getPhoto = function() {
    Camera.getPicture().then((function(imageURI) {
      console.log(imageURI);
    }), function(err) {
      console.err(err);
    });
  };

  /*
   * Loading Utility
   */
  $scope.showLoading = function() {
    return $scope.loading = true;

    /*
    $ionicLoading.show({
      template: '<i class="icon ion-loading-c"></i> Wird geladen...'
    
      })
     */
  };
  $scope.hideLoading = function() {
    return $scope.loading = false;

    /*
    $ionicLoading.hide()
     */
  };

  /*
   * General Stuff
   */
  $scope.goBack = function() {
    return $ionicViewService.getBackView().go();
  };
  $scope.toggleHidden = function() {
    return $scope.searchbar.hidden = $scope.searchbar.hidden ? false : true;
  };
  $scope.searchbar = {
    'hidden': false
  };
  return $scope.loading = false;
});

angular.module("DocCheckPictures.controllers").controller('PictureDetailCtrl', function($scope, $ionicSlideBoxDelegate, Pictures, $ionicModal, Rating, $ionicScrollDelegate) {

  /*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
   *#  PictureDetailCtrl               #
   *   -> picture-detail-view         ##
   *-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
   */
  $scope.currentItem = {};

  /*
   * Picture Service Helpers
   */
  $scope.getPicture = function() {
    return Pictures.getPicture();
  };
  $scope.getItems = function() {
    return Pictures.getItems();
  };
  $scope.activeSlide = function() {
    return Pictures.getCurrentPicture();
  };

  /*
   * UI Update on load / slide change
   */
  $scope.onSlideChange = function($index) {
    return $scope.updateInfoSection($index);
  };
  $scope.updateInfoSection = function($index) {
    $scope.currentItem = $scope.items[$index];
    $scope.slide.index = $index;
    $scope.rating = $scope.currentItem.rating;
    $scope.parseTags();
    console.log($scope.currentItem);
    return console.log($scope.rating);
  };
  $scope.isHidden = function($index) {
    var len;
    len = $scope.items.length;
    if (($index + len - $scope.slide.index) % len > 1 && ($scope.slide.index + len - $index) % len > 1) {
      return false;
    }
    return true;
  };
  $scope.parseTags = function() {
    var tag, _i, _len, _ref, _results;
    $scope.formatted.tags = "";
    _ref = $scope.currentItem.tags;
    _results = [];
    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
      tag = _ref[_i];
      _results.push($scope.formatted.tags += "[" + tag + "] ");
    }
    return _results;
  };
  $scope.loadNextSlide = function($index) {
    var slideToLoad;
    slideToLoad = $index + $scope.pufferLength;
    if (slideToLoad < $scope.items.length && slideToLoad >= $scope.loadedItems.length) {
      console.log("PUSHED");
      $scope.loadedItems.push($scope.items[slideToLoad]);
      return $ionicSlideBoxDelegate.update();
    }
  };
  $scope.prepareLoadedSlides = function($index) {
    var i, _i, _ref, _results;
    if ($scope.items.length < 3) {
      $scope.pufferLength = $scope.items.length;
    }
    console.log($scope.pufferLength);
    _results = [];
    for (i = _i = 0, _ref = $scope.pufferLength; 0 <= _ref ? _i <= _ref : _i >= _ref; i = 0 <= _ref ? ++_i : --_i) {
      _results.push($scope.loadedItems.push($scope.items[i]));
    }
    return _results;
  };
  $scope.scrollTop = function() {
    return $ionicScrollDelegate.scrollTop(true);
  };
  $scope.scrollBottom = function() {
    return $ionicScrollDelegate.scrollBottom(true);
  };

  /*
   * Modal
   */
  $scope.openModal = function() {
    return $scope.modal.show();
  };
  $scope.closeModal = function() {
    return $scope.modal.hide();
  };
  $scope.isFilled = function($index) {
    if ($index <= $scope.rating) {
      return "filled ion-ios7-star";
    }
    return "notfilled ion-ios7-star-outline";
  };
  $scope.setRating = function($index) {
    if ($scope.rating === $index) {
      return $scope.rating = $scope.rating - 1;
    } else {
      return $scope.rating = $index;
    }
  };
  $scope.getNumber = function(num) {
    return new Array(num);
  };

  /*
   * Utility
   */
  $scope.init = function() {
    $ionicModal.fromTemplateUrl('templates/picture-detail-modal.html', {
      scope: $scope,
      animation: 'ease-in-out'
    }).then(function(modal) {
      return $scope.modal = modal;
    });
    $scope.$on('$destroy', function() {
      $scope.modal.remove();
      $scope.items = [];
      $scope.slide.index = -3;
      return console.log("destroyed!");
    });
    $scope.$on('modal.hidden', function() {});
    $scope.$on('modal.removed', function() {});
    $scope.items = $scope.getItems();
    $scope.formatted = {
      'tags': ''
    };
    $scope.loadedItems = [];
    $scope.pufferLength = 3;
    $scope.slide = {
      'index': 0
    };
    return $scope.updateInfoSection(0);
  };
  return $scope.init();
});

angular.module("DocCheckPictures.controllers").controller('PictureSearchCtrl', function($scope, $ionicScrollDelegate, $http, Search, Pictures, Camera) {

  /*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
   *#  PictureSearchCtrl               #
   *   -> picture-search-view         ##
   *-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
   */

  /*
   * Current Pictures
   */
  $scope.setItems = function(append) {
    if (append == null) {
      append = false;
    }
    if (!append) {
      $scope.clearItems();
    }
    return $scope.items.push.apply($scope.items, $scope.results);
  };
  $scope.clearItems = function() {
    var _results;
    _results = [];
    while ($scope.items.length > 0) {
      _results.push($scope.items.pop());
    }
    return _results;
  };
  $scope.setItemsInService = function(id) {
    return Pictures.setItems($scope.items, id);
  };
  $scope.setPictureDim = function($index, item) {
    return $scope.pictures.dim = window.innerWidth / 3;
  };
  $scope.getPictureDim = function($index, item) {
    return $scope.pictures.dim;
  };

  /*
   * Search
   */
  $scope.clearResults = function() {
    return $scope.results = [];
  };
  $scope.search = function(searchQuery, page, callback) {
    var append, e;
    if (searchQuery == null) {
      searchQuery = "";
    }
    if (page == null) {
      page = 0;
    }
    if (callback == null) {
      callback = void 0;
    }
    console.log("searching!");
    $scope.clearResults();
    append = true;
    $scope.showLoading();
    if (searchQuery.length > 2 || searchQuery.length === 0) {
      if (searchQuery === "search.more") {
        searchQuery = Search.getLastSearchPattern();
        $scope.page++;
        console.log("Page increased: " + $scope.page);
        $scope.searchvar.hasMoreData = true;
        $scope.searchvar.noDataAtAll = false;
      } else {
        Search.setLastSearchPattern(searchQuery);
        $scope.clearItems();
        $scope.page = 1;
        console.log($scope.page + " reset");
        append = false;
        $ionicScrollDelegate.scrollTop();
      }
      try {
        return Search.getPicturesByQuery(searchQuery, $scope.page, $scope.intPhotosPerPage).success(function(response) {
          response = response.replace(/\(/g, "").replace(/\)/g, "").replace(/\;/g, "").replace(/\?/g, "");
          response = angular.fromJson(response);
          if (response.data.results.length === 0) {

            /*
             * No data found for keyword
             */
            $scope.$broadcast('scroll.infiniteScrollComplete');
            $scope.searchvar.hasMoreData = false;
            console.log("FALSE IF!");
            $scope.searchvar.noDataAtAll = true;
          } else if (parseInt(response.data.currentPage, 10) !== $scope.page) {

            /*
             * No more data available
             */
            $scope.intPhotosToShow = $scope.intPhotosPerPage * $scope.page;
            $scope.$broadcast('scroll.infiniteScrollComplete');
            $scope.searchvar.hasMoreData = false;
            console.log("FALSE ELSE!");
            console.log(parseInt(response.data.currentPage, 10));
            console.log($scope.page);
          } else {

            /*
             * Data found
             */
            $scope.intPhotosToShow = $scope.intPhotosPerPage * ($scope.page - 1) + $scope.intPhotosPerPage / 2;
            $scope.setSearchResults(response);
            if (typeof callback === 'function') {
              callback(response);
            }
            $scope.setItems(append);
            $scope.$broadcast('scroll.infiniteScrollComplete');
            $scope.$broadcast('scroll.resize');
            $scope.searchvar.hasMoreData = true;
            $scope.searchvar.noDataAtAll = false;
          }
          $scope.hideLoading();
        }).error(function(data, status, headers, config) {
          console.log("JSON error!!!");
          console.log(data);
          $scope.searchvar.hasMoreData = false;
          $scope.hideLoading();
          console.log("FALSE ERROR!");
        });
      } catch (_error) {
        e = _error;
        console.log(e);
      }
    }
  };
  $scope.setSearchResults = function(response) {
    var i, photo, _i, _ref;
    if (response.data.results.length !== 0) {
      for (i = _i = 0, _ref = response.data.results.length - 1; 0 <= _ref ? _i <= _ref : _i >= _ref; i = 0 <= _ref ? ++_i : --_i) {
        photo = response.data.results[i];
        photo.index = i;
        $scope.results.push(photo);
      }
    }
    return $scope.totalResults = parseInt(response.numberOfResults, 10);
  };

  /*
   * Service Helper
   */
  $scope.setImage = function(imageId) {
    return Pictures.setImage($scope.results[imageId]);
  };

  /*
   * Utility
   */
  $scope.loseFocus = function($event) {
    var formElement;
    formElement = $event.currentTarget;
    console.log(formElement.children);
    return formElement.children[0].children[1].blur();
  };
  $scope.init = function() {
    $scope.searchStatus = false;
    $scope.searchString = '';
    $scope.totalResults = 0;
    $scope.searchResultCountLoaded = 0;
    $scope.searchResultsPerPage = 0;
    $scope.searchPageCount = 0;
    $scope.searchPageCurrent = 1;
    $scope.photos = [];
    $scope.photosOrder = [];
    $scope.intPhotosPerPage = 30;
    $scope.intPhotosToShow = 15;
    $scope.currentVisibleSearchResults = 0;
    $scope.photoWrittenCounter = 0;
    $scope.results = [];
    $scope.items = [];
    $scope.page = 0;
    $scope.searchvar = {
      'hasMoreData': true
    };
    $scope.pictures = {
      'dim': 0
    };
    angular.element(window).bind('orientationchange', function() {
      return $scope.setPictureDim();
    });
    return $scope.setPictureDim();
  };
  return $scope.init();
});

angular.module("DocCheckPictures.controllers").controller('SettingsCtrl', function($scope) {

  /*-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#
   *#  SettingsCtrl                    #
   *   -> settings-view               ##
   *-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-#-
   */
});

angular.module('DocCheckPictures.directives').directive('starrating', function() {
  return {
    restrict: 'E',
    templateUrl: 'templates/star-rating-element.html'
  };
});

angular.module("DocCheckPictures.services").factory("Camera", [
  "$q", function($q) {
    return {
      getPicture: function(options) {
        var q;
        q = $q.defer();
        navigator.camera.getPicture((function(result) {
          q.resolve(result);
        }), (function(err) {
          q.reject(err);
        }), options);
        return q.promise;
      }
    };
  }
]);

angular.module("DocCheckPictures.services").factory("Pictures", function() {
  var currentPictureId, detailedPicture, items;
  detailedPicture = {};
  items = [];
  currentPictureId = 0;
  return {
    setPicture: function(picture) {
      var detailedPicurue;
      return detailedPicurue = picture;
    },
    getPicture: function() {
      return detailedPicture;
    },
    setItems: function(pItems, pIndex) {
      var x, _results;
      items = pItems.slice(0);
      currentPictureId = pIndex;
      _results = [];
      while (("" + items[0].id) !== ("" + currentPictureId)) {
        x = items.shift();
        _results.push(items.push(x));
      }
      return _results;
    },
    getItems: function() {
      return items;
    },
    getCurrentPicture: function() {
      return currentPictureId;
    }
  };
});

angular.module("DocCheckPictures.services").factory("Rating", function() {
  var currentRating;
  currentRating = 0;
  return {
    setCurrentRating: function(rating) {
      return currentRating = rating;
    },
    getCurrentRating: function() {
      return currentRating;
    }
  };
});

angular.module("DocCheckPictures.services").factory("Search", function($base64, $http, $cacheFactory) {
  var hostUrl, lastSearchPattern, searchBarShown;
  searchBarShown = false;
  hostUrl = 'http://pictures.doccheck.com/de/';
  lastSearchPattern = "";
  return {
    getPicturesByQuery: function(searchQuery, page, intPhotosPerPage) {
      var qParams, qUrl;
      if (searchQuery == null) {
        searchQuery = "";
      }
      if (page == null) {
        page = 1;
      }
      if (intPhotosPerPage == null) {
        intPhotosPerPage = 20;
      }
      if (searchQuery === "") {
        qUrl = hostUrl + "service/list/new-photos?jsoncallback=?";
      } else {
        qUrl = hostUrl + "service/search/do?jsoncallback=?";
        qParams = {
          q: searchQuery,
          p: page,
          rpp: intPhotosPerPage
        };
      }
      return $http({
        url: qUrl,
        method: 'GET',
        cache: $cacheFactory.get('PictureCache'),
        transformRequest: (function(_this) {
          return function(obj) {
            var p, str;
            str = [];
            for (p in obj) {
              str.push(encodeURIComponent(p) + "=" + encodeURIComponent(obj[p]));
            }
            return str.join("&");
          };
        })(this),
        params: qParams
      });
    },
    setLastSearchPattern: function(pattern) {
      return lastSearchPattern = pattern;
    },
    getLastSearchPattern: function() {
      return lastSearchPattern;
    }
  };
});
